# iblai
API for iblai

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 3.54.3-ai-plus
- Package version: 3.54.3+ai.plus
- Generator version: 7.7.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/iblai/iblai-python-sdk.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/iblai/iblai-python-sdk.git`)

Then import the package:
```python
import iblai
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import iblai
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import iblai
from iblai.clients import get_platform_api_client
from iblai.rest import ApiException
from pprint import pprint

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# The APIs use bearer tokens for authentication with a prefix of: `Api-Key`
# You can generate an authenticated client using the following helper method
client = get_platform_api_client(
    host="https://base.manager.iblai.app", 
    key=os.environ["API_KEY"]
)


# There are two main ways to then use the API
# 1. Make the client the default for all API calls
iblai.ApiClient.set_default(client)
api_instance = iblai.MediaResourcesApi()

# 2. Pass the client to each API constructor
api_instance = iblai.MediaResourcesApi(client)

# Then use that api_instance
item_id = 'item_id_example' # str | ID of the item
item_type = 'item_type_example' # str | Type of item. Valid values: course, unit, resource, course_unit, course_resource, unit_resource, all
org = 'org_example' # str | Organization identifier
user_id = 'user_id_example' # str | User identifier
course_id = 'course_id_example' # str | Filter by course ID (e.g., course-v1:main+NB101+2025-T1) (optional)
search = 'search_example' # str | Search across title, description, course_id, unit_id, item_id, and file_url (optional)
unit_id = 'unit_id_example' # str | Filter by unit ID (e.g., block-v1:main+NB101+2025-T1+type@vertical+block@12345) (optional)

try:
    api_instance.media_orgs_users_media_media_resources_by_item_retrieve(item_id, item_type, org, user_id, course_id=course_id, search=search, unit_id=unit_id)
except ApiException as e:
    print("Exception when calling MediaResourcesApi->media_orgs_users_media_media_resources_by_item_retrieve: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://base.manager.iblai.app*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*MediaResourcesApi* | [**media_orgs_users_media_media_resources_by_item_retrieve**](docs/MediaResourcesApi.md#media_orgs_users_media_media_resources_by_item_retrieve) | **GET** /api/media/orgs/{org}/users/{user_id}/media/media-resources/by_item/ | 
*MediaResourcesApi* | [**media_orgs_users_media_media_resources_create**](docs/MediaResourcesApi.md#media_orgs_users_media_media_resources_create) | **POST** /api/media/orgs/{org}/users/{user_id}/media/media-resources/ | 
*MediaResourcesApi* | [**media_orgs_users_media_media_resources_destroy**](docs/MediaResourcesApi.md#media_orgs_users_media_media_resources_destroy) | **DELETE** /api/media/orgs/{org}/users/{user_id}/media/media-resources/{id}/ | 
*MediaResourcesApi* | [**media_orgs_users_media_media_resources_list**](docs/MediaResourcesApi.md#media_orgs_users_media_media_resources_list) | **GET** /api/media/orgs/{org}/users/{user_id}/media/media-resources/ | 
*MediaResourcesApi* | [**media_orgs_users_media_media_resources_partial_update**](docs/MediaResourcesApi.md#media_orgs_users_media_media_resources_partial_update) | **PATCH** /api/media/orgs/{org}/users/{user_id}/media/media-resources/{id}/ | 
*MediaResourcesApi* | [**media_orgs_users_media_media_resources_retrieve**](docs/MediaResourcesApi.md#media_orgs_users_media_media_resources_retrieve) | **GET** /api/media/orgs/{org}/users/{user_id}/media/media-resources/{id}/ | 
*MediaResourcesApi* | [**media_orgs_users_media_media_resources_search_retrieve**](docs/MediaResourcesApi.md#media_orgs_users_media_media_resources_search_retrieve) | **GET** /api/media/orgs/{org}/users/{user_id}/media/media-resources/search/ | 
*MediaResourcesApi* | [**media_orgs_users_media_media_resources_update**](docs/MediaResourcesApi.md#media_orgs_users_media_media_resources_update) | **PUT** /api/media/orgs/{org}/users/{user_id}/media/media-resources/{id}/ | 
*AiAccountApi* | [**ai_account_orgs_credential_create**](docs/AiAccountApi.md#ai_account_orgs_credential_create) | **POST** /api/ai-account/orgs/{org}/credential/ | 
*AiAccountApi* | [**ai_account_orgs_credential_partial_update**](docs/AiAccountApi.md#ai_account_orgs_credential_partial_update) | **PATCH** /api/ai-account/orgs/{org}/credential/ | 
*AiAccountApi* | [**ai_account_orgs_credential_retrieve**](docs/AiAccountApi.md#ai_account_orgs_credential_retrieve) | **GET** /api/ai-account/orgs/{org}/credential/ | 
*AiAccountApi* | [**ai_account_orgs_integration_credential_create**](docs/AiAccountApi.md#ai_account_orgs_integration_credential_create) | **POST** /api/ai-account/orgs/{org}/integration-credential/ | 
*AiAccountApi* | [**ai_account_orgs_integration_credential_partial_update**](docs/AiAccountApi.md#ai_account_orgs_integration_credential_partial_update) | **PATCH** /api/ai-account/orgs/{org}/integration-credential/ | 
*AiAccountApi* | [**ai_account_orgs_integration_credential_retrieve**](docs/AiAccountApi.md#ai_account_orgs_integration_credential_retrieve) | **GET** /api/ai-account/orgs/{org}/integration-credential/ | 
*AiAccountApi* | [**ai_account_orgs_platform_metadata_create**](docs/AiAccountApi.md#ai_account_orgs_platform_metadata_create) | **POST** /api/ai-account/orgs/{org}/platform-metadata/ | 
*AiAccountApi* | [**ai_account_orgs_platform_metadata_list**](docs/AiAccountApi.md#ai_account_orgs_platform_metadata_list) | **GET** /api/ai-account/orgs/{org}/platform-metadata/ | 
*AiAccountApi* | [**ai_account_orgs_platform_metadata_update**](docs/AiAccountApi.md#ai_account_orgs_platform_metadata_update) | **PUT** /api/ai-account/orgs/{org}/platform-metadata/ | 
*AiAccountApi* | [**ai_account_orgs_tokens_list**](docs/AiAccountApi.md#ai_account_orgs_tokens_list) | **GET** /api/ai-account/orgs/{org}/tokens/ | 
*AiAccountApi* | [**ai_account_orgs_use_default_llm_key_create**](docs/AiAccountApi.md#ai_account_orgs_use_default_llm_key_create) | **POST** /api/ai-account/orgs/{org}/use-default-llm-key/ | 
*AiAccountApi* | [**ai_account_orgs_use_free_trial_create**](docs/AiAccountApi.md#ai_account_orgs_use_free_trial_create) | **POST** /api/ai-account/orgs/{org}/use-free-trial/ | 
*AiAccountApi* | [**ai_account_orgs_users_default_llm_key_usage_retrieve**](docs/AiAccountApi.md#ai_account_orgs_users_default_llm_key_usage_retrieve) | **GET** /api/ai-account/orgs/{org}/users/{user_id}/default-llm-key-usage | 
*AiAccountApi* | [**ai_account_orgs_users_free_trial_retrieve**](docs/AiAccountApi.md#ai_account_orgs_users_free_trial_retrieve) | **GET** /api/ai-account/orgs/{org}/users/{user_id}/free-trial | 
*AiAnalyticsApi* | [**ai_analytics_audience_orgs_active_users_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_audience_orgs_active_users_over_time_retrieve) | **GET** /api/ai-analytics/audience/orgs/{org}/active-users/over-time | 
*AiAnalyticsApi* | [**ai_analytics_audience_orgs_active_users_per_course_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_audience_orgs_active_users_per_course_retrieve) | **GET** /api/ai-analytics/audience/orgs/{org}/active-users/per-course | 
*AiAnalyticsApi* | [**ai_analytics_audience_orgs_active_users_users_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_audience_orgs_active_users_users_retrieve) | **GET** /api/ai-analytics/audience/orgs/{org}/active-users/users | 
*AiAnalyticsApi* | [**ai_analytics_audience_orgs_enrollments_courses_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_audience_orgs_enrollments_courses_over_time_retrieve) | **GET** /api/ai-analytics/audience/orgs/{org}/enrollments/courses/{course_id}/over-time | 
*AiAnalyticsApi* | [**ai_analytics_audience_orgs_enrollments_courses_users_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_audience_orgs_enrollments_courses_users_retrieve) | **GET** /api/ai-analytics/audience/orgs/{org}/enrollments/courses/{course_id}/users | 
*AiAnalyticsApi* | [**ai_analytics_audience_orgs_enrollments_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_audience_orgs_enrollments_over_time_retrieve) | **GET** /api/ai-analytics/audience/orgs/{org}/enrollments/over-time | 
*AiAnalyticsApi* | [**ai_analytics_audience_orgs_enrollments_per_course_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_audience_orgs_enrollments_per_course_retrieve) | **GET** /api/ai-analytics/audience/orgs/{org}/enrollments/per-course | 
*AiAnalyticsApi* | [**ai_analytics_audience_orgs_registered_users_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_audience_orgs_registered_users_over_time_retrieve) | **GET** /api/ai-analytics/audience/orgs/{org}/registered-users/over-time | 
*AiAnalyticsApi* | [**ai_analytics_audience_orgs_registered_users_per_course_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_audience_orgs_registered_users_per_course_retrieve) | **GET** /api/ai-analytics/audience/orgs/{org}/registered-users/per-course | 
*AiAnalyticsApi* | [**ai_analytics_audience_orgs_registered_users_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_audience_orgs_registered_users_retrieve) | **GET** /api/ai-analytics/audience/orgs/{org}/registered-users/ | 
*AiAnalyticsApi* | [**ai_analytics_costs_pertenant_list**](docs/AiAnalyticsApi.md#ai_analytics_costs_pertenant_list) | **GET** /api/ai-analytics/costs/pertenant/ | 
*AiAnalyticsApi* | [**ai_analytics_departments_orgs_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_departments_orgs_retrieve) | **GET** /api/ai-analytics/departments/orgs/{org}/ | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_activity_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_activity_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/activity | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_course_completion_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_course_completion_over_time_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/course_completion/over-time | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_course_completion_per_course_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_course_completion_per_course_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/course_completion/per-course | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_courses_time_average_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_courses_time_average_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/courses/{course_id}/time/average | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_courses_time_detail_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_courses_time_detail_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/courses/{course_id}/time/detail | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_courses_time_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_courses_time_over_time_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/courses/{course_id}/time/over-time | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_courses_time_users_detail_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_courses_time_users_detail_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/courses/{course_id}/time/users/{user_id}/detail | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_courses_time_users_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_courses_time_users_over_time_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/courses/{course_id}/time/users/{user_id}/over-time | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_courses_time_users_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_courses_time_users_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/courses/{course_id}/time/users | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_courses_videos_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_courses_videos_over_time_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/courses/{course_id}/videos/over-time | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_courses_videos_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_courses_videos_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/courses/{course_id}/videos/ | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_courses_videos_summary_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_courses_videos_summary_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/courses/{course_id}/videos/summary | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_courses_videos_users_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_courses_videos_users_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/courses/{course_id}/videos/users | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_time_average_perlearner_percourse_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_time_average_perlearner_percourse_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/time/average-perlearner-percourse | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_time_average_with_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_time_average_with_over_time_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/time/average-with-over-time | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_time_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_time_over_time_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/time/over-time | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_time_per_course_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_time_per_course_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/time/per-course | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_videos_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_videos_over_time_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/videos/over-time | 
*AiAnalyticsApi* | [**ai_analytics_engagement_orgs_videos_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_engagement_orgs_videos_retrieve) | **GET** /api/ai-analytics/engagement/orgs/{org}/videos/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_average_messages_per_session_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_average_messages_per_session_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/average-messages-per-session/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_chat_history_create**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_chat_history_create) | **POST** /api/ai-analytics/orgs/{org}/users/{user_id}/chat-history/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_chat_history_destroy**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_chat_history_destroy) | **DELETE** /api/ai-analytics/orgs/{org}/users/{user_id}/chat-history/{id}/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_chat_history_filter_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_chat_history_filter_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/chat-history-filter/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_chat_history_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_chat_history_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/chat-history/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_chat_history_partial_update**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_chat_history_partial_update) | **PATCH** /api/ai-analytics/orgs/{org}/users/{user_id}/chat-history/{id}/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_chat_history_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_chat_history_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/chat-history/{id}/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_chat_history_update**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_chat_history_update) | **PUT** /api/ai-analytics/orgs/{org}/users/{user_id}/chat-history/{id}/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_conversation_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_conversation_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/conversation/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_conversation_summary_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_conversation_summary_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/conversation-summary/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_costs_model_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_costs_model_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/costs/model/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_costs_permentor_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_costs_permentor_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/costs/permentor/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_costs_peruser_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_costs_peruser_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/costs/peruser/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_mentor_detail_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_mentor_detail_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/mentor-detail/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_mentor_summary_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_mentor_summary_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/mentor-summary/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_mentors_cost_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_mentors_cost_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/mentors/{mentor_unique_id}/cost/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_most_discussed_topics_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_most_discussed_topics_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/most-discussed-topics/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_overview_summary_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_overview_summary_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/overview-summary/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_rating_summary_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_rating_summary_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/rating-summary/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_registered_users_trend_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_registered_users_trend_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/registered-users-trend/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_sentiment_count_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_sentiment_count_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/sentiment-count/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_tenant_cost_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_tenant_cost_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/tenant-cost/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_top_students_by_chat_messages_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_top_students_by_chat_messages_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/top-students-by-chat-messages/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_topic_overview_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_topic_overview_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/topic-overview/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_topic_statistics_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_topic_statistics_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/topic-statistics/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_topics_summary_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_topics_summary_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/topics/summary/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_total_users_by_mentor_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_total_users_by_mentor_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/total-users-by-mentor/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_transcripts_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_transcripts_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/transcripts/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_usage_summary_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_usage_summary_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/usage-summary/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_user_cohorts_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_user_cohorts_over_time_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/user-cohorts-over-time/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_user_cost_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_user_cost_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/user-cost/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_user_feedback_list**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_user_feedback_list) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/user-feedback/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_user_metrics_pie_chart_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_user_metrics_pie_chart_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/user-metrics-pie-chart/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_user_metrics_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_user_metrics_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/user-metrics/ | 
*AiAnalyticsApi* | [**ai_analytics_orgs_users_user_sentiment_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_orgs_users_user_sentiment_retrieve) | **GET** /api/ai-analytics/orgs/{org}/users/{user_id}/user-sentiment/ | 
*AiAnalyticsApi* | [**ai_analytics_overview_orgs_active_users_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_overview_orgs_active_users_retrieve) | **GET** /api/ai-analytics/overview/orgs/{org}/active-users | 
*AiAnalyticsApi* | [**ai_analytics_overview_orgs_average_grade_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_overview_orgs_average_grade_retrieve) | **GET** /api/ai-analytics/overview/orgs/{org}/average-grade | 
*AiAnalyticsApi* | [**ai_analytics_overview_orgs_courses_completions_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_overview_orgs_courses_completions_retrieve) | **GET** /api/ai-analytics/overview/orgs/{org}/courses/completions | 
*AiAnalyticsApi* | [**ai_analytics_overview_orgs_learners_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_overview_orgs_learners_retrieve) | **GET** /api/ai-analytics/overview/orgs/{org}/learners | 
*AiAnalyticsApi* | [**ai_analytics_overview_orgs_most_active_courses_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_overview_orgs_most_active_courses_retrieve) | **GET** /api/ai-analytics/overview/orgs/{org}/most-active-courses | 
*AiAnalyticsApi* | [**ai_analytics_overview_orgs_registered_users_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_overview_orgs_registered_users_retrieve) | **GET** /api/ai-analytics/overview/orgs/{org}/registered-users | 
*AiAnalyticsApi* | [**ai_analytics_performance_orgs_courses_grading_average_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_performance_orgs_courses_grading_average_retrieve) | **GET** /api/ai-analytics/performance/orgs/{org}/courses/{course_id}/grading/average | 
*AiAnalyticsApi* | [**ai_analytics_performance_orgs_courses_grading_average_with_cutoff_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_performance_orgs_courses_grading_average_with_cutoff_retrieve) | **GET** /api/ai-analytics/performance/orgs/{org}/courses/{course_id}/grading/average-with-cutoff | 
*AiAnalyticsApi* | [**ai_analytics_performance_orgs_courses_grading_detail_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_performance_orgs_courses_grading_detail_retrieve) | **GET** /api/ai-analytics/performance/orgs/{org}/courses/{course_id}/grading/detail | 
*AiAnalyticsApi* | [**ai_analytics_performance_orgs_courses_grading_per_learner_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_performance_orgs_courses_grading_per_learner_retrieve) | **GET** /api/ai-analytics/performance/orgs/{org}/courses/{course_id}/grading/per-learner | 
*AiAnalyticsApi* | [**ai_analytics_performance_orgs_courses_grading_summary_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_performance_orgs_courses_grading_summary_retrieve) | **GET** /api/ai-analytics/performance/orgs/{org}/courses/{course_id}/grading/summary | 
*AiAnalyticsApi* | [**ai_analytics_performance_orgs_grading_average_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_performance_orgs_grading_average_retrieve) | **GET** /api/ai-analytics/performance/orgs/{org}/grading/average | 
*AiAnalyticsApi* | [**ai_analytics_performance_orgs_grading_per_course_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_performance_orgs_grading_per_course_retrieve) | **GET** /api/ai-analytics/performance/orgs/{org}/grading/per-course | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_learners_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_learners_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/learners | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_activity_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_activity_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/activity/ | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_courses_grading_cutoffs_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_courses_grading_cutoffs_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/grading/cutoffs | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_courses_grading_detail_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_courses_grading_detail_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/grading/detail | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_courses_grading_summary_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_courses_grading_summary_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/grading/summary | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_courses_overview_engagement_index_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_courses_overview_engagement_index_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/overview/engagement-index | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_courses_overview_grade_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_courses_overview_grade_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/overview/grade | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_courses_overview_performance_index_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_courses_overview_performance_index_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/overview/performance-index | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_courses_overview_time_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_courses_overview_time_over_time_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/overview/time/over-time | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_courses_videos_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_courses_videos_over_time_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/videos/over-time | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_courses_videos_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_courses_videos_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/videos | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_grades_per_course_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_grades_per_course_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/grades/per-course | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_info_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_info_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/info | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_last_access_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_last_access_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/last-access | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_overview_engagement_index_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_overview_engagement_index_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/overview/engagement-index | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_overview_grades_average_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_overview_grades_average_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/overview/grades/average | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_overview_performance_index_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_overview_performance_index_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/overview/performance-index | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_overview_time_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_overview_time_over_time_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/overview/time/over-time | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_videos_over_time_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_videos_over_time_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/videos/over-time | 
*AiAnalyticsApi* | [**ai_analytics_perlearner_orgs_users_videos_per_course_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_perlearner_orgs_users_videos_per_course_retrieve) | **GET** /api/ai-analytics/perlearner/orgs/{org}/users/{user_id}/videos/per-course | 
*AiAnalyticsApi* | [**ai_analytics_user_groups_orgs_retrieve**](docs/AiAnalyticsApi.md#ai_analytics_user_groups_orgs_retrieve) | **GET** /api/ai-analytics/user-groups/orgs/{org}/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_commands_create**](docs/AiBotApi.md#ai_bot_v1_bots_bot_commands_create) | **POST** /api/ai-bot/v1/bots/{org}/bot-commands/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_commands_destroy**](docs/AiBotApi.md#ai_bot_v1_bots_bot_commands_destroy) | **DELETE** /api/ai-bot/v1/bots/{org}/bot-commands/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_commands_list**](docs/AiBotApi.md#ai_bot_v1_bots_bot_commands_list) | **GET** /api/ai-bot/v1/bots/{org}/bot-commands/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_commands_partial_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_commands_partial_update) | **PATCH** /api/ai-bot/v1/bots/{org}/bot-commands/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_commands_retrieve**](docs/AiBotApi.md#ai_bot_v1_bots_bot_commands_retrieve) | **GET** /api/ai-bot/v1/bots/{org}/bot-commands/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_commands_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_commands_update) | **PUT** /api/ai-bot/v1/bots/{org}/bot-commands/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_discord_partial_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_discord_partial_update) | **PATCH** /api/ai-bot/v1/bots/{org}/bot/{id}/config/discord/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_discord_retrieve**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_discord_retrieve) | **GET** /api/ai-bot/v1/bots/{org}/bot/{id}/config/discord/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_slack_retrieve**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_slack_retrieve) | **GET** /api/ai-bot/v1/bots/{org}/bot/{id}/config/slack/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_slack_update_create**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_slack_update_create) | **POST** /api/ai-bot/v1/bots/{org}/bot/{id}/config/slack/update/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_slack_update_partial_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_slack_update_partial_update) | **PATCH** /api/ai-bot/v1/bots/{org}/bot/{id}/config/slack/update/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_slack_update_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_slack_update_update) | **PUT** /api/ai-bot/v1/bots/{org}/bot/{id}/config/slack/update/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_teams_retrieve**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_teams_retrieve) | **GET** /api/ai-bot/v1/bots/{org}/bot/{id}/config/teams/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_teams_update_create**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_teams_update_create) | **POST** /api/ai-bot/v1/bots/{org}/bot/{id}/config/teams/update/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_teams_update_partial_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_teams_update_partial_update) | **PATCH** /api/ai-bot/v1/bots/{org}/bot/{id}/config/teams/update/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_teams_update_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_teams_update_update) | **PUT** /api/ai-bot/v1/bots/{org}/bot/{id}/config/teams/update/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_webex_partial_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_webex_partial_update) | **PATCH** /api/ai-bot/v1/bots/{org}/bot/{id}/config/webex/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_webex_retrieve**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_webex_retrieve) | **GET** /api/ai-bot/v1/bots/{org}/bot/{id}/config/webex/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_config_whatsapp_retrieve**](docs/AiBotApi.md#ai_bot_v1_bots_bot_config_whatsapp_retrieve) | **GET** /api/ai-bot/v1/bots/{org}/bot/{id}/config/whatsapp/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_create**](docs/AiBotApi.md#ai_bot_v1_bots_bot_create) | **POST** /api/ai-bot/v1/bots/{org}/bot/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_destroy**](docs/AiBotApi.md#ai_bot_v1_bots_bot_destroy) | **DELETE** /api/ai-bot/v1/bots/{org}/bot/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_list**](docs/AiBotApi.md#ai_bot_v1_bots_bot_list) | **GET** /api/ai-bot/v1/bots/{org}/bot/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_partial_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_partial_update) | **PATCH** /api/ai-bot/v1/bots/{org}/bot/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_retrieve**](docs/AiBotApi.md#ai_bot_v1_bots_bot_retrieve) | **GET** /api/ai-bot/v1/bots/{org}/bot/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_update) | **PUT** /api/ai-bot/v1/bots/{org}/bot/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_whatsapp_config_partial_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_whatsapp_config_partial_update) | **PATCH** /api/ai-bot/v1/bots/{org}/bot/{id}/whatsapp-config/ | 
*AiBotApi* | [**ai_bot_v1_bots_bot_whatsapp_config_update**](docs/AiBotApi.md#ai_bot_v1_bots_bot_whatsapp_config_update) | **PUT** /api/ai-bot/v1/bots/{org}/bot/{id}/whatsapp-config/ | 
*AiBotApi* | [**ai_bot_v1_bots_discord_user_config_create**](docs/AiBotApi.md#ai_bot_v1_bots_discord_user_config_create) | **POST** /api/ai-bot/v1/bots/{org}/discord-user-config/ | 
*AiBotApi* | [**ai_bot_v1_bots_discord_user_config_destroy**](docs/AiBotApi.md#ai_bot_v1_bots_discord_user_config_destroy) | **DELETE** /api/ai-bot/v1/bots/{org}/discord-user-config/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_discord_user_config_list**](docs/AiBotApi.md#ai_bot_v1_bots_discord_user_config_list) | **GET** /api/ai-bot/v1/bots/{org}/discord-user-config/ | 
*AiBotApi* | [**ai_bot_v1_bots_discord_user_config_partial_update**](docs/AiBotApi.md#ai_bot_v1_bots_discord_user_config_partial_update) | **PATCH** /api/ai-bot/v1/bots/{org}/discord-user-config/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_discord_user_config_retrieve**](docs/AiBotApi.md#ai_bot_v1_bots_discord_user_config_retrieve) | **GET** /api/ai-bot/v1/bots/{org}/discord-user-config/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_discord_user_config_update**](docs/AiBotApi.md#ai_bot_v1_bots_discord_user_config_update) | **PUT** /api/ai-bot/v1/bots/{org}/discord-user-config/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_slack_user_config_create**](docs/AiBotApi.md#ai_bot_v1_bots_slack_user_config_create) | **POST** /api/ai-bot/v1/bots/{org}/slack-user-config/ | 
*AiBotApi* | [**ai_bot_v1_bots_slack_user_config_destroy**](docs/AiBotApi.md#ai_bot_v1_bots_slack_user_config_destroy) | **DELETE** /api/ai-bot/v1/bots/{org}/slack-user-config/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_slack_user_config_list**](docs/AiBotApi.md#ai_bot_v1_bots_slack_user_config_list) | **GET** /api/ai-bot/v1/bots/{org}/slack-user-config/ | 
*AiBotApi* | [**ai_bot_v1_bots_slack_user_config_partial_update**](docs/AiBotApi.md#ai_bot_v1_bots_slack_user_config_partial_update) | **PATCH** /api/ai-bot/v1/bots/{org}/slack-user-config/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_slack_user_config_retrieve**](docs/AiBotApi.md#ai_bot_v1_bots_slack_user_config_retrieve) | **GET** /api/ai-bot/v1/bots/{org}/slack-user-config/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_slack_user_config_update**](docs/AiBotApi.md#ai_bot_v1_bots_slack_user_config_update) | **PUT** /api/ai-bot/v1/bots/{org}/slack-user-config/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_webhooks_discord_create**](docs/AiBotApi.md#ai_bot_v1_bots_webhooks_discord_create) | **POST** /api/ai-bot/v1/bots/webhooks/{org}/discord/{name}/ | 
*AiBotApi* | [**ai_bot_v1_bots_webhooks_slack_create**](docs/AiBotApi.md#ai_bot_v1_bots_webhooks_slack_create) | **POST** /api/ai-bot/v1/bots/webhooks/{org}/slack/{name}/ | 
*AiBotApi* | [**ai_bot_v1_bots_webhooks_teams_create**](docs/AiBotApi.md#ai_bot_v1_bots_webhooks_teams_create) | **POST** /api/ai-bot/v1/bots/webhooks/{org}/teams/{name}/ | 
*AiBotApi* | [**ai_bot_v1_bots_webhooks_webex_create**](docs/AiBotApi.md#ai_bot_v1_bots_webhooks_webex_create) | **POST** /api/ai-bot/v1/bots/webhooks/{org}/webex/{name}/ | 
*AiBotApi* | [**ai_bot_v1_bots_webhooks_whatsapp_create**](docs/AiBotApi.md#ai_bot_v1_bots_webhooks_whatsapp_create) | **POST** /api/ai-bot/v1/bots/webhooks/{org}/whatsapp/{name}/ | 
*AiBotApi* | [**ai_bot_v1_bots_webhooks_whatsapp_retrieve**](docs/AiBotApi.md#ai_bot_v1_bots_webhooks_whatsapp_retrieve) | **GET** /api/ai-bot/v1/bots/webhooks/{org}/whatsapp/{name}/ | 
*AiBotApi* | [**ai_bot_v1_bots_whatsapp_user_config_create**](docs/AiBotApi.md#ai_bot_v1_bots_whatsapp_user_config_create) | **POST** /api/ai-bot/v1/bots/{org}/whatsapp-user-config/ | 
*AiBotApi* | [**ai_bot_v1_bots_whatsapp_user_config_destroy**](docs/AiBotApi.md#ai_bot_v1_bots_whatsapp_user_config_destroy) | **DELETE** /api/ai-bot/v1/bots/{org}/whatsapp-user-config/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_whatsapp_user_config_list**](docs/AiBotApi.md#ai_bot_v1_bots_whatsapp_user_config_list) | **GET** /api/ai-bot/v1/bots/{org}/whatsapp-user-config/ | 
*AiBotApi* | [**ai_bot_v1_bots_whatsapp_user_config_partial_update**](docs/AiBotApi.md#ai_bot_v1_bots_whatsapp_user_config_partial_update) | **PATCH** /api/ai-bot/v1/bots/{org}/whatsapp-user-config/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_whatsapp_user_config_retrieve**](docs/AiBotApi.md#ai_bot_v1_bots_whatsapp_user_config_retrieve) | **GET** /api/ai-bot/v1/bots/{org}/whatsapp-user-config/{id}/ | 
*AiBotApi* | [**ai_bot_v1_bots_whatsapp_user_config_update**](docs/AiBotApi.md#ai_bot_v1_bots_whatsapp_user_config_update) | **PUT** /api/ai-bot/v1/bots/{org}/whatsapp-user-config/{id}/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_datasets_create**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_datasets_create) | **POST** /api/ai-finetuning/v1/org/{org}/user/{username}/datasets/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_datasets_destroy**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_datasets_destroy) | **DELETE** /api/ai-finetuning/v1/org/{org}/user/{username}/datasets/{id}/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_datasets_list**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_datasets_list) | **GET** /api/ai-finetuning/v1/org/{org}/user/{username}/datasets/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_datasets_partial_update**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_datasets_partial_update) | **PATCH** /api/ai-finetuning/v1/org/{org}/user/{username}/datasets/{id}/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_datasets_retrieve**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_datasets_retrieve) | **GET** /api/ai-finetuning/v1/org/{org}/user/{username}/datasets/{id}/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_datasets_update**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_datasets_update) | **PUT** /api/ai-finetuning/v1/org/{org}/user/{username}/datasets/{id}/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_trainings_create**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_trainings_create) | **POST** /api/ai-finetuning/v1/org/{org}/user/{username}/trainings/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_trainings_destroy**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_trainings_destroy) | **DELETE** /api/ai-finetuning/v1/org/{org}/user/{username}/trainings/{id}/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_trainings_finetuned_models_retrieve**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_trainings_finetuned_models_retrieve) | **GET** /api/ai-finetuning/v1/org/{org}/user/{username}/trainings/finetuned-models/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_trainings_list**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_trainings_list) | **GET** /api/ai-finetuning/v1/org/{org}/user/{username}/trainings/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_trainings_partial_update**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_trainings_partial_update) | **PATCH** /api/ai-finetuning/v1/org/{org}/user/{username}/trainings/{id}/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_trainings_retrieve**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_trainings_retrieve) | **GET** /api/ai-finetuning/v1/org/{org}/user/{username}/trainings/{id}/ | 
*AiFinetuningApi* | [**ai_finetuning_v1_org_user_trainings_update**](docs/AiFinetuningApi.md#ai_finetuning_v1_org_user_trainings_update) | **PUT** /api/ai-finetuning/v1/org/{org}/user/{username}/trainings/{id}/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_destroy**](docs/AiIndexApi.md#ai_index_orgs_users_documents_destroy) | **DELETE** /api/ai-index/orgs/{org}/users/{user_id}/documents/{document_id}/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_graph_train_create**](docs/AiIndexApi.md#ai_index_orgs_users_documents_graph_train_create) | **POST** /api/ai-index/orgs/{org}/users/{user_id}/documents/graph-train/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_pathways_list**](docs/AiIndexApi.md#ai_index_orgs_users_documents_pathways_list) | **GET** /api/ai-index/orgs/{org}/users/{user_id}/documents/pathways/{pathway}/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_retrieve**](docs/AiIndexApi.md#ai_index_orgs_users_documents_retrieve) | **GET** /api/ai-index/orgs/{org}/users/{user_id}/documents/{document_id}/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_search_create**](docs/AiIndexApi.md#ai_index_orgs_users_documents_search_create) | **POST** /api/ai-index/orgs/{org}/users/{user_id}/documents/search/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_settings_create**](docs/AiIndexApi.md#ai_index_orgs_users_documents_settings_create) | **POST** /api/ai-index/orgs/{org}/users/{user_id}/documents/{document_id}/settings/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_settings_retrieve**](docs/AiIndexApi.md#ai_index_orgs_users_documents_settings_retrieve) | **GET** /api/ai-index/orgs/{org}/users/{user_id}/documents/{document_id}/settings/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_sources_create**](docs/AiIndexApi.md#ai_index_orgs_users_documents_sources_create) | **POST** /api/ai-index/orgs/{org}/users/{user_id}/documents/sources/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_tasks_retrieve**](docs/AiIndexApi.md#ai_index_orgs_users_documents_tasks_retrieve) | **GET** /api/ai-index/orgs/{org}/users/{user_id}/documents/tasks/{task_id}/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_train_create**](docs/AiIndexApi.md#ai_index_orgs_users_documents_train_create) | **POST** /api/ai-index/orgs/{org}/users/{user_id}/documents/train/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_train_retriever_create**](docs/AiIndexApi.md#ai_index_orgs_users_documents_train_retriever_create) | **POST** /api/ai-index/orgs/{org}/users/{user_id}/documents/train/retriever/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_train_sessions_create**](docs/AiIndexApi.md#ai_index_orgs_users_documents_train_sessions_create) | **POST** /api/ai-index/orgs/{org}/users/{user_id}/documents/train/sessions/{session_id}/ | 
*AiIndexApi* | [**ai_index_orgs_users_documents_update**](docs/AiIndexApi.md#ai_index_orgs_users_documents_update) | **PUT** /api/ai-index/orgs/{org}/users/{user_id}/documents/{document_id}/ | 
*AiIndexApi* | [**ai_index_orgs_users_resource_data_scrapped_list**](docs/AiIndexApi.md#ai_index_orgs_users_resource_data_scrapped_list) | **GET** /api/ai-index/orgs/{org}/users/{user_id}/resource/data/scrapped/ | 
*AiIndexApi* | [**ai_index_orgs_users_resource_data_scrapped_retrieve**](docs/AiIndexApi.md#ai_index_orgs_users_resource_data_scrapped_retrieve) | **GET** /api/ai-index/orgs/{org}/users/{user_id}/resource/{resource_id}/data/scrapped/ | 
*AiIndexApi* | [**ai_index_webhook_scan_create**](docs/AiIndexApi.md#ai_index_webhook_scan_create) | **POST** /api/ai-index/webhook/scan/ | 
*AiMarketingApi* | [**ai_marketing_orgs_users_heygen_videos_create**](docs/AiMarketingApi.md#ai_marketing_orgs_users_heygen_videos_create) | **POST** /api/ai-marketing/orgs/{org}/users/{user_id}/heygen-videos/ | 
*AiMarketingApi* | [**ai_marketing_orgs_users_heygen_videos_list**](docs/AiMarketingApi.md#ai_marketing_orgs_users_heygen_videos_list) | **GET** /api/ai-marketing/orgs/{org}/users/{user_id}/heygen-videos/ | 
*AiMarketingApi* | [**ai_marketing_orgs_users_heygen_videos_retrieve**](docs/AiMarketingApi.md#ai_marketing_orgs_users_heygen_videos_retrieve) | **GET** /api/ai-marketing/orgs/{org}/users/{user_id}/heygen-videos/{name}/ | 
*AiMediaApi* | [**ai_media_orgs_users_heygen_templates_create**](docs/AiMediaApi.md#ai_media_orgs_users_heygen_templates_create) | **POST** /api/ai-media/orgs/{org}/users/{user_id}/heygen/templates/ | 
*AiMediaApi* | [**ai_media_orgs_users_heygen_templates_destroy**](docs/AiMediaApi.md#ai_media_orgs_users_heygen_templates_destroy) | **DELETE** /api/ai-media/orgs/{org}/users/{user_id}/heygen/templates/{template_name}/ | 
*AiMediaApi* | [**ai_media_orgs_users_heygen_templates_list**](docs/AiMediaApi.md#ai_media_orgs_users_heygen_templates_list) | **GET** /api/ai-media/orgs/{org}/users/{user_id}/heygen/templates/ | 
*AiMediaApi* | [**ai_media_orgs_users_heygen_video_captions_create**](docs/AiMediaApi.md#ai_media_orgs_users_heygen_video_captions_create) | **POST** /api/ai-media/orgs/{org}/users/{user_id}/heygen/video-captions/{heygen_marketing_video_id}/ | 
*AiMediaApi* | [**ai_media_orgs_users_heygen_video_captions_retrieve**](docs/AiMediaApi.md#ai_media_orgs_users_heygen_video_captions_retrieve) | **GET** /api/ai-media/orgs/{org}/users/{user_id}/heygen/video-captions/{heygen_marketing_video_id}/ | 
*AiMediaApi* | [**ai_media_orgs_users_heygen_video_download_retrieve**](docs/AiMediaApi.md#ai_media_orgs_users_heygen_video_download_retrieve) | **GET** /api/ai-media/orgs/{org}/users/{user_id}/heygen/video-download/{heygen_marketing_video_id}/ | 
*AiMediaApi* | [**ai_media_orgs_users_heygen_videos_create**](docs/AiMediaApi.md#ai_media_orgs_users_heygen_videos_create) | **POST** /api/ai-media/orgs/{org}/users/{user_id}/heygen/videos/ | 
*AiMediaApi* | [**ai_media_orgs_users_heygen_videos_destroy**](docs/AiMediaApi.md#ai_media_orgs_users_heygen_videos_destroy) | **DELETE** /api/ai-media/orgs/{org}/users/{user_id}/heygen/videos/{heygen_marketing_video_id}/ | 
*AiMediaApi* | [**ai_media_orgs_users_heygen_videos_list**](docs/AiMediaApi.md#ai_media_orgs_users_heygen_videos_list) | **GET** /api/ai-media/orgs/{org}/users/{user_id}/heygen/videos/ | 
*AiMediaApi* | [**ai_media_orgs_users_heygen_videos_retrieve**](docs/AiMediaApi.md#ai_media_orgs_users_heygen_videos_retrieve) | **GET** /api/ai-media/orgs/{org}/users/{user_id}/heygen/videos/{heygen_marketing_video_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_all_triggers_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_all_triggers_retrieve) | **GET** /api/ai-mentor/orgs/{org}/all-triggers/ | 
*AiMentorApi* | [**ai_mentor_orgs_mentors_email_inbox_list**](docs/AiMentorApi.md#ai_mentor_orgs_mentors_email_inbox_list) | **GET** /api/ai-mentor/orgs/{org}/mentors/{mentor}/email-inbox/ | 
*AiMentorApi* | [**ai_mentor_orgs_mentors_email_inbox_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_mentors_email_inbox_retrieve) | **GET** /api/ai-mentor/orgs/{org}/mentors/{mentor}/email-inbox/{email_prompt_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_mentors_email_inbox_summary_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_mentors_email_inbox_summary_retrieve) | **GET** /api/ai-mentor/orgs/{org}/mentors/{mentor}/email-inbox-summary/ | 
*AiMentorApi* | [**ai_mentor_orgs_mentors_link_course_create**](docs/AiMentorApi.md#ai_mentor_orgs_mentors_link_course_create) | **POST** /api/ai-mentor/orgs/{org}/mentors/{mentor}/link-course/ | 
*AiMentorApi* | [**ai_mentor_orgs_mentors_link_course_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_mentors_link_course_retrieve) | **GET** /api/ai-mentor/orgs/{org}/mentors/{mentor}/link-course/ | 
*AiMentorApi* | [**ai_mentor_orgs_metadata_create**](docs/AiMentorApi.md#ai_mentor_orgs_metadata_create) | **POST** /api/ai-mentor/orgs/{org}/metadata/ | 
*AiMentorApi* | [**ai_mentor_orgs_quiz_customizer_create**](docs/AiMentorApi.md#ai_mentor_orgs_quiz_customizer_create) | **POST** /api/ai-mentor/orgs/{org}/quiz-customizer/ | 
*AiMentorApi* | [**ai_mentor_orgs_quiz_customizer_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_quiz_customizer_retrieve) | **GET** /api/ai-mentor/orgs/{org}/quiz-customizer/ | 
*AiMentorApi* | [**ai_mentor_orgs_sessions_create**](docs/AiMentorApi.md#ai_mentor_orgs_sessions_create) | **POST** /api/ai-mentor/orgs/{org}/sessions/ | 
*AiMentorApi* | [**ai_mentor_orgs_trigger_create**](docs/AiMentorApi.md#ai_mentor_orgs_trigger_create) | **POST** /api/ai-mentor/orgs/{org}/trigger/ | 
*AiMentorApi* | [**ai_mentor_orgs_trigger_deletion_create**](docs/AiMentorApi.md#ai_mentor_orgs_trigger_deletion_create) | **POST** /api/ai-mentor/orgs/{org}/trigger/{slug}/deletion/ | 
*AiMentorApi* | [**ai_mentor_orgs_trigger_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_trigger_retrieve) | **GET** /api/ai-mentor/orgs/{org}/trigger/{slug}/ | 
*AiMentorApi* | [**ai_mentor_orgs_trigger_templates_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_trigger_templates_retrieve) | **GET** /api/ai-mentor/orgs/{org}/trigger-templates/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_ai_generated_images_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_ai_generated_images_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/ai-generated-images/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_ai_generated_images_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_ai_generated_images_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/ai-generated-images/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_ai_generated_images_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_ai_generated_images_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/ai-generated-images/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_ai_user_profile_memory_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_ai_user_profile_memory_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/ai-user-profile-memory/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_ai_user_profile_memory_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_ai_user_profile_memory_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/ai-user-profile-memory/{tag}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_ai_user_profile_memory_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_ai_user_profile_memory_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/ai-user-profile-memory/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_assumed_knowledge_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_assumed_knowledge_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/assumed-knowledge/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_assumed_knowledge_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_assumed_knowledge_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/assumed-knowledge/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_audio_to_text_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_audio_to_text_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/audio-to-text/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_available_template_mentors_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_available_template_mentors_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/available-template-mentors/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_call_configurations_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_call_configurations_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/call-configurations/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_call_configurations_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_call_configurations_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/call-configurations/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_call_configurations_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_call_configurations_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/call-configurations/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_call_configurations_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_call_configurations_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/call-configurations/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_call_configurations_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_call_configurations_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/call-configurations/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_category_groups_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_category_groups_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/category-groups/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_category_groups_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_category_groups_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/category-groups/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_category_groups_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_category_groups_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/category-groups/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_category_groups_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_category_groups_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/category-groups/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_category_groups_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_category_groups_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/category-groups/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_category_groups_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_category_groups_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/category-groups/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_clean_vector_results_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_clean_vector_results_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/clean-vector-results/{session_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_clean_vector_results_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_clean_vector_results_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/clean-vector-results/{session_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_clear_chathistory_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_clear_chathistory_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/clear-chathistory | Delete User Chat History
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_component_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_component_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/component/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_component_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_component_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/component/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_component_draft_content_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_component_draft_content_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/component/{id}/draft-content/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_component_draft_content_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_component_draft_content_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/component/{id}/draft-content/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_component_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_component_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/component/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_component_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_component_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/component/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_component_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_component_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/component/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_component_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_component_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/component/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_course_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_course_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/course/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_course_draft_content_for_all_units_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_course_draft_content_for_all_units_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/course/{id}/draft-content-for-all-units/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_course_full_structure_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_course_full_structure_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/course/{id}/full-structure/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_course_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_course_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/course/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_course_load_from_edx_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_course_load_from_edx_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/course/{id}/load-from-edx/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_course_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_course_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/course/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_course_sync_to_edx_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_course_sync_to_edx_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/course/{id}/sync-to-edx/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_files_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_files_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/files/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_files_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_files_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/files/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_files_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_files_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/files/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_files_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_files_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/files/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_files_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_files_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/files/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_files_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_files_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/files/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_section_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_section_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/section/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_section_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_section_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/section/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_section_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_section_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/section/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_section_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_section_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/section/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_section_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_section_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/section/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_section_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_section_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/section/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_subsection_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_subsection_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/subsection/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_subsection_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_subsection_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/subsection/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_subsection_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_subsection_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/subsection/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_subsection_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_subsection_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/subsection/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_subsection_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_subsection_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/subsection/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_subsection_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_subsection_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/subsection/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_task_files_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_task_files_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-task-files/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_task_files_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_task_files_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-task-files/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_task_files_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_task_files_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-task-files/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_task_files_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_task_files_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-task-files/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_task_files_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_task_files_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-task-files/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_task_files_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_task_files_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-task-files/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_cancel_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_cancel_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-tasks/{id}/cancel/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_cancel_retrieve2**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_cancel_retrieve2) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/tasks/{id}/cancel/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-tasks/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_create2**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_create2) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/tasks/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_create_course_outline_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_create_course_outline_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-tasks/{id}/create-course-outline/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_create_course_outline_create2**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_create_course_outline_create2) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/tasks/{id}/create-course-outline/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_create_course_outline_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_create_course_outline_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-tasks/{id}/create-course-outline/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_create_course_outline_retrieve2**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_create_course_outline_retrieve2) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/tasks/{id}/create-course-outline/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-tasks/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_destroy2**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_destroy2) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/tasks/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-tasks/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_list2**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_list2) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/tasks/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-tasks/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_retrieve2**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_retrieve2) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/tasks/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_start_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_start_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation-tasks/{id}/start/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_tasks_start_retrieve2**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_tasks_start_retrieve2) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/tasks/{id}/start/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_unit_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_unit_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/unit/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_unit_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_unit_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/unit/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_unit_draft_content_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_unit_draft_content_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/unit/{id}/draft-content/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_unit_draft_content_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_unit_draft_content_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/unit/{id}/draft-content/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_unit_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_unit_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/unit/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_unit_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_unit_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/unit/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_unit_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_unit_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/unit/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_course_creation_unit_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_course_creation_unit_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/course-creation/unit/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_create_mentor_wizard_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_create_mentor_wizard_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/create-mentor-wizard/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_custom_instruction_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_custom_instruction_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/custom-instruction/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_custom_instruction_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_custom_instruction_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/custom-instruction/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_custom_instruction_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_custom_instruction_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/custom-instruction/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/{name}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_downloads_tasks_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_downloads_tasks_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/downloads/tasks/{task_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_edx_memory_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_edx_memory_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/edx-memory/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_edx_memory_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_edx_memory_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/edx-memory/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_edx_memory_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_edx_memory_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/edx-memory/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_elevenlabs_voice_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_elevenlabs_voice_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/elevenlabs-voice/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_elevenlabs_voice_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_elevenlabs_voice_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/elevenlabs-voice/{voice_name}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_elevenlabs_voice_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_elevenlabs_voice_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/elevenlabs-voice/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_export_chathistory_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_export_chathistory_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/export-chathistory/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_free_usage_count_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_free_usage_count_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/free-usage-count | 
*AiMentorApi* | [**ai_mentor_orgs_users_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mcp_servers_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mcp_servers_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mcp-servers/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mcp_servers_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_mcp_servers_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/mcp-servers/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mcp_servers_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_mcp_servers_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mcp-servers/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mcp_servers_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_mcp_servers_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/mcp-servers/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mcp_servers_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mcp_servers_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mcp-servers/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mcp_servers_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_mcp_servers_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/mcp-servers/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_audience_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_audience_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor/audience/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_audience_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_audience_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor/audience/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_audience_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_audience_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor/audience/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_categories_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_categories_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor/categories/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_categories_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_categories_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor/categories/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_categories_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_categories_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor/categories/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_feedback_create_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_feedback_create_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor-feedback/create/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_feedback_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_feedback_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor-feedback/{feedback_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_feedback_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_feedback_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor-feedback/{feedback_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_from_template_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_from_template_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor-from-template/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_llms_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_llms_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor-llms/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_seed_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_seed_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor/seed/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_tools_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_tools_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor-tools/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentor_with_settings_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentor_with_settings_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentor-with-settings/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_available_tools_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_available_tools_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/available-tools/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_create_call_credentials_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_create_call_credentials_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/create-call-credentials/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_current_memory_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_current_memory_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/current-memory/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_current_memory_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_current_memory_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/current-memory/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_custom_voice_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_custom_voice_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/custom-voice/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_custom_voice_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_custom_voice_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/custom-voice/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_custom_voice_tts_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_custom_voice_tts_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/custom-voice-tts/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_edit_scenarios_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_edit_scenarios_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/edit-scenarios/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_fork_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_fork_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/fork/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_historical_memory_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_historical_memory_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/historical-memory/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_memory_progress_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_memory_progress_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/memory-progress/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_memory_settings_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_memory_settings_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/memory-settings/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_memory_settings_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_memory_settings_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/memory-settings/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_mentor_eval_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_mentor_eval_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/mentor-eval/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_mentor_eval_execution_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_mentor_eval_execution_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/mentor-eval-execution/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_mentor_eval_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_mentor_eval_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/mentor-eval/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_public_settings_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_public_settings_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/public-settings/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_reports_mentor_eval_report_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_reports_mentor_eval_report_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/reports/{report_id}/mentor-eval-report/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_scenarios_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_scenarios_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/scenarios/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_settings_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_settings_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/settings/ | Retrieve Mentor Settings
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_settings_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_settings_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/settings/ | Update Mentor Settings
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_spaced_repetition_question_stats_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_spaced_repetition_question_stats_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/spaced-repetition-question-stats/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_spaced_repetition_recommended_paths_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_spaced_repetition_recommended_paths_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/spaced-repetition-recommended-paths/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_spaced_repetition_recommended_paths_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_spaced_repetition_recommended_paths_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/spaced-repetition-recommended-paths/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_star_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_star_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/star/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_star_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_star_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/star/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_mentors_unstar_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_mentors_unstar_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/mentors/{mentor}/unstar/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_metadata_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_metadata_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/metadata | 
*AiMentorApi* | [**ai_mentor_orgs_users_moderation_logs_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_moderation_logs_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/moderation-logs/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_moderation_logs_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_moderation_logs_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/moderation-logs/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_moderation_logs_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_moderation_logs_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/moderation-logs/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/{name}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_periodic_agent_logs_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_periodic_agent_logs_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/periodic-agent-logs/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_periodic_agent_logs_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_periodic_agent_logs_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/periodic-agent-logs/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_periodic_agents_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_periodic_agents_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/periodic-agents/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_periodic_agents_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_periodic_agents_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/periodic-agents/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_periodic_agents_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_periodic_agents_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/periodic-agents/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_periodic_agents_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_periodic_agents_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/periodic-agents/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_periodic_agents_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_periodic_agents_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/periodic-agents/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_periodic_agents_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_periodic_agents_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/periodic-agents/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_pin_message_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_pin_message_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/pin-message/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_pin_message_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_pin_message_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/pin-message/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_pin_message_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_pin_message_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/pin-message/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_planned_jobs_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_planned_jobs_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/planned-jobs/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_planned_jobs_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_planned_jobs_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/planned-jobs/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_playwright_scripts_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_playwright_scripts_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/playwright-scripts/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_playwright_scripts_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_playwright_scripts_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/playwright-scripts/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_playwright_scripts_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_playwright_scripts_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/playwright-scripts/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_playwright_scripts_partial_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_playwright_scripts_partial_update) | **PATCH** /api/ai-mentor/orgs/{org}/users/{user_id}/playwright-scripts/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_playwright_scripts_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_playwright_scripts_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/playwright-scripts/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_playwright_scripts_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_playwright_scripts_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/playwright-scripts/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_predictive_analytics_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_predictive_analytics_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/predictive-analytics/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_recent_messages_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_recent_messages_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/recent-messages/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_recently_accessed_mentors_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_recently_accessed_mentors_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/recently-accessed-mentors/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_recommend_courses_block_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_recommend_courses_block_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/recommend-courses-block/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_recommend_courses_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_recommend_courses_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/recommend-courses/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_resources_web_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_resources_web_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/resources/web/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/{name}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_safety_logs_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_safety_logs_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/safety-logs/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_safety_logs_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_safety_logs_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/safety-logs/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_safety_logs_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_safety_logs_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/safety-logs/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_session_detail_mentors_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_session_detail_mentors_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/session-detail/mentors/{mentor}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_sessionid_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_sessionid_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/sessionid/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_sessions_browser_screenshot_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_sessions_browser_screenshot_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/sessions/{session_id}/browser-screenshot/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_sessions_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_sessions_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/sessions/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_sessions_destroy**](docs/AiMentorApi.md#ai_mentor_orgs_users_sessions_destroy) | **DELETE** /api/ai-mentor/orgs/{org}/users/{user_id}/sessions/{session_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_sessions_download_session_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_sessions_download_session_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/sessions/{session_id}/download-session | 
*AiMentorApi* | [**ai_mentor_orgs_users_sessions_memory_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_sessions_memory_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/sessions/{session_id}/memory/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_sessions_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_sessions_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/sessions/{session_id}/ | Retrieve Chat Messages
*AiMentorApi* | [**ai_mentor_orgs_users_sessions_shell_logs_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_sessions_shell_logs_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/sessions/{session_id}/shell-logs/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_sessions_suggestion_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_sessions_suggestion_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/sessions/{session_id}/suggestion | 
*AiMentorApi* | [**ai_mentor_orgs_users_sessions_tasks_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_sessions_tasks_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/sessions/{session_id}/tasks/{task_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_sessions_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_sessions_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/sessions/{session_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_settings_tenant_llm_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_settings_tenant_llm_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/settings/tenant-llm/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_settings_tenant_llm_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_settings_tenant_llm_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/settings/tenant-llm/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_starred_mentors_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_starred_mentors_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/starred-mentors/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_tasks_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_tasks_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/tasks/{task_id} | 
*AiMentorApi* | [**ai_mentor_orgs_users_tasks_sessions_create**](docs/AiMentorApi.md#ai_mentor_orgs_users_tasks_sessions_create) | **POST** /api/ai-mentor/orgs/{org}/users/{user_id}/tasks/sessions/{session_id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_update**](docs/AiMentorApi.md#ai_mentor_orgs_users_update) | **PUT** /api/ai-mentor/orgs/{org}/users/{user_id}/{name}/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_voices_list**](docs/AiMentorApi.md#ai_mentor_orgs_users_voices_list) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/voices/ | 
*AiMentorApi* | [**ai_mentor_orgs_users_voices_retrieve**](docs/AiMentorApi.md#ai_mentor_orgs_users_voices_retrieve) | **GET** /api/ai-mentor/orgs/{org}/users/{user_id}/voices/{id}/ | 
*AiMentorApi* | [**ai_mentor_orgs_webhooks_azure_trigger_create**](docs/AiMentorApi.md#ai_mentor_orgs_webhooks_azure_trigger_create) | **POST** /api/ai-mentor/orgs/{org}/webhooks/azure/trigger/{slug}/ | 
*AiMentorApi* | [**ai_mentor_orgs_webhooks_github_pullrequest_create**](docs/AiMentorApi.md#ai_mentor_orgs_webhooks_github_pullrequest_create) | **POST** /api/ai-mentor/orgs/{org}/webhooks/github/pullrequest/ | 
*AiMentorApi* | [**ai_mentor_webhooks_azure_emailchat_create**](docs/AiMentorApi.md#ai_mentor_webhooks_azure_emailchat_create) | **POST** /api/ai-mentor/webhooks/azure/emailchat/ | 
*AiPromptApi* | [**ai_prompt_orgs_metadata_create**](docs/AiPromptApi.md#ai_prompt_orgs_metadata_create) | **POST** /api/ai-prompt/orgs/{org}/metadata/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_all_chats_memory_create**](docs/AiPromptApi.md#ai_prompt_orgs_users_all_chats_memory_create) | **POST** /api/ai-prompt/orgs/{org}/users/{user_id}/all-chats-memory/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_all_chats_memory_destroy**](docs/AiPromptApi.md#ai_prompt_orgs_users_all_chats_memory_destroy) | **DELETE** /api/ai-prompt/orgs/{org}/users/{user_id}/all-chats-memory/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_all_chats_memory_destroy2**](docs/AiPromptApi.md#ai_prompt_orgs_users_all_chats_memory_destroy2) | **DELETE** /api/ai-prompt/orgs/{org}/users/{user_id}/all-chats-memory/{memory_id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_all_chats_memory_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_all_chats_memory_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/all-chats-memory/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_all_chats_memory_update**](docs/AiPromptApi.md#ai_prompt_orgs_users_all_chats_memory_update) | **PUT** /api/ai-prompt/orgs/{org}/users/{user_id}/all-chats-memory/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_all_chats_memory_update2**](docs/AiPromptApi.md#ai_prompt_orgs_users_all_chats_memory_update2) | **PUT** /api/ai-prompt/orgs/{org}/users/{user_id}/all-chats-memory/{memory_id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_chat_memory_status_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_chat_memory_status_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/chat-memory-status/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_chat_memory_status_update**](docs/AiPromptApi.md#ai_prompt_orgs_users_chat_memory_status_update) | **PUT** /api/ai-prompt/orgs/{org}/users/{user_id}/chat-memory-status/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_languages_create**](docs/AiPromptApi.md#ai_prompt_orgs_users_languages_create) | **POST** /api/ai-prompt/orgs/{org}/users/{user_id}/languages/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_languages_destroy**](docs/AiPromptApi.md#ai_prompt_orgs_users_languages_destroy) | **DELETE** /api/ai-prompt/orgs/{org}/users/{user_id}/languages/{language_id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_languages_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_languages_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/languages/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_languages_update**](docs/AiPromptApi.md#ai_prompt_orgs_users_languages_update) | **PUT** /api/ai-prompt/orgs/{org}/users/{user_id}/languages/{language_id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_memory_context_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_memory_context_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/memory-context/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_memory_context_update**](docs/AiPromptApi.md#ai_prompt_orgs_users_memory_context_update) | **PUT** /api/ai-prompt/orgs/{org}/users/{user_id}/memory-context/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_memory_create**](docs/AiPromptApi.md#ai_prompt_orgs_users_memory_create) | **POST** /api/ai-prompt/orgs/{org}/users/{user_id}/memory/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_memory_destroy**](docs/AiPromptApi.md#ai_prompt_orgs_users_memory_destroy) | **DELETE** /api/ai-prompt/orgs/{org}/users/{user_id}/memory/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_memory_destroy2**](docs/AiPromptApi.md#ai_prompt_orgs_users_memory_destroy2) | **DELETE** /api/ai-prompt/orgs/{org}/users/{user_id}/memory/{memory_id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_memory_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_memory_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/memory/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_memory_status_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_memory_status_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/memory-status/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_memory_status_update**](docs/AiPromptApi.md#ai_prompt_orgs_users_memory_status_update) | **PUT** /api/ai-prompt/orgs/{org}/users/{user_id}/memory-status/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_memory_update**](docs/AiPromptApi.md#ai_prompt_orgs_users_memory_update) | **PUT** /api/ai-prompt/orgs/{org}/users/{user_id}/memory/{memory_id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_metadata_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_metadata_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/metadata | 
*AiPromptApi* | [**ai_prompt_orgs_users_prompt_create**](docs/AiPromptApi.md#ai_prompt_orgs_users_prompt_create) | **POST** /api/ai-prompt/orgs/{org}/users/{user_id}/prompt/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_prompt_destroy**](docs/AiPromptApi.md#ai_prompt_orgs_users_prompt_destroy) | **DELETE** /api/ai-prompt/orgs/{org}/users/{user_id}/prompt/{id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_prompt_list**](docs/AiPromptApi.md#ai_prompt_orgs_users_prompt_list) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/prompt/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_prompt_partial_update**](docs/AiPromptApi.md#ai_prompt_orgs_users_prompt_partial_update) | **PATCH** /api/ai-prompt/orgs/{org}/users/{user_id}/prompt/{id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_prompt_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_prompt_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/prompt/{id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_prompt_update**](docs/AiPromptApi.md#ai_prompt_orgs_users_prompt_update) | **PUT** /api/ai-prompt/orgs/{org}/users/{user_id}/prompt/{id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_prompts_category_create**](docs/AiPromptApi.md#ai_prompt_orgs_users_prompts_category_create) | **POST** /api/ai-prompt/orgs/{org}/users/{user_id}/prompts/category/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_prompts_category_destroy**](docs/AiPromptApi.md#ai_prompt_orgs_users_prompts_category_destroy) | **DELETE** /api/ai-prompt/orgs/{org}/users/{user_id}/prompts/category/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_prompts_category_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_prompts_category_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/prompts/category/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_prompts_public_list**](docs/AiPromptApi.md#ai_prompt_orgs_users_prompts_public_list) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/prompts/public/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_prompts_public_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_prompts_public_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/prompts/public/{id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_sessions_guided_prompts_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_sessions_guided_prompts_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/sessions/{session_id}/guided-prompts/ | Retrieve guided prompts for a chat session
*AiPromptApi* | [**ai_prompt_orgs_users_styles_create**](docs/AiPromptApi.md#ai_prompt_orgs_users_styles_create) | **POST** /api/ai-prompt/orgs/{org}/users/{user_id}/styles/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_styles_destroy**](docs/AiPromptApi.md#ai_prompt_orgs_users_styles_destroy) | **DELETE** /api/ai-prompt/orgs/{org}/users/{user_id}/styles/{style_id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_styles_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_styles_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/styles/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_styles_update**](docs/AiPromptApi.md#ai_prompt_orgs_users_styles_update) | **PUT** /api/ai-prompt/orgs/{org}/users/{user_id}/styles/{style_id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_tags_create**](docs/AiPromptApi.md#ai_prompt_orgs_users_tags_create) | **POST** /api/ai-prompt/orgs/{org}/users/{user_id}/tags/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_tags_destroy**](docs/AiPromptApi.md#ai_prompt_orgs_users_tags_destroy) | **DELETE** /api/ai-prompt/orgs/{org}/users/{user_id}/tags/{tag_id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_tags_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_tags_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/tags/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_tags_update**](docs/AiPromptApi.md#ai_prompt_orgs_users_tags_update) | **PUT** /api/ai-prompt/orgs/{org}/users/{user_id}/tags/{tag_id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_tones_create**](docs/AiPromptApi.md#ai_prompt_orgs_users_tones_create) | **POST** /api/ai-prompt/orgs/{org}/users/{user_id}/tones/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_tones_destroy**](docs/AiPromptApi.md#ai_prompt_orgs_users_tones_destroy) | **DELETE** /api/ai-prompt/orgs/{org}/users/{user_id}/tones/{tone_id}/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_tones_retrieve**](docs/AiPromptApi.md#ai_prompt_orgs_users_tones_retrieve) | **GET** /api/ai-prompt/orgs/{org}/users/{user_id}/tones/ | 
*AiPromptApi* | [**ai_prompt_orgs_users_tones_update**](docs/AiPromptApi.md#ai_prompt_orgs_users_tones_update) | **PUT** /api/ai-prompt/orgs/{org}/users/{user_id}/tones/{tone_id}/ | 
*AnalyticsApi* | [**analytics_orgs_time_update_create**](docs/AnalyticsApi.md#analytics_orgs_time_update_create) | **POST** /api/analytics/orgs/{org}/time/update/ | 
*AnalyticsApi* | [**analytics_time_spent_user_retrieve**](docs/AnalyticsApi.md#analytics_time_spent_user_retrieve) | **GET** /api/analytics/time-spent/user/ | Get total time spent for current user
*AudienceApi* | [**audience_orgs_active_users_over_time_retrieve**](docs/AudienceApi.md#audience_orgs_active_users_over_time_retrieve) | **GET** /api/audience/orgs/{org}/active-users/over-time | 
*AudienceApi* | [**audience_orgs_active_users_per_course_retrieve**](docs/AudienceApi.md#audience_orgs_active_users_per_course_retrieve) | **GET** /api/audience/orgs/{org}/active-users/per-course | 
*AudienceApi* | [**audience_orgs_active_users_users_retrieve**](docs/AudienceApi.md#audience_orgs_active_users_users_retrieve) | **GET** /api/audience/orgs/{org}/active-users/users | 
*AudienceApi* | [**audience_orgs_enrollments_courses_over_time_retrieve**](docs/AudienceApi.md#audience_orgs_enrollments_courses_over_time_retrieve) | **GET** /api/audience/orgs/{org}/enrollments/courses/{course_id}/over-time | 
*AudienceApi* | [**audience_orgs_enrollments_courses_users_retrieve**](docs/AudienceApi.md#audience_orgs_enrollments_courses_users_retrieve) | **GET** /api/audience/orgs/{org}/enrollments/courses/{course_id}/users | 
*AudienceApi* | [**audience_orgs_enrollments_over_time_retrieve**](docs/AudienceApi.md#audience_orgs_enrollments_over_time_retrieve) | **GET** /api/audience/orgs/{org}/enrollments/over-time | 
*AudienceApi* | [**audience_orgs_enrollments_per_course_retrieve**](docs/AudienceApi.md#audience_orgs_enrollments_per_course_retrieve) | **GET** /api/audience/orgs/{org}/enrollments/per-course | 
*AudienceApi* | [**audience_orgs_registered_users_over_time_retrieve**](docs/AudienceApi.md#audience_orgs_registered_users_over_time_retrieve) | **GET** /api/audience/orgs/{org}/registered-users/over-time | 
*AudienceApi* | [**audience_orgs_registered_users_per_course_retrieve**](docs/AudienceApi.md#audience_orgs_registered_users_per_course_retrieve) | **GET** /api/audience/orgs/{org}/registered-users/per-course | 
*AudienceApi* | [**audience_orgs_registered_users_retrieve**](docs/AudienceApi.md#audience_orgs_registered_users_retrieve) | **GET** /api/audience/orgs/{org}/registered-users/ | 
*CareerApi* | [**career_location_orgs_users_create**](docs/CareerApi.md#career_location_orgs_users_create) | **POST** /api/career/location/orgs/{org}/users/{username}/ | 
*CareerApi* | [**career_location_orgs_users_retrieve**](docs/CareerApi.md#career_location_orgs_users_retrieve) | **GET** /api/career/location/orgs/{org}/users/{username}/ | 
*CareerApi* | [**career_location_orgs_users_update**](docs/CareerApi.md#career_location_orgs_users_update) | **PUT** /api/career/location/orgs/{org}/users/{username}/ | 
*CareerApi* | [**career_locations_orgs_retrieve**](docs/CareerApi.md#career_locations_orgs_retrieve) | **GET** /api/career/locations/orgs/{org}/ | 
*CareerApi* | [**career_orgs_companies_users_create**](docs/CareerApi.md#career_orgs_companies_users_create) | **POST** /api/career/orgs/{org}/companies/users/{username}/ | 
*CareerApi* | [**career_orgs_companies_users_destroy**](docs/CareerApi.md#career_orgs_companies_users_destroy) | **DELETE** /api/career/orgs/{org}/companies/users/{username}/ | 
*CareerApi* | [**career_orgs_companies_users_retrieve**](docs/CareerApi.md#career_orgs_companies_users_retrieve) | **GET** /api/career/orgs/{org}/companies/users/{username}/ | 
*CareerApi* | [**career_orgs_companies_users_update**](docs/CareerApi.md#career_orgs_companies_users_update) | **PUT** /api/career/orgs/{org}/companies/users/{username}/ | 
*CareerApi* | [**career_orgs_education_users_create**](docs/CareerApi.md#career_orgs_education_users_create) | **POST** /api/career/orgs/{org}/education/users/{username}/ | 
*CareerApi* | [**career_orgs_education_users_destroy**](docs/CareerApi.md#career_orgs_education_users_destroy) | **DELETE** /api/career/orgs/{org}/education/users/{username}/ | 
*CareerApi* | [**career_orgs_education_users_retrieve**](docs/CareerApi.md#career_orgs_education_users_retrieve) | **GET** /api/career/orgs/{org}/education/users/{username}/ | 
*CareerApi* | [**career_orgs_education_users_update**](docs/CareerApi.md#career_orgs_education_users_update) | **PUT** /api/career/orgs/{org}/education/users/{username}/ | 
*CareerApi* | [**career_orgs_experience_users_create**](docs/CareerApi.md#career_orgs_experience_users_create) | **POST** /api/career/orgs/{org}/experience/users/{username}/ | 
*CareerApi* | [**career_orgs_experience_users_destroy**](docs/CareerApi.md#career_orgs_experience_users_destroy) | **DELETE** /api/career/orgs/{org}/experience/users/{username}/ | 
*CareerApi* | [**career_orgs_experience_users_retrieve**](docs/CareerApi.md#career_orgs_experience_users_retrieve) | **GET** /api/career/orgs/{org}/experience/users/{username}/ | 
*CareerApi* | [**career_orgs_experience_users_update**](docs/CareerApi.md#career_orgs_experience_users_update) | **PUT** /api/career/orgs/{org}/experience/users/{username}/ | 
*CareerApi* | [**career_orgs_institutions_users_create**](docs/CareerApi.md#career_orgs_institutions_users_create) | **POST** /api/career/orgs/{org}/institutions/users/{username}/ | 
*CareerApi* | [**career_orgs_institutions_users_destroy**](docs/CareerApi.md#career_orgs_institutions_users_destroy) | **DELETE** /api/career/orgs/{org}/institutions/users/{username}/ | 
*CareerApi* | [**career_orgs_institutions_users_retrieve**](docs/CareerApi.md#career_orgs_institutions_users_retrieve) | **GET** /api/career/orgs/{org}/institutions/users/{username}/ | 
*CareerApi* | [**career_orgs_institutions_users_update**](docs/CareerApi.md#career_orgs_institutions_users_update) | **PUT** /api/career/orgs/{org}/institutions/users/{username}/ | 
*CareerApi* | [**career_orgs_programs_users_create**](docs/CareerApi.md#career_orgs_programs_users_create) | **POST** /api/career/orgs/{org}/programs/users/{username}/ | 
*CareerApi* | [**career_orgs_programs_users_destroy**](docs/CareerApi.md#career_orgs_programs_users_destroy) | **DELETE** /api/career/orgs/{org}/programs/users/{username}/ | 
*CareerApi* | [**career_orgs_programs_users_retrieve**](docs/CareerApi.md#career_orgs_programs_users_retrieve) | **GET** /api/career/orgs/{org}/programs/users/{username}/ | 
*CareerApi* | [**career_orgs_programs_users_update**](docs/CareerApi.md#career_orgs_programs_users_update) | **PUT** /api/career/orgs/{org}/programs/users/{username}/ | 
*CareerApi* | [**career_resume_orgs_users_create**](docs/CareerApi.md#career_resume_orgs_users_create) | **POST** /api/career/resume/orgs/{org}/users/{username}/ | 
*CareerApi* | [**career_resume_orgs_users_retrieve**](docs/CareerApi.md#career_resume_orgs_users_retrieve) | **GET** /api/career/resume/orgs/{org}/users/{username}/ | 
*CareerApi* | [**career_resume_orgs_users_update**](docs/CareerApi.md#career_resume_orgs_users_update) | **PUT** /api/career/resume/orgs/{org}/users/{username}/ | 
*CatalogApi* | [**catalog_access_requests_course_manage_create**](docs/CatalogApi.md#catalog_access_requests_course_manage_create) | **POST** /api/catalog/access_requests/course/manage/ | 
*CatalogApi* | [**catalog_access_requests_course_manage_retrieve**](docs/CatalogApi.md#catalog_access_requests_course_manage_retrieve) | **GET** /api/catalog/access_requests/course/manage/ | 
*CatalogApi* | [**catalog_access_requests_course_request_create**](docs/CatalogApi.md#catalog_access_requests_course_request_create) | **POST** /api/catalog/access_requests/course/request/ | 
*CatalogApi* | [**catalog_access_requests_course_request_retrieve**](docs/CatalogApi.md#catalog_access_requests_course_request_retrieve) | **GET** /api/catalog/access_requests/course/request/ | 
*CatalogApi* | [**catalog_conditionals_course_eligibility_retrieve**](docs/CatalogApi.md#catalog_conditionals_course_eligibility_retrieve) | **GET** /api/catalog/conditionals/course/eligibility/ | 
*CatalogApi* | [**catalog_conditionals_course_prerequisites_manage_bulk_create**](docs/CatalogApi.md#catalog_conditionals_course_prerequisites_manage_bulk_create) | **POST** /api/catalog/conditionals/course/prerequisites/manage/bulk/ | 
*CatalogApi* | [**catalog_conditionals_course_prerequisites_manage_retrieve**](docs/CatalogApi.md#catalog_conditionals_course_prerequisites_manage_retrieve) | **GET** /api/catalog/conditionals/course/prerequisites/manage/ | 
*CatalogApi* | [**catalog_courses_create**](docs/CatalogApi.md#catalog_courses_create) | **POST** /api/catalog/courses/ | 
*CatalogApi* | [**catalog_courses_destroy**](docs/CatalogApi.md#catalog_courses_destroy) | **DELETE** /api/catalog/courses/ | 
*CatalogApi* | [**catalog_courses_list**](docs/CatalogApi.md#catalog_courses_list) | **GET** /api/catalog/courses/ | 
*CatalogApi* | [**catalog_eligibility_courses_check_retrieve**](docs/CatalogApi.md#catalog_eligibility_courses_check_retrieve) | **GET** /api/catalog/eligibility/courses/check/ | 
*CatalogApi* | [**catalog_eligibility_courses_list**](docs/CatalogApi.md#catalog_eligibility_courses_list) | **GET** /api/catalog/eligibility/courses/ | 
*CatalogApi* | [**catalog_enrollment_courses_search_retrieve**](docs/CatalogApi.md#catalog_enrollment_courses_search_retrieve) | **GET** /api/catalog/enrollment/courses/search/ | 
*CatalogApi* | [**catalog_enrollment_pathways_create**](docs/CatalogApi.md#catalog_enrollment_pathways_create) | **POST** /api/catalog/enrollment/pathways/ | 
*CatalogApi* | [**catalog_enrollment_pathways_destroy**](docs/CatalogApi.md#catalog_enrollment_pathways_destroy) | **DELETE** /api/catalog/enrollment/pathways/ | 
*CatalogApi* | [**catalog_enrollment_pathways_retrieve**](docs/CatalogApi.md#catalog_enrollment_pathways_retrieve) | **GET** /api/catalog/enrollment/pathways/ | 
*CatalogApi* | [**catalog_enrollment_pathways_search_retrieve**](docs/CatalogApi.md#catalog_enrollment_pathways_search_retrieve) | **GET** /api/catalog/enrollment/pathways/search/ | 
*CatalogApi* | [**catalog_enrollment_pathways_self_create**](docs/CatalogApi.md#catalog_enrollment_pathways_self_create) | **POST** /api/catalog/enrollment/pathways/self/ | 
*CatalogApi* | [**catalog_enrollment_pathways_self_destroy**](docs/CatalogApi.md#catalog_enrollment_pathways_self_destroy) | **DELETE** /api/catalog/enrollment/pathways/self/ | 
*CatalogApi* | [**catalog_enrollment_programs_create**](docs/CatalogApi.md#catalog_enrollment_programs_create) | **POST** /api/catalog/enrollment/programs/ | 
*CatalogApi* | [**catalog_enrollment_programs_destroy**](docs/CatalogApi.md#catalog_enrollment_programs_destroy) | **DELETE** /api/catalog/enrollment/programs/ | 
*CatalogApi* | [**catalog_enrollment_programs_retrieve**](docs/CatalogApi.md#catalog_enrollment_programs_retrieve) | **GET** /api/catalog/enrollment/programs/ | 
*CatalogApi* | [**catalog_enrollment_programs_search_retrieve**](docs/CatalogApi.md#catalog_enrollment_programs_search_retrieve) | **GET** /api/catalog/enrollment/programs/search/ | 
*CatalogApi* | [**catalog_enrollment_programs_self_create**](docs/CatalogApi.md#catalog_enrollment_programs_self_create) | **POST** /api/catalog/enrollment/programs/self/ | 
*CatalogApi* | [**catalog_enrollment_programs_self_destroy**](docs/CatalogApi.md#catalog_enrollment_programs_self_destroy) | **DELETE** /api/catalog/enrollment/programs/self/ | 
*CatalogApi* | [**catalog_increment_create**](docs/CatalogApi.md#catalog_increment_create) | **POST** /api/catalog/increment/ | 
*CatalogApi* | [**catalog_increment_retrieve**](docs/CatalogApi.md#catalog_increment_retrieve) | **GET** /api/catalog/increment/ | 
*CatalogApi* | [**catalog_invitations_course_blank_create**](docs/CatalogApi.md#catalog_invitations_course_blank_create) | **POST** /api/catalog/invitations/course/blank/ | 
*CatalogApi* | [**catalog_invitations_course_bulk_create**](docs/CatalogApi.md#catalog_invitations_course_bulk_create) | **POST** /api/catalog/invitations/course/bulk/ | 
*CatalogApi* | [**catalog_invitations_course_create**](docs/CatalogApi.md#catalog_invitations_course_create) | **POST** /api/catalog/invitations/course/ | 
*CatalogApi* | [**catalog_invitations_course_destroy**](docs/CatalogApi.md#catalog_invitations_course_destroy) | **DELETE** /api/catalog/invitations/course/ | 
*CatalogApi* | [**catalog_invitations_course_redeem_create**](docs/CatalogApi.md#catalog_invitations_course_redeem_create) | **POST** /api/catalog/invitations/course/redeem/ | 
*CatalogApi* | [**catalog_invitations_course_retrieve**](docs/CatalogApi.md#catalog_invitations_course_retrieve) | **GET** /api/catalog/invitations/course/ | 
*CatalogApi* | [**catalog_invitations_platform_blank_create**](docs/CatalogApi.md#catalog_invitations_platform_blank_create) | **POST** /api/catalog/invitations/platform/blank/ | 
*CatalogApi* | [**catalog_invitations_platform_bulk_create**](docs/CatalogApi.md#catalog_invitations_platform_bulk_create) | **POST** /api/catalog/invitations/platform/bulk/ | 
*CatalogApi* | [**catalog_invitations_platform_check_retrieve**](docs/CatalogApi.md#catalog_invitations_platform_check_retrieve) | **GET** /api/catalog/invitations/platform/check/ | 
*CatalogApi* | [**catalog_invitations_platform_create**](docs/CatalogApi.md#catalog_invitations_platform_create) | **POST** /api/catalog/invitations/platform/ | 
*CatalogApi* | [**catalog_invitations_platform_destroy**](docs/CatalogApi.md#catalog_invitations_platform_destroy) | **DELETE** /api/catalog/invitations/platform/ | 
*CatalogApi* | [**catalog_invitations_platform_redeem_create**](docs/CatalogApi.md#catalog_invitations_platform_redeem_create) | **POST** /api/catalog/invitations/platform/redeem/ | 
*CatalogApi* | [**catalog_invitations_platform_retrieve**](docs/CatalogApi.md#catalog_invitations_platform_retrieve) | **GET** /api/catalog/invitations/platform/ | 
*CatalogApi* | [**catalog_invitations_program_blank_create**](docs/CatalogApi.md#catalog_invitations_program_blank_create) | **POST** /api/catalog/invitations/program/blank/ | 
*CatalogApi* | [**catalog_invitations_program_bulk_create**](docs/CatalogApi.md#catalog_invitations_program_bulk_create) | **POST** /api/catalog/invitations/program/bulk/ | 
*CatalogApi* | [**catalog_invitations_program_create**](docs/CatalogApi.md#catalog_invitations_program_create) | **POST** /api/catalog/invitations/program/ | 
*CatalogApi* | [**catalog_invitations_program_destroy**](docs/CatalogApi.md#catalog_invitations_program_destroy) | **DELETE** /api/catalog/invitations/program/ | 
*CatalogApi* | [**catalog_invitations_program_redeem_create**](docs/CatalogApi.md#catalog_invitations_program_redeem_create) | **POST** /api/catalog/invitations/program/redeem/ | 
*CatalogApi* | [**catalog_invitations_program_retrieve**](docs/CatalogApi.md#catalog_invitations_program_retrieve) | **GET** /api/catalog/invitations/program/ | 
*CatalogApi* | [**catalog_licenses_course_assignment_create**](docs/CatalogApi.md#catalog_licenses_course_assignment_create) | **POST** /api/catalog/licenses/course/assignment/ | 
*CatalogApi* | [**catalog_licenses_course_assignment_destroy**](docs/CatalogApi.md#catalog_licenses_course_assignment_destroy) | **DELETE** /api/catalog/licenses/course/assignment/ | 
*CatalogApi* | [**catalog_licenses_course_assignment_group_create**](docs/CatalogApi.md#catalog_licenses_course_assignment_group_create) | **POST** /api/catalog/licenses/course/assignment/group/ | 
*CatalogApi* | [**catalog_licenses_course_assignment_group_destroy**](docs/CatalogApi.md#catalog_licenses_course_assignment_group_destroy) | **DELETE** /api/catalog/licenses/course/assignment/group/ | 
*CatalogApi* | [**catalog_licenses_course_assignment_group_retrieve**](docs/CatalogApi.md#catalog_licenses_course_assignment_group_retrieve) | **GET** /api/catalog/licenses/course/assignment/group/ | 
*CatalogApi* | [**catalog_licenses_course_assignment_retrieve**](docs/CatalogApi.md#catalog_licenses_course_assignment_retrieve) | **GET** /api/catalog/licenses/course/assignment/ | 
*CatalogApi* | [**catalog_licenses_course_create_create**](docs/CatalogApi.md#catalog_licenses_course_create_create) | **POST** /api/catalog/licenses/course/create/ | 
*CatalogApi* | [**catalog_licenses_course_retrieve**](docs/CatalogApi.md#catalog_licenses_course_retrieve) | **GET** /api/catalog/licenses/course/ | 
*CatalogApi* | [**catalog_licenses_course_update_create**](docs/CatalogApi.md#catalog_licenses_course_update_create) | **POST** /api/catalog/licenses/course/update/ | 
*CatalogApi* | [**catalog_licenses_platform_create_create**](docs/CatalogApi.md#catalog_licenses_platform_create_create) | **POST** /api/catalog/licenses/platform/create/ | 
*CatalogApi* | [**catalog_licenses_platform_retrieve**](docs/CatalogApi.md#catalog_licenses_platform_retrieve) | **GET** /api/catalog/licenses/platform/ | 
*CatalogApi* | [**catalog_licenses_platform_update_create**](docs/CatalogApi.md#catalog_licenses_platform_update_create) | **POST** /api/catalog/licenses/platform/update/ | 
*CatalogApi* | [**catalog_licenses_program_assignment_create**](docs/CatalogApi.md#catalog_licenses_program_assignment_create) | **POST** /api/catalog/licenses/program/assignment/ | 
*CatalogApi* | [**catalog_licenses_program_assignment_destroy**](docs/CatalogApi.md#catalog_licenses_program_assignment_destroy) | **DELETE** /api/catalog/licenses/program/assignment/ | 
*CatalogApi* | [**catalog_licenses_program_assignment_group_create**](docs/CatalogApi.md#catalog_licenses_program_assignment_group_create) | **POST** /api/catalog/licenses/program/assignment/group/ | 
*CatalogApi* | [**catalog_licenses_program_assignment_group_destroy**](docs/CatalogApi.md#catalog_licenses_program_assignment_group_destroy) | **DELETE** /api/catalog/licenses/program/assignment/group/ | 
*CatalogApi* | [**catalog_licenses_program_assignment_group_retrieve**](docs/CatalogApi.md#catalog_licenses_program_assignment_group_retrieve) | **GET** /api/catalog/licenses/program/assignment/group/ | 
*CatalogApi* | [**catalog_licenses_program_assignment_retrieve**](docs/CatalogApi.md#catalog_licenses_program_assignment_retrieve) | **GET** /api/catalog/licenses/program/assignment/ | 
*CatalogApi* | [**catalog_licenses_program_create_create**](docs/CatalogApi.md#catalog_licenses_program_create_create) | **POST** /api/catalog/licenses/program/create/ | 
*CatalogApi* | [**catalog_licenses_program_retrieve**](docs/CatalogApi.md#catalog_licenses_program_retrieve) | **GET** /api/catalog/licenses/program/ | 
*CatalogApi* | [**catalog_licenses_program_update_create**](docs/CatalogApi.md#catalog_licenses_program_update_create) | **POST** /api/catalog/licenses/program/update/ | 
*CatalogApi* | [**catalog_licenses_user_assignment_check_retrieve**](docs/CatalogApi.md#catalog_licenses_user_assignment_check_retrieve) | **GET** /api/catalog/licenses/user/assignment/check/ | 
*CatalogApi* | [**catalog_licenses_user_assignment_create**](docs/CatalogApi.md#catalog_licenses_user_assignment_create) | **POST** /api/catalog/licenses/user/assignment/ | 
*CatalogApi* | [**catalog_licenses_user_assignment_destroy**](docs/CatalogApi.md#catalog_licenses_user_assignment_destroy) | **DELETE** /api/catalog/licenses/user/assignment/ | 
*CatalogApi* | [**catalog_licenses_user_assignment_group_create**](docs/CatalogApi.md#catalog_licenses_user_assignment_group_create) | **POST** /api/catalog/licenses/user/assignment/group/ | 
*CatalogApi* | [**catalog_licenses_user_assignment_group_destroy**](docs/CatalogApi.md#catalog_licenses_user_assignment_group_destroy) | **DELETE** /api/catalog/licenses/user/assignment/group/ | 
*CatalogApi* | [**catalog_licenses_user_assignment_group_retrieve**](docs/CatalogApi.md#catalog_licenses_user_assignment_group_retrieve) | **GET** /api/catalog/licenses/user/assignment/group/ | 
*CatalogApi* | [**catalog_licenses_user_assignment_retrieve**](docs/CatalogApi.md#catalog_licenses_user_assignment_retrieve) | **GET** /api/catalog/licenses/user/assignment/ | 
*CatalogApi* | [**catalog_licenses_user_create_create**](docs/CatalogApi.md#catalog_licenses_user_create_create) | **POST** /api/catalog/licenses/user/create/ | 
*CatalogApi* | [**catalog_licenses_user_retrieve**](docs/CatalogApi.md#catalog_licenses_user_retrieve) | **GET** /api/catalog/licenses/user/ | 
*CatalogApi* | [**catalog_licenses_user_update_create**](docs/CatalogApi.md#catalog_licenses_user_update_create) | **POST** /api/catalog/licenses/user/update/ | 
*CatalogApi* | [**catalog_metadata_choices_retrieve**](docs/CatalogApi.md#catalog_metadata_choices_retrieve) | **GET** /api/catalog/metadata/choices/ | 
*CatalogApi* | [**catalog_metadata_course_create**](docs/CatalogApi.md#catalog_metadata_course_create) | **POST** /api/catalog/metadata/course/ | 
*CatalogApi* | [**catalog_metadata_course_create2**](docs/CatalogApi.md#catalog_metadata_course_create2) | **POST** /api/catalog/metadata/course/{field}/ | 
*CatalogApi* | [**catalog_metadata_course_public_retrieve**](docs/CatalogApi.md#catalog_metadata_course_public_retrieve) | **GET** /api/catalog/metadata/course-public/ | 
*CatalogApi* | [**catalog_metadata_course_public_retrieve2**](docs/CatalogApi.md#catalog_metadata_course_public_retrieve2) | **GET** /api/catalog/metadata/course-public/{field}/ | 
*CatalogApi* | [**catalog_metadata_course_retrieve**](docs/CatalogApi.md#catalog_metadata_course_retrieve) | **GET** /api/catalog/metadata/course/ | 
*CatalogApi* | [**catalog_metadata_course_retrieve2**](docs/CatalogApi.md#catalog_metadata_course_retrieve2) | **GET** /api/catalog/metadata/course/{field}/ | 
*CatalogApi* | [**catalog_metadata_course_search_create**](docs/CatalogApi.md#catalog_metadata_course_search_create) | **POST** /api/catalog/metadata/course-search/ | 
*CatalogApi* | [**catalog_metadata_program_create**](docs/CatalogApi.md#catalog_metadata_program_create) | **POST** /api/catalog/metadata/program/ | 
*CatalogApi* | [**catalog_metadata_program_create2**](docs/CatalogApi.md#catalog_metadata_program_create2) | **POST** /api/catalog/metadata/program/{field}/ | 
*CatalogApi* | [**catalog_metadata_program_public_retrieve**](docs/CatalogApi.md#catalog_metadata_program_public_retrieve) | **GET** /api/catalog/metadata/program-public/ | 
*CatalogApi* | [**catalog_metadata_program_public_retrieve2**](docs/CatalogApi.md#catalog_metadata_program_public_retrieve2) | **GET** /api/catalog/metadata/program-public/{field}/ | 
*CatalogApi* | [**catalog_metadata_program_retrieve**](docs/CatalogApi.md#catalog_metadata_program_retrieve) | **GET** /api/catalog/metadata/program/ | 
*CatalogApi* | [**catalog_metadata_program_retrieve2**](docs/CatalogApi.md#catalog_metadata_program_retrieve2) | **GET** /api/catalog/metadata/program/{field}/ | 
*CatalogApi* | [**catalog_milestones_completions_course_catalog_retrieve**](docs/CatalogApi.md#catalog_milestones_completions_course_catalog_retrieve) | **GET** /api/catalog/milestones/completions/course/catalog/ | 
*CatalogApi* | [**catalog_milestones_completions_course_manage_create**](docs/CatalogApi.md#catalog_milestones_completions_course_manage_create) | **POST** /api/catalog/milestones/completions/course/manage/ | 
*CatalogApi* | [**catalog_milestones_completions_course_manage_retrieve**](docs/CatalogApi.md#catalog_milestones_completions_course_manage_retrieve) | **GET** /api/catalog/milestones/completions/course/manage/ | 
*CatalogApi* | [**catalog_milestones_completions_pathway_query_retrieve**](docs/CatalogApi.md#catalog_milestones_completions_pathway_query_retrieve) | **GET** /api/catalog/milestones/completions/pathway/query/ | 
*CatalogApi* | [**catalog_milestones_completions_program_query_retrieve**](docs/CatalogApi.md#catalog_milestones_completions_program_query_retrieve) | **GET** /api/catalog/milestones/completions/program/query/ | 
*CatalogApi* | [**catalog_milestones_completions_resource_manage_create**](docs/CatalogApi.md#catalog_milestones_completions_resource_manage_create) | **POST** /api/catalog/milestones/completions/resource/manage/ | 
*CatalogApi* | [**catalog_milestones_completions_resource_manage_retrieve**](docs/CatalogApi.md#catalog_milestones_completions_resource_manage_retrieve) | **GET** /api/catalog/milestones/completions/resource/manage/ | 
*CatalogApi* | [**catalog_milestones_skill_points_block_create**](docs/CatalogApi.md#catalog_milestones_skill_points_block_create) | **POST** /api/catalog/milestones/skill_points/block/ | 
*CatalogApi* | [**catalog_milestones_skill_points_block_retrieve**](docs/CatalogApi.md#catalog_milestones_skill_points_block_retrieve) | **GET** /api/catalog/milestones/skill_points/block/ | 
*CatalogApi* | [**catalog_milestones_skill_points_course_create**](docs/CatalogApi.md#catalog_milestones_skill_points_course_create) | **POST** /api/catalog/milestones/skill_points/course/ | 
*CatalogApi* | [**catalog_milestones_skill_points_course_retrieve**](docs/CatalogApi.md#catalog_milestones_skill_points_course_retrieve) | **GET** /api/catalog/milestones/skill_points/course/ | 
*CatalogApi* | [**catalog_milestones_skill_points_platform_bulk_create**](docs/CatalogApi.md#catalog_milestones_skill_points_platform_bulk_create) | **POST** /api/catalog/milestones/skill_points/platform/bulk/ | 
*CatalogApi* | [**catalog_milestones_skill_points_platform_create**](docs/CatalogApi.md#catalog_milestones_skill_points_platform_create) | **POST** /api/catalog/milestones/skill_points/platform/ | 
*CatalogApi* | [**catalog_milestones_skill_points_platform_destroy**](docs/CatalogApi.md#catalog_milestones_skill_points_platform_destroy) | **DELETE** /api/catalog/milestones/skill_points/platform/ | 
*CatalogApi* | [**catalog_milestones_skill_points_platform_group_create**](docs/CatalogApi.md#catalog_milestones_skill_points_platform_group_create) | **POST** /api/catalog/milestones/skill_points/platform/group/ | 
*CatalogApi* | [**catalog_milestones_skill_points_platform_retrieve**](docs/CatalogApi.md#catalog_milestones_skill_points_platform_retrieve) | **GET** /api/catalog/milestones/skill_points/platform/ | 
*CatalogApi* | [**catalog_milestones_skill_points_user_retrieve**](docs/CatalogApi.md#catalog_milestones_skill_points_user_retrieve) | **GET** /api/catalog/milestones/skill_points/user/ | 
*CatalogApi* | [**catalog_pathways_create**](docs/CatalogApi.md#catalog_pathways_create) | **POST** /api/catalog/pathways/ | 
*CatalogApi* | [**catalog_pathways_destroy**](docs/CatalogApi.md#catalog_pathways_destroy) | **DELETE** /api/catalog/pathways/ | 
*CatalogApi* | [**catalog_pathways_list**](docs/CatalogApi.md#catalog_pathways_list) | **GET** /api/catalog/pathways/ | 
*CatalogApi* | [**catalog_programs_create**](docs/CatalogApi.md#catalog_programs_create) | **POST** /api/catalog/programs/ | 
*CatalogApi* | [**catalog_programs_destroy**](docs/CatalogApi.md#catalog_programs_destroy) | **DELETE** /api/catalog/programs/ | 
*CatalogApi* | [**catalog_programs_list**](docs/CatalogApi.md#catalog_programs_list) | **GET** /api/catalog/programs/ | 
*CatalogApi* | [**catalog_recommendation_courses_retrieve**](docs/CatalogApi.md#catalog_recommendation_courses_retrieve) | **GET** /api/catalog/recommendation/courses/ | 
*CatalogApi* | [**catalog_resources_create**](docs/CatalogApi.md#catalog_resources_create) | **POST** /api/catalog/resources/ | Create or update a resource with optional image upload
*CatalogApi* | [**catalog_resources_destroy**](docs/CatalogApi.md#catalog_resources_destroy) | **DELETE** /api/catalog/resources/ | 
*CatalogApi* | [**catalog_resources_list**](docs/CatalogApi.md#catalog_resources_list) | **GET** /api/catalog/resources/ | 
*CatalogApi* | [**catalog_reviews_course_info_retrieve**](docs/CatalogApi.md#catalog_reviews_course_info_retrieve) | **GET** /api/catalog/reviews/course/info/ | 
*CatalogApi* | [**catalog_reviews_course_retrieve**](docs/CatalogApi.md#catalog_reviews_course_retrieve) | **GET** /api/catalog/reviews/course/ | 
*CatalogApi* | [**catalog_reviews_course_update_create**](docs/CatalogApi.md#catalog_reviews_course_update_create) | **POST** /api/catalog/reviews/course/update/ | 
*CatalogApi* | [**catalog_reviews_course_update_destroy**](docs/CatalogApi.md#catalog_reviews_course_update_destroy) | **DELETE** /api/catalog/reviews/course/update/ | 
*CatalogApi* | [**catalog_reviews_program_info_retrieve**](docs/CatalogApi.md#catalog_reviews_program_info_retrieve) | **GET** /api/catalog/reviews/program/info/ | 
*CatalogApi* | [**catalog_reviews_program_retrieve**](docs/CatalogApi.md#catalog_reviews_program_retrieve) | **GET** /api/catalog/reviews/program/ | 
*CatalogApi* | [**catalog_reviews_program_update_create**](docs/CatalogApi.md#catalog_reviews_program_update_create) | **POST** /api/catalog/reviews/program/update/ | 
*CatalogApi* | [**catalog_reviews_program_update_destroy**](docs/CatalogApi.md#catalog_reviews_program_update_destroy) | **DELETE** /api/catalog/reviews/program/update/ | 
*CatalogApi* | [**catalog_roles_create**](docs/CatalogApi.md#catalog_roles_create) | **POST** /api/catalog/roles/ | 
*CatalogApi* | [**catalog_roles_desired_create**](docs/CatalogApi.md#catalog_roles_desired_create) | **POST** /api/catalog/roles/desired/ | 
*CatalogApi* | [**catalog_roles_desired_retrieve**](docs/CatalogApi.md#catalog_roles_desired_retrieve) | **GET** /api/catalog/roles/desired/ | 
*CatalogApi* | [**catalog_roles_public_create**](docs/CatalogApi.md#catalog_roles_public_create) | **POST** /api/catalog/roles/public/ | 
*CatalogApi* | [**catalog_roles_reported_create**](docs/CatalogApi.md#catalog_roles_reported_create) | **POST** /api/catalog/roles/reported/ | 
*CatalogApi* | [**catalog_roles_reported_retrieve**](docs/CatalogApi.md#catalog_roles_reported_retrieve) | **GET** /api/catalog/roles/reported/ | 
*CatalogApi* | [**catalog_roles_retrieve**](docs/CatalogApi.md#catalog_roles_retrieve) | **GET** /api/catalog/roles/ | 
*CatalogApi* | [**catalog_search_programs_create**](docs/CatalogApi.md#catalog_search_programs_create) | **POST** /api/catalog/search/programs/ | 
*CatalogApi* | [**catalog_skills_create**](docs/CatalogApi.md#catalog_skills_create) | **POST** /api/catalog/skills/ | 
*CatalogApi* | [**catalog_skills_desired_create**](docs/CatalogApi.md#catalog_skills_desired_create) | **POST** /api/catalog/skills/desired/ | 
*CatalogApi* | [**catalog_skills_desired_retrieve**](docs/CatalogApi.md#catalog_skills_desired_retrieve) | **GET** /api/catalog/skills/desired/ | 
*CatalogApi* | [**catalog_skills_public_create**](docs/CatalogApi.md#catalog_skills_public_create) | **POST** /api/catalog/skills/public/ | 
*CatalogApi* | [**catalog_skills_reported_create**](docs/CatalogApi.md#catalog_skills_reported_create) | **POST** /api/catalog/skills/reported/ | 
*CatalogApi* | [**catalog_skills_reported_retrieve**](docs/CatalogApi.md#catalog_skills_reported_retrieve) | **GET** /api/catalog/skills/reported/ | 
*CatalogApi* | [**catalog_skills_retrieve**](docs/CatalogApi.md#catalog_skills_retrieve) | **GET** /api/catalog/skills/ | 
*CatalogApi* | [**catalog_suggestions_course_manage_bulk_create**](docs/CatalogApi.md#catalog_suggestions_course_manage_bulk_create) | **POST** /api/catalog/suggestions/course/manage/bulk/ | 
*CatalogApi* | [**catalog_suggestions_course_manage_create**](docs/CatalogApi.md#catalog_suggestions_course_manage_create) | **POST** /api/catalog/suggestions/course/manage/ | 
*CatalogApi* | [**catalog_suggestions_course_manage_destroy**](docs/CatalogApi.md#catalog_suggestions_course_manage_destroy) | **DELETE** /api/catalog/suggestions/course/manage/ | 
*CatalogApi* | [**catalog_suggestions_course_manage_group_create**](docs/CatalogApi.md#catalog_suggestions_course_manage_group_create) | **POST** /api/catalog/suggestions/course/manage/group/ | 
*CatalogApi* | [**catalog_suggestions_course_manage_group_destroy**](docs/CatalogApi.md#catalog_suggestions_course_manage_group_destroy) | **DELETE** /api/catalog/suggestions/course/manage/group/ | 
*CatalogApi* | [**catalog_suggestions_course_manage_group_retrieve**](docs/CatalogApi.md#catalog_suggestions_course_manage_group_retrieve) | **GET** /api/catalog/suggestions/course/manage/group/ | 
*CatalogApi* | [**catalog_suggestions_course_manage_retrieve**](docs/CatalogApi.md#catalog_suggestions_course_manage_retrieve) | **GET** /api/catalog/suggestions/course/manage/ | 
*CatalogApi* | [**catalog_suggestions_course_user_retrieve**](docs/CatalogApi.md#catalog_suggestions_course_user_retrieve) | **GET** /api/catalog/suggestions/course/user/ | 
*CatalogApi* | [**catalog_suggestions_pathway_manage_bulk_create**](docs/CatalogApi.md#catalog_suggestions_pathway_manage_bulk_create) | **POST** /api/catalog/suggestions/pathway/manage/bulk/ | 
*CatalogApi* | [**catalog_suggestions_pathway_manage_create**](docs/CatalogApi.md#catalog_suggestions_pathway_manage_create) | **POST** /api/catalog/suggestions/pathway/manage/ | 
*CatalogApi* | [**catalog_suggestions_pathway_manage_destroy**](docs/CatalogApi.md#catalog_suggestions_pathway_manage_destroy) | **DELETE** /api/catalog/suggestions/pathway/manage/ | 
*CatalogApi* | [**catalog_suggestions_pathway_manage_group_create**](docs/CatalogApi.md#catalog_suggestions_pathway_manage_group_create) | **POST** /api/catalog/suggestions/pathway/manage/group/ | 
*CatalogApi* | [**catalog_suggestions_pathway_manage_group_destroy**](docs/CatalogApi.md#catalog_suggestions_pathway_manage_group_destroy) | **DELETE** /api/catalog/suggestions/pathway/manage/group/ | 
*CatalogApi* | [**catalog_suggestions_pathway_manage_group_retrieve**](docs/CatalogApi.md#catalog_suggestions_pathway_manage_group_retrieve) | **GET** /api/catalog/suggestions/pathway/manage/group/ | 
*CatalogApi* | [**catalog_suggestions_pathway_manage_retrieve**](docs/CatalogApi.md#catalog_suggestions_pathway_manage_retrieve) | **GET** /api/catalog/suggestions/pathway/manage/ | 
*CatalogApi* | [**catalog_suggestions_pathway_user_retrieve**](docs/CatalogApi.md#catalog_suggestions_pathway_user_retrieve) | **GET** /api/catalog/suggestions/pathway/user/ | 
*CatalogApi* | [**catalog_suggestions_program_manage_bulk_create**](docs/CatalogApi.md#catalog_suggestions_program_manage_bulk_create) | **POST** /api/catalog/suggestions/program/manage/bulk/ | 
*CatalogApi* | [**catalog_suggestions_program_manage_create**](docs/CatalogApi.md#catalog_suggestions_program_manage_create) | **POST** /api/catalog/suggestions/program/manage/ | 
*CatalogApi* | [**catalog_suggestions_program_manage_destroy**](docs/CatalogApi.md#catalog_suggestions_program_manage_destroy) | **DELETE** /api/catalog/suggestions/program/manage/ | 
*CatalogApi* | [**catalog_suggestions_program_manage_group_create**](docs/CatalogApi.md#catalog_suggestions_program_manage_group_create) | **POST** /api/catalog/suggestions/program/manage/group/ | 
*CatalogApi* | [**catalog_suggestions_program_manage_group_destroy**](docs/CatalogApi.md#catalog_suggestions_program_manage_group_destroy) | **DELETE** /api/catalog/suggestions/program/manage/group/ | 
*CatalogApi* | [**catalog_suggestions_program_manage_group_retrieve**](docs/CatalogApi.md#catalog_suggestions_program_manage_group_retrieve) | **GET** /api/catalog/suggestions/program/manage/group/ | 
*CatalogApi* | [**catalog_suggestions_program_manage_retrieve**](docs/CatalogApi.md#catalog_suggestions_program_manage_retrieve) | **GET** /api/catalog/suggestions/program/manage/ | 
*CatalogApi* | [**catalog_suggestions_program_user_retrieve**](docs/CatalogApi.md#catalog_suggestions_program_user_retrieve) | **GET** /api/catalog/suggestions/program/user/ | 
*CoreApi* | [**core_consolidated_token_proxy_create**](docs/CoreApi.md#core_consolidated_token_proxy_create) | **POST** /api/core/consolidated-token/proxy/ | 
*CoreApi* | [**core_departments_create**](docs/CoreApi.md#core_departments_create) | **POST** /api/core/departments/ | 
*CoreApi* | [**core_departments_destroy**](docs/CoreApi.md#core_departments_destroy) | **DELETE** /api/core/departments/ | 
*CoreApi* | [**core_departments_members_bulk_create**](docs/CoreApi.md#core_departments_members_bulk_create) | **POST** /api/core/departments/members/bulk/ | 
*CoreApi* | [**core_departments_members_check_retrieve**](docs/CoreApi.md#core_departments_members_check_retrieve) | **GET** /api/core/departments/members/check/ | 
*CoreApi* | [**core_departments_members_create**](docs/CoreApi.md#core_departments_members_create) | **POST** /api/core/departments/members/ | 
*CoreApi* | [**core_departments_members_destroy**](docs/CoreApi.md#core_departments_members_destroy) | **DELETE** /api/core/departments/members/ | 
*CoreApi* | [**core_departments_members_retrieve**](docs/CoreApi.md#core_departments_members_retrieve) | **GET** /api/core/departments/members/ | 
*CoreApi* | [**core_departments_retrieve**](docs/CoreApi.md#core_departments_retrieve) | **GET** /api/core/departments/ | 
*CoreApi* | [**core_domains_whitelist_create**](docs/CoreApi.md#core_domains_whitelist_create) | **POST** /api/core/domains/whitelist/ | 
*CoreApi* | [**core_domains_whitelist_retrieve**](docs/CoreApi.md#core_domains_whitelist_retrieve) | **GET** /api/core/domains/whitelist/ | 
*CoreApi* | [**core_heartbeat_celery_beat_retrieve**](docs/CoreApi.md#core_heartbeat_celery_beat_retrieve) | **GET** /api/core/heartbeat/celery-beat/ | 
*CoreApi* | [**core_heartbeat_celery_retrieve**](docs/CoreApi.md#core_heartbeat_celery_retrieve) | **GET** /api/core/heartbeat/celery/ | 
*CoreApi* | [**core_launcher_create**](docs/CoreApi.md#core_launcher_create) | **POST** /api/core/launcher/ | 
*CoreApi* | [**core_launcher_retrieve**](docs/CoreApi.md#core_launcher_retrieve) | **GET** /api/core/launcher/ | 
*CoreApi* | [**core_lti1p3_provider_lti_keys_create**](docs/CoreApi.md#core_lti1p3_provider_lti_keys_create) | **POST** /api/core/lti/1p3/provider/lti-keys/ | 
*CoreApi* | [**core_lti1p3_provider_lti_keys_destroy**](docs/CoreApi.md#core_lti1p3_provider_lti_keys_destroy) | **DELETE** /api/core/lti/1p3/provider/lti-keys/{id}/ | 
*CoreApi* | [**core_lti1p3_provider_lti_keys_list**](docs/CoreApi.md#core_lti1p3_provider_lti_keys_list) | **GET** /api/core/lti/1p3/provider/lti-keys/ | 
*CoreApi* | [**core_lti1p3_provider_lti_keys_retrieve**](docs/CoreApi.md#core_lti1p3_provider_lti_keys_retrieve) | **GET** /api/core/lti/1p3/provider/lti-keys/{id}/ | 
*CoreApi* | [**core_lti1p3_provider_lti_keys_update**](docs/CoreApi.md#core_lti1p3_provider_lti_keys_update) | **PUT** /api/core/lti/1p3/provider/lti-keys/{id}/ | 
*CoreApi* | [**core_lti1p3_provider_lti_tools_create**](docs/CoreApi.md#core_lti1p3_provider_lti_tools_create) | **POST** /api/core/lti/1p3/provider/lti-tools/ | 
*CoreApi* | [**core_lti1p3_provider_lti_tools_destroy**](docs/CoreApi.md#core_lti1p3_provider_lti_tools_destroy) | **DELETE** /api/core/lti/1p3/provider/lti-tools/{id}/ | 
*CoreApi* | [**core_lti1p3_provider_lti_tools_list**](docs/CoreApi.md#core_lti1p3_provider_lti_tools_list) | **GET** /api/core/lti/1p3/provider/lti-tools/ | 
*CoreApi* | [**core_lti1p3_provider_lti_tools_retrieve**](docs/CoreApi.md#core_lti1p3_provider_lti_tools_retrieve) | **GET** /api/core/lti/1p3/provider/lti-tools/{id}/ | 
*CoreApi* | [**core_lti1p3_provider_lti_tools_update**](docs/CoreApi.md#core_lti1p3_provider_lti_tools_update) | **PUT** /api/core/lti/1p3/provider/lti-tools/{id}/ | 
*CoreApi* | [**core_orgs_dark_mode_logo_create_create**](docs/CoreApi.md#core_orgs_dark_mode_logo_create_create) | **POST** /api/core/orgs/{org}/dark-mode-logo/create/ | 
*CoreApi* | [**core_orgs_dark_mode_logo_retrieve**](docs/CoreApi.md#core_orgs_dark_mode_logo_retrieve) | **GET** /api/core/orgs/{org}/dark-mode-logo/ | 
*CoreApi* | [**core_orgs_favicon_create_create**](docs/CoreApi.md#core_orgs_favicon_create_create) | **POST** /api/core/orgs/{org}/favicon/create/ | 
*CoreApi* | [**core_orgs_favicon_retrieve**](docs/CoreApi.md#core_orgs_favicon_retrieve) | **GET** /api/core/orgs/{org}/favicon/ | 
*CoreApi* | [**core_orgs_logo_create_create**](docs/CoreApi.md#core_orgs_logo_create_create) | **POST** /api/core/orgs/{org}/logo/create/ | 
*CoreApi* | [**core_orgs_logo_retrieve**](docs/CoreApi.md#core_orgs_logo_retrieve) | **GET** /api/core/orgs/{org}/logo/ | 
*CoreApi* | [**core_orgs_metadata_partial_update**](docs/CoreApi.md#core_orgs_metadata_partial_update) | **PATCH** /api/core/orgs/{org}/metadata/ | 
*CoreApi* | [**core_orgs_metadata_retrieve**](docs/CoreApi.md#core_orgs_metadata_retrieve) | **GET** /api/core/orgs/{org}/metadata/ | 
*CoreApi* | [**core_orgs_metadata_update**](docs/CoreApi.md#core_orgs_metadata_update) | **PUT** /api/core/orgs/{org}/metadata/ | 
*CoreApi* | [**core_orgs_redirect_tokens_create**](docs/CoreApi.md#core_orgs_redirect_tokens_create) | **POST** /api/core/orgs/{org}/redirect-tokens/ | 
*CoreApi* | [**core_orgs_redirect_tokens_delete_destroy**](docs/CoreApi.md#core_orgs_redirect_tokens_delete_destroy) | **DELETE** /api/core/orgs/{org}/redirect-tokens/{redirect_token}/delete | 
*CoreApi* | [**core_orgs_redirect_tokens_retrieve**](docs/CoreApi.md#core_orgs_redirect_tokens_retrieve) | **GET** /api/core/orgs/{org}/redirect-tokens/{redirect_token}/ | 
*CoreApi* | [**core_orgs_thumbnail_create_create**](docs/CoreApi.md#core_orgs_thumbnail_create_create) | **POST** /api/core/orgs/{org}/thumbnail/create/ | 
*CoreApi* | [**core_orgs_thumbnail_retrieve**](docs/CoreApi.md#core_orgs_thumbnail_retrieve) | **GET** /api/core/orgs/{org}/thumbnail/ | 
*CoreApi* | [**core_platform_api_tokens_create**](docs/CoreApi.md#core_platform_api_tokens_create) | **POST** /api/core/platform/api-tokens/ | 
*CoreApi* | [**core_platform_api_tokens_destroy**](docs/CoreApi.md#core_platform_api_tokens_destroy) | **DELETE** /api/core/platform/api-tokens/{name} | 
*CoreApi* | [**core_platform_api_tokens_list**](docs/CoreApi.md#core_platform_api_tokens_list) | **GET** /api/core/platform/api-tokens/ | 
*CoreApi* | [**core_platform_config_site_create**](docs/CoreApi.md#core_platform_config_site_create) | **POST** /api/core/platform/config/site/ | 
*CoreApi* | [**core_platform_config_site_retrieve**](docs/CoreApi.md#core_platform_config_site_retrieve) | **GET** /api/core/platform/config/site/ | 
*CoreApi* | [**core_platform_create**](docs/CoreApi.md#core_platform_create) | **POST** /api/core/platform/ | 
*CoreApi* | [**core_platform_retrieve**](docs/CoreApi.md#core_platform_retrieve) | **GET** /api/core/platform/ | 
*CoreApi* | [**core_platform_users_retrieve**](docs/CoreApi.md#core_platform_users_retrieve) | **GET** /api/core/platform/users/ | 
*CoreApi* | [**core_rbac_groups_create**](docs/CoreApi.md#core_rbac_groups_create) | **POST** /api/core/rbac/groups/ | Create RBAC group
*CoreApi* | [**core_rbac_groups_destroy**](docs/CoreApi.md#core_rbac_groups_destroy) | **DELETE** /api/core/rbac/groups/{id}/ | Delete RBAC group
*CoreApi* | [**core_rbac_groups_list**](docs/CoreApi.md#core_rbac_groups_list) | **GET** /api/core/rbac/groups/ | List RBAC groups
*CoreApi* | [**core_rbac_groups_partial_update**](docs/CoreApi.md#core_rbac_groups_partial_update) | **PATCH** /api/core/rbac/groups/{id}/ | Partially update RBAC group
*CoreApi* | [**core_rbac_groups_retrieve**](docs/CoreApi.md#core_rbac_groups_retrieve) | **GET** /api/core/rbac/groups/{id}/ | Retrieve RBAC group
*CoreApi* | [**core_rbac_groups_update**](docs/CoreApi.md#core_rbac_groups_update) | **PUT** /api/core/rbac/groups/{id}/ | Update RBAC group
*CoreApi* | [**core_rbac_policies_create**](docs/CoreApi.md#core_rbac_policies_create) | **POST** /api/core/rbac/policies/ | Create RBAC policy
*CoreApi* | [**core_rbac_policies_destroy**](docs/CoreApi.md#core_rbac_policies_destroy) | **DELETE** /api/core/rbac/policies/{id}/ | Delete RBAC policy
*CoreApi* | [**core_rbac_policies_list**](docs/CoreApi.md#core_rbac_policies_list) | **GET** /api/core/rbac/policies/ | List RBAC policies
*CoreApi* | [**core_rbac_policies_partial_update**](docs/CoreApi.md#core_rbac_policies_partial_update) | **PATCH** /api/core/rbac/policies/{id}/ | Partially update RBAC policy
*CoreApi* | [**core_rbac_policies_retrieve**](docs/CoreApi.md#core_rbac_policies_retrieve) | **GET** /api/core/rbac/policies/{id}/ | Retrieve RBAC policy
*CoreApi* | [**core_rbac_policies_update**](docs/CoreApi.md#core_rbac_policies_update) | **PUT** /api/core/rbac/policies/{id}/ | Update RBAC policy
*CoreApi* | [**core_rbac_roles_create**](docs/CoreApi.md#core_rbac_roles_create) | **POST** /api/core/rbac/roles/ | Create RBAC role
*CoreApi* | [**core_rbac_roles_destroy**](docs/CoreApi.md#core_rbac_roles_destroy) | **DELETE** /api/core/rbac/roles/{id}/ | Delete RBAC role
*CoreApi* | [**core_rbac_roles_list**](docs/CoreApi.md#core_rbac_roles_list) | **GET** /api/core/rbac/roles/ | List RBAC roles
*CoreApi* | [**core_rbac_roles_partial_update**](docs/CoreApi.md#core_rbac_roles_partial_update) | **PATCH** /api/core/rbac/roles/{id}/ | Partially update RBAC role
*CoreApi* | [**core_rbac_roles_retrieve**](docs/CoreApi.md#core_rbac_roles_retrieve) | **GET** /api/core/rbac/roles/{id}/ | Retrieve RBAC role
*CoreApi* | [**core_rbac_roles_update**](docs/CoreApi.md#core_rbac_roles_update) | **PUT** /api/core/rbac/roles/{id}/ | Update RBAC role
*CoreApi* | [**core_session_logout_create**](docs/CoreApi.md#core_session_logout_create) | **POST** /api/core/session/logout/ | 
*CoreApi* | [**core_signals_edx_create**](docs/CoreApi.md#core_signals_edx_create) | **POST** /api/core/signals/edx/ | 
*CoreApi* | [**core_token_proxy_create**](docs/CoreApi.md#core_token_proxy_create) | **POST** /api/core/token/proxy/ | 
*CoreApi* | [**core_token_verify_retrieve**](docs/CoreApi.md#core_token_verify_retrieve) | **GET** /api/core/token/verify/ | 
*CoreApi* | [**core_user_groups_create**](docs/CoreApi.md#core_user_groups_create) | **POST** /api/core/user_groups/ | 
*CoreApi* | [**core_user_groups_destroy**](docs/CoreApi.md#core_user_groups_destroy) | **DELETE** /api/core/user_groups/ | 
*CoreApi* | [**core_user_groups_link_bulk_create**](docs/CoreApi.md#core_user_groups_link_bulk_create) | **POST** /api/core/user_groups/link/bulk/ | 
*CoreApi* | [**core_user_groups_link_create**](docs/CoreApi.md#core_user_groups_link_create) | **POST** /api/core/user_groups/link/ | 
*CoreApi* | [**core_user_groups_link_destroy**](docs/CoreApi.md#core_user_groups_link_destroy) | **DELETE** /api/core/user_groups/link/ | 
*CoreApi* | [**core_user_groups_link_retrieve**](docs/CoreApi.md#core_user_groups_link_retrieve) | **GET** /api/core/user_groups/link/ | 
*CoreApi* | [**core_user_groups_retrieve**](docs/CoreApi.md#core_user_groups_retrieve) | **GET** /api/core/user_groups/ | 
*CoreApi* | [**core_users_delete_create**](docs/CoreApi.md#core_users_delete_create) | **POST** /api/core/users/delete/ | 
*CoreApi* | [**core_users_metadata_proxy_retrieve**](docs/CoreApi.md#core_users_metadata_proxy_retrieve) | **GET** /api/core/users/metadata/proxy/ | 
*CoreApi* | [**core_users_platforms_create**](docs/CoreApi.md#core_users_platforms_create) | **POST** /api/core/users/platforms/ | 
*CoreApi* | [**core_users_platforms_list**](docs/CoreApi.md#core_users_platforms_list) | **GET** /api/core/users/platforms/ | 
*CoreApi* | [**core_users_proxy_bulk_create**](docs/CoreApi.md#core_users_proxy_bulk_create) | **POST** /api/core/users/proxy/bulk/ | 
*CoreApi* | [**core_users_proxy_create**](docs/CoreApi.md#core_users_proxy_create) | **POST** /api/core/users/proxy/ | 
*CoreApi* | [**core_users_proxy_retrieve**](docs/CoreApi.md#core_users_proxy_retrieve) | **GET** /api/core/users/proxy/ | 
*CoreApi* | [**core_users_search_retrieve**](docs/CoreApi.md#core_users_search_retrieve) | **GET** /api/core/users/search/ | 
*CredentialsApi* | [**credentials_orgs_users_assertions_bulk_create**](docs/CredentialsApi.md#credentials_orgs_users_assertions_bulk_create) | **POST** /api/credentials/orgs/{org}/users/{user_id}/{entity_id}/assertions/bulk/ | 
*CredentialsApi* | [**credentials_orgs_users_assertions_create**](docs/CredentialsApi.md#credentials_orgs_users_assertions_create) | **POST** /api/credentials/orgs/{org}/users/{user_id}/{entity_id}/assertions/ | 
*CredentialsApi* | [**credentials_orgs_users_assertions_over_time_retrieve**](docs/CredentialsApi.md#credentials_orgs_users_assertions_over_time_retrieve) | **GET** /api/credentials/orgs/{org}/users/{user_id}/assertions-over-time/ | 
*CredentialsApi* | [**credentials_orgs_users_assertions_retrieve**](docs/CredentialsApi.md#credentials_orgs_users_assertions_retrieve) | **GET** /api/credentials/orgs/{org}/users/{user_id}/assertions/ | 
*CredentialsApi* | [**credentials_orgs_users_assertions_retrieve2**](docs/CredentialsApi.md#credentials_orgs_users_assertions_retrieve2) | **GET** /api/credentials/orgs/{org}/users/{user_id}/assertions/{entity_id} | 
*CredentialsApi* | [**credentials_orgs_users_assertions_retrieve3**](docs/CredentialsApi.md#credentials_orgs_users_assertions_retrieve3) | **GET** /api/credentials/orgs/{org}/users/{user_id}/{entity_id}/assertions/ | 
*CredentialsApi* | [**credentials_orgs_users_assertions_update**](docs/CredentialsApi.md#credentials_orgs_users_assertions_update) | **PUT** /api/credentials/orgs/{org}/users/{user_id}/assertions/{entity_id} | 
*CredentialsApi* | [**credentials_orgs_users_assignments_destroy**](docs/CredentialsApi.md#credentials_orgs_users_assignments_destroy) | **DELETE** /api/credentials/orgs/{org}/users/{user_id}/assignments/{assignment_id} | 
*CredentialsApi* | [**credentials_orgs_users_assignments_groups_create**](docs/CredentialsApi.md#credentials_orgs_users_assignments_groups_create) | **POST** /api/credentials/orgs/{org}/users/{user_id}/assignments/groups/ | 
*CredentialsApi* | [**credentials_orgs_users_assignments_groups_retrieve**](docs/CredentialsApi.md#credentials_orgs_users_assignments_groups_retrieve) | **GET** /api/credentials/orgs/{org}/users/{user_id}/assignments/groups/ | 
*CredentialsApi* | [**credentials_orgs_users_assignments_users_create**](docs/CredentialsApi.md#credentials_orgs_users_assignments_users_create) | **POST** /api/credentials/orgs/{org}/users/{user_id}/assignments/users/ | 
*CredentialsApi* | [**credentials_orgs_users_assignments_users_retrieve**](docs/CredentialsApi.md#credentials_orgs_users_assignments_users_retrieve) | **GET** /api/credentials/orgs/{org}/users/{user_id}/assignments/users/ | 
*CredentialsApi* | [**credentials_orgs_users_course_assertions_over_time_retrieve**](docs/CredentialsApi.md#credentials_orgs_users_course_assertions_over_time_retrieve) | **GET** /api/credentials/orgs/{org}/users/{user_id}/course-assertions-over-time/ | 
*CredentialsApi* | [**credentials_orgs_users_course_credentials_list**](docs/CredentialsApi.md#credentials_orgs_users_course_credentials_list) | **GET** /api/credentials/orgs/{org}/users/{user_id}/course-credentials/ | 
*CredentialsApi* | [**credentials_orgs_users_create**](docs/CredentialsApi.md#credentials_orgs_users_create) | **POST** /api/credentials/orgs/{org}/users/{user_id}/ | 
*CredentialsApi* | [**credentials_orgs_users_credentials_over_time_retrieve**](docs/CredentialsApi.md#credentials_orgs_users_credentials_over_time_retrieve) | **GET** /api/credentials/orgs/{org}/users/{user_id}/credentials-over-time/ | 
*CredentialsApi* | [**credentials_orgs_users_destroy**](docs/CredentialsApi.md#credentials_orgs_users_destroy) | **DELETE** /api/credentials/orgs/{org}/users/{user_id}/{entity_id} | 
*CredentialsApi* | [**credentials_orgs_users_images_create**](docs/CredentialsApi.md#credentials_orgs_users_images_create) | **POST** /api/credentials/orgs/{org}/users/{user_id}/images/ | 
*CredentialsApi* | [**credentials_orgs_users_images_retrieve**](docs/CredentialsApi.md#credentials_orgs_users_images_retrieve) | **GET** /api/credentials/orgs/{org}/users/{user_id}/images/ | 
*CredentialsApi* | [**credentials_orgs_users_issuers_authority_create**](docs/CredentialsApi.md#credentials_orgs_users_issuers_authority_create) | **POST** /api/credentials/orgs/{org}/users/{user_id}/issuers/authority/ | 
*CredentialsApi* | [**credentials_orgs_users_issuers_create**](docs/CredentialsApi.md#credentials_orgs_users_issuers_create) | **POST** /api/credentials/orgs/{org}/users/{user_id}/issuers/ | 
*CredentialsApi* | [**credentials_orgs_users_issuers_destroy**](docs/CredentialsApi.md#credentials_orgs_users_issuers_destroy) | **DELETE** /api/credentials/orgs/{org}/users/{user_id}/issuers/{entity_id} | 
*CredentialsApi* | [**credentials_orgs_users_issuers_retrieve**](docs/CredentialsApi.md#credentials_orgs_users_issuers_retrieve) | **GET** /api/credentials/orgs/{org}/users/{user_id}/issuers/ | 
*CredentialsApi* | [**credentials_orgs_users_issuers_retrieve2**](docs/CredentialsApi.md#credentials_orgs_users_issuers_retrieve2) | **GET** /api/credentials/orgs/{org}/users/{user_id}/issuers/{entity_id} | 
*CredentialsApi* | [**credentials_orgs_users_issuers_update**](docs/CredentialsApi.md#credentials_orgs_users_issuers_update) | **PUT** /api/credentials/orgs/{org}/users/{user_id}/issuers/{entity_id} | 
*CredentialsApi* | [**credentials_orgs_users_retrieve**](docs/CredentialsApi.md#credentials_orgs_users_retrieve) | **GET** /api/credentials/orgs/{org}/users/{user_id}/ | 
*CredentialsApi* | [**credentials_orgs_users_retrieve2**](docs/CredentialsApi.md#credentials_orgs_users_retrieve2) | **GET** /api/credentials/orgs/{org}/users/{user_id}/{entity_id} | 
*CredentialsApi* | [**credentials_orgs_users_update**](docs/CredentialsApi.md#credentials_orgs_users_update) | **PUT** /api/credentials/orgs/{org}/users/{user_id}/{entity_id} | 
*CredentialsApi* | [**credentials_public_assertions_retrieve**](docs/CredentialsApi.md#credentials_public_assertions_retrieve) | **GET** /api/credentials/public/assertions/{entity_id}/ | 
*DepartmentsApi* | [**departments_orgs_retrieve**](docs/DepartmentsApi.md#departments_orgs_retrieve) | **GET** /api/departments/orgs/{org}/ | 
*EngagementApi* | [**engagement_orgs_activity_retrieve**](docs/EngagementApi.md#engagement_orgs_activity_retrieve) | **GET** /api/engagement/orgs/{org}/activity | 
*EngagementApi* | [**engagement_orgs_course_completion_over_time_retrieve**](docs/EngagementApi.md#engagement_orgs_course_completion_over_time_retrieve) | **GET** /api/engagement/orgs/{org}/course_completion/over-time | 
*EngagementApi* | [**engagement_orgs_course_completion_per_course_retrieve**](docs/EngagementApi.md#engagement_orgs_course_completion_per_course_retrieve) | **GET** /api/engagement/orgs/{org}/course_completion/per-course | 
*EngagementApi* | [**engagement_orgs_courses_time_average_retrieve**](docs/EngagementApi.md#engagement_orgs_courses_time_average_retrieve) | **GET** /api/engagement/orgs/{org}/courses/{course_id}/time/average | 
*EngagementApi* | [**engagement_orgs_courses_time_detail_retrieve**](docs/EngagementApi.md#engagement_orgs_courses_time_detail_retrieve) | **GET** /api/engagement/orgs/{org}/courses/{course_id}/time/detail | 
*EngagementApi* | [**engagement_orgs_courses_time_over_time_retrieve**](docs/EngagementApi.md#engagement_orgs_courses_time_over_time_retrieve) | **GET** /api/engagement/orgs/{org}/courses/{course_id}/time/over-time | 
*EngagementApi* | [**engagement_orgs_courses_time_users_detail_retrieve**](docs/EngagementApi.md#engagement_orgs_courses_time_users_detail_retrieve) | **GET** /api/engagement/orgs/{org}/courses/{course_id}/time/users/{user_id}/detail | 
*EngagementApi* | [**engagement_orgs_courses_time_users_over_time_retrieve**](docs/EngagementApi.md#engagement_orgs_courses_time_users_over_time_retrieve) | **GET** /api/engagement/orgs/{org}/courses/{course_id}/time/users/{user_id}/over-time | 
*EngagementApi* | [**engagement_orgs_courses_time_users_retrieve**](docs/EngagementApi.md#engagement_orgs_courses_time_users_retrieve) | **GET** /api/engagement/orgs/{org}/courses/{course_id}/time/users | 
*EngagementApi* | [**engagement_orgs_courses_videos_over_time_retrieve**](docs/EngagementApi.md#engagement_orgs_courses_videos_over_time_retrieve) | **GET** /api/engagement/orgs/{org}/courses/{course_id}/videos/over-time | 
*EngagementApi* | [**engagement_orgs_courses_videos_retrieve**](docs/EngagementApi.md#engagement_orgs_courses_videos_retrieve) | **GET** /api/engagement/orgs/{org}/courses/{course_id}/videos/ | 
*EngagementApi* | [**engagement_orgs_courses_videos_summary_retrieve**](docs/EngagementApi.md#engagement_orgs_courses_videos_summary_retrieve) | **GET** /api/engagement/orgs/{org}/courses/{course_id}/videos/summary | 
*EngagementApi* | [**engagement_orgs_courses_videos_users_retrieve**](docs/EngagementApi.md#engagement_orgs_courses_videos_users_retrieve) | **GET** /api/engagement/orgs/{org}/courses/{course_id}/videos/users | 
*EngagementApi* | [**engagement_orgs_time_average_perlearner_percourse_retrieve**](docs/EngagementApi.md#engagement_orgs_time_average_perlearner_percourse_retrieve) | **GET** /api/engagement/orgs/{org}/time/average-perlearner-percourse | 
*EngagementApi* | [**engagement_orgs_time_average_with_over_time_retrieve**](docs/EngagementApi.md#engagement_orgs_time_average_with_over_time_retrieve) | **GET** /api/engagement/orgs/{org}/time/average-with-over-time | 
*EngagementApi* | [**engagement_orgs_time_over_time_retrieve**](docs/EngagementApi.md#engagement_orgs_time_over_time_retrieve) | **GET** /api/engagement/orgs/{org}/time/over-time | 
*EngagementApi* | [**engagement_orgs_time_per_course_retrieve**](docs/EngagementApi.md#engagement_orgs_time_per_course_retrieve) | **GET** /api/engagement/orgs/{org}/time/per-course | 
*EngagementApi* | [**engagement_orgs_videos_over_time_retrieve**](docs/EngagementApi.md#engagement_orgs_videos_over_time_retrieve) | **GET** /api/engagement/orgs/{org}/videos/over-time | 
*EngagementApi* | [**engagement_orgs_videos_retrieve**](docs/EngagementApi.md#engagement_orgs_videos_retrieve) | **GET** /api/engagement/orgs/{org}/videos/ | 
*FeaturesApi* | [**features_apps_list**](docs/FeaturesApi.md#features_apps_list) | **GET** /api/features/apps/ | 
*FeaturesApi* | [**features_apps_update_create**](docs/FeaturesApi.md#features_apps_update_create) | **POST** /api/features/apps/update/ | 
*FeaturesApi* | [**features_apps_update_trial_status_create**](docs/FeaturesApi.md#features_apps_update_trial_status_create) | **POST** /api/features/apps/update-trial-status/ | 
*FeaturesApi* | [**features_bulk_config_create**](docs/FeaturesApi.md#features_bulk_config_create) | **POST** /api/features/bulk-config/ | 
*FeaturesApi* | [**features_config_create**](docs/FeaturesApi.md#features_config_create) | **POST** /api/features/config/ | 
*FeaturesApi* | [**features_config_retrieve**](docs/FeaturesApi.md#features_config_retrieve) | **GET** /api/features/config/ | 
*FinanceApi* | [**finance_orgs_products_orders_retrieve**](docs/FinanceApi.md#finance_orgs_products_orders_retrieve) | **GET** /api/finance/orgs/{org}/products/{item_id}/orders | 
*FinanceApi* | [**finance_orgs_products_retrieve**](docs/FinanceApi.md#finance_orgs_products_retrieve) | **GET** /api/finance/orgs/{org}/products | 
*FinanceApi* | [**finance_orgs_products_sales_over_time_retrieve**](docs/FinanceApi.md#finance_orgs_products_sales_over_time_retrieve) | **GET** /api/finance/orgs/{org}/products/{item_id}/sales-over-time | 
*FinanceApi* | [**finance_orgs_revenue_net_over_time_retrieve**](docs/FinanceApi.md#finance_orgs_revenue_net_over_time_retrieve) | **GET** /api/finance/orgs/{org}/revenue/net-over-time | 
*FinanceApi* | [**finance_orgs_revenue_products_retrieve**](docs/FinanceApi.md#finance_orgs_revenue_products_retrieve) | **GET** /api/finance/orgs/{org}/revenue/products | 
*NotificationApi* | [**notification_v1_campaigns_unsubscribe_retrieve**](docs/NotificationApi.md#notification_v1_campaigns_unsubscribe_retrieve) | **GET** /api/notification/v1/campaigns/unsubscribe/{unsubscribe_hash}/ | 
*NotificationApi* | [**notification_v1_orgs_campaigns_enable_create**](docs/NotificationApi.md#notification_v1_orgs_campaigns_enable_create) | **POST** /api/notification/v1/orgs/{platform_key}/campaigns/enable/ | 
*NotificationApi* | [**notification_v1_orgs_campaigns_exclude_create**](docs/NotificationApi.md#notification_v1_orgs_campaigns_exclude_create) | **POST** /api/notification/v1/orgs/{platform_key}/campaigns/exclude/ | 
*NotificationApi* | [**notification_v1_orgs_mark_all_as_read_create**](docs/NotificationApi.md#notification_v1_orgs_mark_all_as_read_create) | **POST** /api/notification/v1/orgs/{platform_key}/mark-all-as-read | 
*NotificationApi* | [**notification_v1_orgs_notifications_bulk_update_partial_update**](docs/NotificationApi.md#notification_v1_orgs_notifications_bulk_update_partial_update) | **PATCH** /api/notification/v1/orgs/{org}/notifications/bulk-update/ | 
*NotificationApi* | [**notification_v1_orgs_notifications_retrieve**](docs/NotificationApi.md#notification_v1_orgs_notifications_retrieve) | **GET** /api/notification/v1/orgs/{org}/notifications/ | 
*NotificationApi* | [**notification_v1_orgs_notifications_update**](docs/NotificationApi.md#notification_v1_orgs_notifications_update) | **PUT** /api/notification/v1/orgs/{org}/notifications/ | 
*NotificationApi* | [**notification_v1_orgs_users_notifications_bulk_update_partial_update**](docs/NotificationApi.md#notification_v1_orgs_users_notifications_bulk_update_partial_update) | **PATCH** /api/notification/v1/orgs/{org}/users/{user_id}/notifications/bulk-update/ | 
*NotificationApi* | [**notification_v1_orgs_users_notifications_count_retrieve**](docs/NotificationApi.md#notification_v1_orgs_users_notifications_count_retrieve) | **GET** /api/notification/v1/orgs/{org}/users/{user_id}/notifications-count/ | 
*NotificationApi* | [**notification_v1_orgs_users_notifications_destroy**](docs/NotificationApi.md#notification_v1_orgs_users_notifications_destroy) | **DELETE** /api/notification/v1/orgs/{org}/users/{user_id}/notifications/{notification_id}/ | 
*NotificationApi* | [**notification_v1_orgs_users_notifications_retrieve**](docs/NotificationApi.md#notification_v1_orgs_users_notifications_retrieve) | **GET** /api/notification/v1/orgs/{org}/users/{user_id}/notifications/ | 
*NotificationApi* | [**notification_v1_orgs_users_notifications_update**](docs/NotificationApi.md#notification_v1_orgs_users_notifications_update) | **PUT** /api/notification/v1/orgs/{org}/users/{user_id}/notifications/ | 
*NotificationBuilderApi* | [**notification_v1_orgs_notification_builder_context_retrieve**](docs/NotificationBuilderApi.md#notification_v1_orgs_notification_builder_context_retrieve) | **GET** /api/notification/v1/orgs/{platform_key}/notification-builder/context/ | Get notification context data
*NotificationBuilderApi* | [**notification_v1_orgs_notification_builder_preview_create**](docs/NotificationBuilderApi.md#notification_v1_orgs_notification_builder_preview_create) | **POST** /api/notification/v1/orgs/{platform_key}/notification-builder/preview/ | Preview notification
*NotificationBuilderApi* | [**notification_v1_orgs_notification_builder_recipients_list**](docs/NotificationBuilderApi.md#notification_v1_orgs_notification_builder_recipients_list) | **GET** /api/notification/v1/orgs/{platform_key}/notification-builder/{id}/recipients/ | Get build recipients
*NotificationBuilderApi* | [**notification_v1_orgs_notification_builder_send_create**](docs/NotificationBuilderApi.md#notification_v1_orgs_notification_builder_send_create) | **POST** /api/notification/v1/orgs/{platform_key}/notification-builder/send/ | Send notification
*NotificationBuilderApi* | [**notification_v1_orgs_notification_builder_validate_source_create**](docs/NotificationBuilderApi.md#notification_v1_orgs_notification_builder_validate_source_create) | **POST** /api/notification/v1/orgs/{platform_key}/notification-builder/validate_source/ | Validate notification source
*OrgsApi* | [**orgs_scim_v2_department_members_create**](docs/OrgsApi.md#orgs_scim_v2_department_members_create) | **POST** /api/orgs/{org}/scim/v2/DepartmentMembers/ | 
*OrgsApi* | [**orgs_scim_v2_department_members_destroy**](docs/OrgsApi.md#orgs_scim_v2_department_members_destroy) | **DELETE** /api/orgs/{org}/scim/v2/DepartmentMembers/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_department_members_retrieve**](docs/OrgsApi.md#orgs_scim_v2_department_members_retrieve) | **GET** /api/orgs/{org}/scim/v2/DepartmentMembers/ | 
*OrgsApi* | [**orgs_scim_v2_department_members_retrieve2**](docs/OrgsApi.md#orgs_scim_v2_department_members_retrieve2) | **GET** /api/orgs/{org}/scim/v2/DepartmentMembers/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_department_members_update**](docs/OrgsApi.md#orgs_scim_v2_department_members_update) | **PUT** /api/orgs/{org}/scim/v2/DepartmentMembers/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_departments_add_members_create**](docs/OrgsApi.md#orgs_scim_v2_departments_add_members_create) | **POST** /api/orgs/{org}/scim/v2/Departments/{id}/add_members/ | 
*OrgsApi* | [**orgs_scim_v2_departments_create**](docs/OrgsApi.md#orgs_scim_v2_departments_create) | **POST** /api/orgs/{org}/scim/v2/Departments/ | 
*OrgsApi* | [**orgs_scim_v2_departments_destroy**](docs/OrgsApi.md#orgs_scim_v2_departments_destroy) | **DELETE** /api/orgs/{org}/scim/v2/Departments/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_departments_remove_members_create**](docs/OrgsApi.md#orgs_scim_v2_departments_remove_members_create) | **POST** /api/orgs/{org}/scim/v2/Departments/{id}/remove_members/ | 
*OrgsApi* | [**orgs_scim_v2_departments_retrieve**](docs/OrgsApi.md#orgs_scim_v2_departments_retrieve) | **GET** /api/orgs/{org}/scim/v2/Departments/ | 
*OrgsApi* | [**orgs_scim_v2_departments_retrieve2**](docs/OrgsApi.md#orgs_scim_v2_departments_retrieve2) | **GET** /api/orgs/{org}/scim/v2/Departments/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_departments_update**](docs/OrgsApi.md#orgs_scim_v2_departments_update) | **PUT** /api/orgs/{org}/scim/v2/Departments/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_group_members_create**](docs/OrgsApi.md#orgs_scim_v2_group_members_create) | **POST** /api/orgs/{org}/scim/v2/GroupMembers/ | 
*OrgsApi* | [**orgs_scim_v2_group_members_destroy**](docs/OrgsApi.md#orgs_scim_v2_group_members_destroy) | **DELETE** /api/orgs/{org}/scim/v2/GroupMembers/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_group_members_retrieve**](docs/OrgsApi.md#orgs_scim_v2_group_members_retrieve) | **GET** /api/orgs/{org}/scim/v2/GroupMembers/ | 
*OrgsApi* | [**orgs_scim_v2_group_members_retrieve2**](docs/OrgsApi.md#orgs_scim_v2_group_members_retrieve2) | **GET** /api/orgs/{org}/scim/v2/GroupMembers/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_group_members_update**](docs/OrgsApi.md#orgs_scim_v2_group_members_update) | **PUT** /api/orgs/{org}/scim/v2/GroupMembers/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_groups_add_members_create**](docs/OrgsApi.md#orgs_scim_v2_groups_add_members_create) | **POST** /api/orgs/{org}/scim/v2/Groups/{id}/add_members/ | 
*OrgsApi* | [**orgs_scim_v2_groups_create**](docs/OrgsApi.md#orgs_scim_v2_groups_create) | **POST** /api/orgs/{org}/scim/v2/Groups/ | 
*OrgsApi* | [**orgs_scim_v2_groups_destroy**](docs/OrgsApi.md#orgs_scim_v2_groups_destroy) | **DELETE** /api/orgs/{org}/scim/v2/Groups/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_groups_remove_members_create**](docs/OrgsApi.md#orgs_scim_v2_groups_remove_members_create) | **POST** /api/orgs/{org}/scim/v2/Groups/{id}/remove_members/ | 
*OrgsApi* | [**orgs_scim_v2_groups_retrieve**](docs/OrgsApi.md#orgs_scim_v2_groups_retrieve) | **GET** /api/orgs/{org}/scim/v2/Groups/ | 
*OrgsApi* | [**orgs_scim_v2_groups_retrieve2**](docs/OrgsApi.md#orgs_scim_v2_groups_retrieve2) | **GET** /api/orgs/{org}/scim/v2/Groups/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_groups_update**](docs/OrgsApi.md#orgs_scim_v2_groups_update) | **PUT** /api/orgs/{org}/scim/v2/Groups/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_users_create**](docs/OrgsApi.md#orgs_scim_v2_users_create) | **POST** /api/orgs/{org}/scim/v2/Users/ | 
*OrgsApi* | [**orgs_scim_v2_users_destroy**](docs/OrgsApi.md#orgs_scim_v2_users_destroy) | **DELETE** /api/orgs/{org}/scim/v2/Users/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_users_retrieve**](docs/OrgsApi.md#orgs_scim_v2_users_retrieve) | **GET** /api/orgs/{org}/scim/v2/Users/ | 
*OrgsApi* | [**orgs_scim_v2_users_retrieve2**](docs/OrgsApi.md#orgs_scim_v2_users_retrieve2) | **GET** /api/orgs/{org}/scim/v2/Users/{id}/ | 
*OrgsApi* | [**orgs_scim_v2_users_update**](docs/OrgsApi.md#orgs_scim_v2_users_update) | **PUT** /api/orgs/{org}/scim/v2/Users/{id}/ | 
*OverviewApi* | [**overview_orgs_active_users_retrieve**](docs/OverviewApi.md#overview_orgs_active_users_retrieve) | **GET** /api/overview/orgs/{org}/active-users | 
*OverviewApi* | [**overview_orgs_average_grade_retrieve**](docs/OverviewApi.md#overview_orgs_average_grade_retrieve) | **GET** /api/overview/orgs/{org}/average-grade | 
*OverviewApi* | [**overview_orgs_courses_completions_retrieve**](docs/OverviewApi.md#overview_orgs_courses_completions_retrieve) | **GET** /api/overview/orgs/{org}/courses/completions | 
*OverviewApi* | [**overview_orgs_learners_retrieve**](docs/OverviewApi.md#overview_orgs_learners_retrieve) | **GET** /api/overview/orgs/{org}/learners | 
*OverviewApi* | [**overview_orgs_most_active_courses_retrieve**](docs/OverviewApi.md#overview_orgs_most_active_courses_retrieve) | **GET** /api/overview/orgs/{org}/most-active-courses | 
*OverviewApi* | [**overview_orgs_registered_users_retrieve**](docs/OverviewApi.md#overview_orgs_registered_users_retrieve) | **GET** /api/overview/orgs/{org}/registered-users | 
*PerformanceApi* | [**performance_orgs_courses_grading_average_retrieve**](docs/PerformanceApi.md#performance_orgs_courses_grading_average_retrieve) | **GET** /api/performance/orgs/{org}/courses/{course_id}/grading/average | 
*PerformanceApi* | [**performance_orgs_courses_grading_average_with_cutoff_retrieve**](docs/PerformanceApi.md#performance_orgs_courses_grading_average_with_cutoff_retrieve) | **GET** /api/performance/orgs/{org}/courses/{course_id}/grading/average-with-cutoff | 
*PerformanceApi* | [**performance_orgs_courses_grading_detail_retrieve**](docs/PerformanceApi.md#performance_orgs_courses_grading_detail_retrieve) | **GET** /api/performance/orgs/{org}/courses/{course_id}/grading/detail | 
*PerformanceApi* | [**performance_orgs_courses_grading_per_learner_retrieve**](docs/PerformanceApi.md#performance_orgs_courses_grading_per_learner_retrieve) | **GET** /api/performance/orgs/{org}/courses/{course_id}/grading/per-learner | 
*PerformanceApi* | [**performance_orgs_courses_grading_summary_retrieve**](docs/PerformanceApi.md#performance_orgs_courses_grading_summary_retrieve) | **GET** /api/performance/orgs/{org}/courses/{course_id}/grading/summary | 
*PerformanceApi* | [**performance_orgs_grading_average_retrieve**](docs/PerformanceApi.md#performance_orgs_grading_average_retrieve) | **GET** /api/performance/orgs/{org}/grading/average | 
*PerformanceApi* | [**performance_orgs_grading_per_course_retrieve**](docs/PerformanceApi.md#performance_orgs_grading_per_course_retrieve) | **GET** /api/performance/orgs/{org}/grading/per-course | 
*PerlearnerApi* | [**perlearner_orgs_learners_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_learners_retrieve) | **GET** /api/perlearner/orgs/{org}/learners | 
*PerlearnerApi* | [**perlearner_orgs_users_activity_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_activity_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/activity/ | 
*PerlearnerApi* | [**perlearner_orgs_users_courses_grading_cutoffs_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_courses_grading_cutoffs_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/grading/cutoffs | 
*PerlearnerApi* | [**perlearner_orgs_users_courses_grading_detail_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_courses_grading_detail_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/grading/detail | 
*PerlearnerApi* | [**perlearner_orgs_users_courses_grading_summary_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_courses_grading_summary_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/grading/summary | 
*PerlearnerApi* | [**perlearner_orgs_users_courses_overview_engagement_index_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_courses_overview_engagement_index_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/overview/engagement-index | 
*PerlearnerApi* | [**perlearner_orgs_users_courses_overview_grade_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_courses_overview_grade_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/overview/grade | 
*PerlearnerApi* | [**perlearner_orgs_users_courses_overview_performance_index_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_courses_overview_performance_index_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/overview/performance-index | 
*PerlearnerApi* | [**perlearner_orgs_users_courses_overview_time_over_time_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_courses_overview_time_over_time_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/overview/time/over-time | 
*PerlearnerApi* | [**perlearner_orgs_users_courses_videos_over_time_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_courses_videos_over_time_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/videos/over-time | 
*PerlearnerApi* | [**perlearner_orgs_users_courses_videos_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_courses_videos_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/videos | 
*PerlearnerApi* | [**perlearner_orgs_users_grades_per_course_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_grades_per_course_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/grades/per-course | 
*PerlearnerApi* | [**perlearner_orgs_users_info_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_info_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/info | 
*PerlearnerApi* | [**perlearner_orgs_users_last_access_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_last_access_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/last-access | 
*PerlearnerApi* | [**perlearner_orgs_users_overview_engagement_index_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_overview_engagement_index_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/overview/engagement-index | 
*PerlearnerApi* | [**perlearner_orgs_users_overview_grades_average_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_overview_grades_average_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/overview/grades/average | 
*PerlearnerApi* | [**perlearner_orgs_users_overview_performance_index_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_overview_performance_index_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/overview/performance-index | 
*PerlearnerApi* | [**perlearner_orgs_users_overview_time_over_time_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_overview_time_over_time_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/overview/time/over-time | 
*PerlearnerApi* | [**perlearner_orgs_users_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_retrieve) | **GET** /api/perlearner/orgs/{org}/users | 
*PerlearnerApi* | [**perlearner_orgs_users_videos_over_time_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_videos_over_time_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/videos/over-time | 
*PerlearnerApi* | [**perlearner_orgs_users_videos_per_course_retrieve**](docs/PerlearnerApi.md#perlearner_orgs_users_videos_per_course_retrieve) | **GET** /api/perlearner/orgs/{org}/users/{user_id}/videos/per-course | 
*PlatformApi* | [**platform_orgs_courses_count_retrieve**](docs/PlatformApi.md#platform_orgs_courses_count_retrieve) | **GET** /api/platform/orgs/{org}/courses/count | 
*PlatformApi* | [**platform_orgs_courses_grades_retrieve**](docs/PlatformApi.md#platform_orgs_courses_grades_retrieve) | **GET** /api/platform/orgs/{org}/courses/grades | 
*PlatformApi* | [**platform_orgs_courses_progress_average_days_to_complete_retrieve**](docs/PlatformApi.md#platform_orgs_courses_progress_average_days_to_complete_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/progress/average-days-to-complete | 
*PlatformApi* | [**platform_orgs_courses_progress_average_time_to_complete_retrieve**](docs/PlatformApi.md#platform_orgs_courses_progress_average_time_to_complete_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/progress/average-time-to-complete | 
*PlatformApi* | [**platform_orgs_courses_progress_completed_retrieve**](docs/PlatformApi.md#platform_orgs_courses_progress_completed_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/progress/completed | 
*PlatformApi* | [**platform_orgs_courses_progress_completion_rate_retrieve**](docs/PlatformApi.md#platform_orgs_courses_progress_completion_rate_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/progress/completion-rate | 
*PlatformApi* | [**platform_orgs_courses_progress_in_progress_retrieve**](docs/PlatformApi.md#platform_orgs_courses_progress_in_progress_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/progress/in-progress | 
*PlatformApi* | [**platform_orgs_courses_progress_retrieve**](docs/PlatformApi.md#platform_orgs_courses_progress_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/progress/ | 
*PlatformApi* | [**platform_orgs_courses_progress_started_retrieve**](docs/PlatformApi.md#platform_orgs_courses_progress_started_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/progress/started | 
*PlatformApi* | [**platform_orgs_courses_users_grades_passed_retrieve**](docs/PlatformApi.md#platform_orgs_courses_users_grades_passed_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/users/{user_id}/grades/passed | 
*PlatformApi* | [**platform_orgs_courses_users_progress_days_to_complete_retrieve**](docs/PlatformApi.md#platform_orgs_courses_users_progress_days_to_complete_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/users/{user_id}/progress/days-to-complete | 
*PlatformApi* | [**platform_orgs_courses_users_progress_retrieve**](docs/PlatformApi.md#platform_orgs_courses_users_progress_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/users/{user_id}/progress | 
*PlatformApi* | [**platform_orgs_courses_users_time_count_retrieve**](docs/PlatformApi.md#platform_orgs_courses_users_time_count_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/users/{user_id}/time/count | 
*PlatformApi* | [**platform_orgs_courses_users_videos_count_retrieve**](docs/PlatformApi.md#platform_orgs_courses_users_videos_count_retrieve) | **GET** /api/platform/orgs/{org}/courses/{course_id}/users/{user_id}/videos/count | 
*PlatformApi* | [**platform_orgs_courses_videos_retrieve**](docs/PlatformApi.md#platform_orgs_courses_videos_retrieve) | **GET** /api/platform/orgs/{org}/courses/videos | 
*PlatformApi* | [**platform_orgs_courses_videos_retrieve2**](docs/PlatformApi.md#platform_orgs_courses_videos_retrieve2) | **GET** /api/platform/orgs/{org}/courses/{course_id}/videos/ | 
*PlatformApi* | [**platform_orgs_progress_completed_retrieve**](docs/PlatformApi.md#platform_orgs_progress_completed_retrieve) | **GET** /api/platform/orgs/{org}/progress/completed | 
*PlatformApi* | [**platform_orgs_progress_completion_rate_retrieve**](docs/PlatformApi.md#platform_orgs_progress_completion_rate_retrieve) | **GET** /api/platform/orgs/{org}/progress/completion-rate | 
*PlatformApi* | [**platform_orgs_progress_in_progress_retrieve**](docs/PlatformApi.md#platform_orgs_progress_in_progress_retrieve) | **GET** /api/platform/orgs/{org}/progress/in-progress | 
*PlatformApi* | [**platform_orgs_progress_started_retrieve**](docs/PlatformApi.md#platform_orgs_progress_started_retrieve) | **GET** /api/platform/orgs/{org}/progress/started | 
*PlatformApi* | [**platform_orgs_retrieve**](docs/PlatformApi.md#platform_orgs_retrieve) | **GET** /api/platform/orgs/{org}/ | 
*PlatformApi* | [**platform_orgs_time_count_retrieve**](docs/PlatformApi.md#platform_orgs_time_count_retrieve) | **GET** /api/platform/orgs/{org}/time/count | 
*PlatformApi* | [**platform_orgs_users_active_count_retrieve**](docs/PlatformApi.md#platform_orgs_users_active_count_retrieve) | **GET** /api/platform/orgs/{org}/users/active/count | 
*PlatformApi* | [**platform_orgs_users_count_retrieve**](docs/PlatformApi.md#platform_orgs_users_count_retrieve) | **GET** /api/platform/orgs/{org}/users/count | 
*PlatformApi* | [**platform_orgs_users_courses_completed_count_retrieve**](docs/PlatformApi.md#platform_orgs_users_courses_completed_count_retrieve) | **GET** /api/platform/orgs/{org}/users/courses-completed/count | 
*ProviderAssociationApi* | [**provider_association_stripe_callback_retrieve**](docs/ProviderAssociationApi.md#provider_association_stripe_callback_retrieve) | **GET** /api/provider-association/stripe/callback/{launch_id}/ | 
*ProvidersApi* | [**providers_apple_associate_account_create**](docs/ProvidersApi.md#providers_apple_associate_account_create) | **POST** /api/providers/apple/associate-account/ | 
*ProvidersApi* | [**providers_apple_hook_create**](docs/ProvidersApi.md#providers_apple_hook_create) | **POST** /api/providers/apple/hook/ | 
*ProvidersApi* | [**providers_apple_subscription_status_create**](docs/ProvidersApi.md#providers_apple_subscription_status_create) | **POST** /api/providers/apple/subscription-status/ | 
*ProvidersApi* | [**providers_apple_validate_transaction_id_create**](docs/ProvidersApi.md#providers_apple_validate_transaction_id_create) | **POST** /api/providers/apple/validate-transaction-id/ | 
*ProvidersApi* | [**providers_aws_create_organization_create**](docs/ProvidersApi.md#providers_aws_create_organization_create) | **POST** /api/providers/aws/create-organization/ | 
*ProvidersApi* | [**providers_aws_domain_status_retrieve**](docs/ProvidersApi.md#providers_aws_domain_status_retrieve) | **GET** /api/providers/aws/domain-status/ | 
*ProvidersApi* | [**providers_aws_launch_tenant_create**](docs/ProvidersApi.md#providers_aws_launch_tenant_create) | **POST** /api/providers/aws/launch-tenant/ | 
*ProvidersApi* | [**providers_aws_sync_domain_records_create**](docs/ProvidersApi.md#providers_aws_sync_domain_records_create) | **POST** /api/providers/aws/sync-domain-records/ | 
*ProvidersApi* | [**providers_aws_sync_domain_records_retrieve**](docs/ProvidersApi.md#providers_aws_sync_domain_records_retrieve) | **GET** /api/providers/aws/sync-domain-records/ | 
*ProvidersApi* | [**providers_gcp_create_organization_create**](docs/ProvidersApi.md#providers_gcp_create_organization_create) | **POST** /api/providers/gcp/create-organization/ | 
*ProvidersApi* | [**providers_gcp_create_organization_create2**](docs/ProvidersApi.md#providers_gcp_create_organization_create2) | **POST** /api/providers/gcp/create-organization/{product_id}/ | 
*ProvidersApi* | [**providers_gcp_hook_create**](docs/ProvidersApi.md#providers_gcp_hook_create) | **POST** /api/providers/gcp/hook/ | 
*ProvidersApi* | [**providers_gcp_launch_tenant_create**](docs/ProvidersApi.md#providers_gcp_launch_tenant_create) | **POST** /api/providers/gcp/launch-tenant/ | 
*ProvidersApi* | [**providers_gcp_validate_signup_token_create**](docs/ProvidersApi.md#providers_gcp_validate_signup_token_create) | **POST** /api/providers/gcp/validate-signup-token/ | 
*ProvidersApi* | [**providers_google_pay_get_account_retrieve**](docs/ProvidersApi.md#providers_google_pay_get_account_retrieve) | **GET** /api/providers/google-pay/get-account/{bundle_id} | 
*ProvidersApi* | [**providers_google_pay_hook_create**](docs/ProvidersApi.md#providers_google_pay_hook_create) | **POST** /api/providers/google-pay/hook/ | 
*ProvidersApi* | [**providers_google_pay_validate_transaction_id_create**](docs/ProvidersApi.md#providers_google_pay_validate_transaction_id_create) | **POST** /api/providers/google-pay/validate-transaction-id/ | 
*ProvidersApi* | [**providers_stripe_create_organization_create**](docs/ProvidersApi.md#providers_stripe_create_organization_create) | **POST** /api/providers/stripe/create-organization/ | 
*ProvisionApi* | [**provision_create**](docs/ProvisionApi.md#provision_create) | **POST** /api/provision/{config_name}/ | 
*RecommendationsApi* | [**recommendations_orgs_users_retrieve**](docs/RecommendationsApi.md#recommendations_orgs_users_retrieve) | **GET** /api/recommendations/orgs/{org}/users/{user_id}/ | 
*ReportsApi* | [**reports_orgs_new_create**](docs/ReportsApi.md#reports_orgs_new_create) | **POST** /api/reports/orgs/{org}/new | 
*ReportsApi* | [**reports_orgs_retrieve**](docs/ReportsApi.md#reports_orgs_retrieve) | **GET** /api/reports/orgs/{org}/ | 
*ReportsApi* | [**reports_orgs_retrieve2**](docs/ReportsApi.md#reports_orgs_retrieve2) | **GET** /api/reports/orgs/{org}/{report_name} | 
*ReportsApi* | [**reports_platforms_new_create**](docs/ReportsApi.md#reports_platforms_new_create) | **POST** /api/reports/platforms/{key}/new | 
*ReportsApi* | [**reports_platforms_retrieve**](docs/ReportsApi.md#reports_platforms_retrieve) | **GET** /api/reports/platforms/{key}/ | 
*ReportsApi* | [**reports_platforms_retrieve2**](docs/ReportsApi.md#reports_platforms_retrieve2) | **GET** /api/reports/platforms/{key}/{report_name} | 
*RolesApi* | [**roles_platform_orgs_roles_users_desired_roles_retrieve**](docs/RolesApi.md#roles_platform_orgs_roles_users_desired_roles_retrieve) | **GET** /api/roles/platform/orgs/{org}/roles/users/{username}/desired-roles/ | 
*RolesApi* | [**roles_platform_orgs_roles_users_reported_roles_retrieve**](docs/RolesApi.md#roles_platform_orgs_roles_users_reported_roles_retrieve) | **GET** /api/roles/platform/orgs/{org}/roles/users/{username}/reported-roles/ | 
*SearchApi* | [**search_ai_search_retrieve**](docs/SearchApi.md#search_ai_search_retrieve) | **GET** /api/search/ai-search/ | 
*SearchApi* | [**search_catalog_retrieve**](docs/SearchApi.md#search_catalog_retrieve) | **GET** /api/search/catalog/ | 
*SearchApi* | [**search_mentors_documents_retrieve**](docs/SearchApi.md#search_mentors_documents_retrieve) | **GET** /api/search/mentors/{mentor_unique_id}/documents/ | 
*SearchApi* | [**search_mentors_retrieve**](docs/SearchApi.md#search_mentors_retrieve) | **GET** /api/search/mentors/ | 
*SearchApi* | [**search_orgs_users_mentors_retrieve**](docs/SearchApi.md#search_orgs_users_mentors_retrieve) | **GET** /api/search/orgs/{org}/users/{username}/mentors/ | 
*SearchApi* | [**search_orgs_users_prompts_retrieve**](docs/SearchApi.md#search_orgs_users_prompts_retrieve) | **GET** /api/search/orgs/{org}/users/{username}/prompts/ | 
*SearchApi* | [**search_orgs_users_recommended_retrieve**](docs/SearchApi.md#search_orgs_users_recommended_retrieve) | **GET** /api/search/orgs/{org}/users/{username}/recommended/ | 
*SearchApi* | [**search_personalized_catalog_retrieve**](docs/SearchApi.md#search_personalized_catalog_retrieve) | **GET** /api/search/personalized-catalog/{username}/ | 
*SearchApi* | [**search_prompts_retrieve**](docs/SearchApi.md#search_prompts_retrieve) | **GET** /api/search/prompts/ | 
*SearchApi* | [**search_users_orgs_users_retrieve**](docs/SearchApi.md#search_users_orgs_users_retrieve) | **GET** /api/search/users/orgs/{org}/users/{username}/ | 
*ServiceApi* | [**service_launch_tenant_create**](docs/ServiceApi.md#service_launch_tenant_create) | **POST** /api/service/launch/tenant/ | 
*ServiceApi* | [**service_manage_user_create**](docs/ServiceApi.md#service_manage_user_create) | **POST** /api/service/manage/user/ | 
*ServiceApi* | [**service_manage_user_role_create**](docs/ServiceApi.md#service_manage_user_role_create) | **POST** /api/service/manage/user/role/ | 
*ServiceApi* | [**service_orgs_stripe_course_payment_callback_retrieve**](docs/ServiceApi.md#service_orgs_stripe_course_payment_callback_retrieve) | **GET** /api/service/orgs/{platform_key}/stripe/course-payment-callback/ | 
*ServiceApi* | [**service_orgs_users_stripe_checkout_session_create**](docs/ServiceApi.md#service_orgs_users_stripe_checkout_session_create) | **POST** /api/service/orgs/{org}/users/{user_id}/stripe/checkout-session/ | 
*ServiceApi* | [**service_orgs_users_stripe_customer_portal_create**](docs/ServiceApi.md#service_orgs_users_stripe_customer_portal_create) | **POST** /api/service/orgs/{org}/users/{user_id}/stripe/customer-portal/ | 
*ServiceApi* | [**service_orgs_users_stripe_products_manage_create**](docs/ServiceApi.md#service_orgs_users_stripe_products_manage_create) | **POST** /api/service/orgs/{org}/users/{user_id}/stripe/products/manage/ | 
*ServiceApi* | [**service_orgs_users_stripe_products_retrieve**](docs/ServiceApi.md#service_orgs_users_stripe_products_retrieve) | **GET** /api/service/orgs/{org}/users/{user_id}/stripe/products/ | 
*ServiceApi* | [**service_orgs_users_stripe_subscription_renewal_create**](docs/ServiceApi.md#service_orgs_users_stripe_subscription_renewal_create) | **POST** /api/service/orgs/{org}/users/{user_id}/stripe/subscription-renewal/ | 
*ServiceApi* | [**service_orgs_users_stripe_subscriptions_retrieve**](docs/ServiceApi.md#service_orgs_users_stripe_subscriptions_retrieve) | **GET** /api/service/orgs/{org}/users/{user_id}/stripe/subscriptions/ | 
*ServiceApi* | [**service_platforms_stripe_context_retrieve**](docs/ServiceApi.md#service_platforms_stripe_context_retrieve) | **GET** /api/service/platforms/{platform_key}/stripe/context/ | 
*ServiceApi* | [**service_platforms_stripe_credit_topup_callback_retrieve**](docs/ServiceApi.md#service_platforms_stripe_credit_topup_callback_retrieve) | **GET** /api/service/platforms/{platform_key}/stripe/credit-topup-callback/{checkout_session_id}/ | 
*ServiceApi* | [**service_platforms_stripe_pricing_page_callback_retrieve**](docs/ServiceApi.md#service_platforms_stripe_pricing_page_callback_retrieve) | **GET** /api/service/platforms/{platform_key}/stripe/pricing-page-callback/{checkout_session_id}/ | 
*ServiceApi* | [**service_platforms_stripe_pricing_page_session_retrieve**](docs/ServiceApi.md#service_platforms_stripe_pricing_page_session_retrieve) | **GET** /api/service/platforms/{platform_key}/stripe/pricing-page-session/ | 
*ServiceApi* | [**service_stripe_checkout_free_trial_create**](docs/ServiceApi.md#service_stripe_checkout_free_trial_create) | **POST** /api/service/stripe/checkout/free-trial/ | 
*ServiceApi* | [**service_stripe_checkout_retrieve**](docs/ServiceApi.md#service_stripe_checkout_retrieve) | **GET** /api/service/stripe/checkout/{checkout_uuid}/ | 
*ServiceApi* | [**service_tenant_validation_create**](docs/ServiceApi.md#service_tenant_validation_create) | **POST** /api/service/tenant/validation/ | 
*ServiceApi* | [**service_token_retrieve**](docs/ServiceApi.md#service_token_retrieve) | **GET** /api/service/token/ | 
*ServiceApi* | [**service_user_validation_create**](docs/ServiceApi.md#service_user_validation_create) | **POST** /api/service/user/validation/ | 
*SkillsApi* | [**skills_orgs_skills_list**](docs/SkillsApi.md#skills_orgs_skills_list) | **GET** /api/skills/orgs/{org}/skills | 
*SkillsApi* | [**skills_orgs_skills_percentile_list**](docs/SkillsApi.md#skills_orgs_skills_percentile_list) | **GET** /api/skills/orgs/{org}/skills/percentile/ | 
*SkillsApi* | [**skills_orgs_skills_percentile_retrieve**](docs/SkillsApi.md#skills_orgs_skills_percentile_retrieve) | **GET** /api/skills/orgs/{org}/skills/{skill_id}/percentile/ | 
*SkillsApi* | [**skills_orgs_skills_retrieve**](docs/SkillsApi.md#skills_orgs_skills_retrieve) | **GET** /api/skills/orgs/{org}/skills/{skill_name}/ | 
*SkillsApi* | [**skills_orgs_skills_thresholds_create**](docs/SkillsApi.md#skills_orgs_skills_thresholds_create) | **POST** /api/skills/orgs/{org}/skills/thresholds/ | 
*SkillsApi* | [**skills_orgs_skills_thresholds_destroy**](docs/SkillsApi.md#skills_orgs_skills_thresholds_destroy) | **DELETE** /api/skills/orgs/{org}/skills/thresholds/ | 
*SkillsApi* | [**skills_orgs_skills_thresholds_partial_update**](docs/SkillsApi.md#skills_orgs_skills_thresholds_partial_update) | **PATCH** /api/skills/orgs/{org}/skills/thresholds/ | 
*SkillsApi* | [**skills_orgs_skills_thresholds_retrieve**](docs/SkillsApi.md#skills_orgs_skills_thresholds_retrieve) | **GET** /api/skills/orgs/{org}/skills/thresholds/ | 
*SkillsApi* | [**skills_orgs_skills_users_desired_skills_retrieve**](docs/SkillsApi.md#skills_orgs_skills_users_desired_skills_retrieve) | **GET** /api/skills/orgs/{org}/skills/users/{user_id}/desired-skills/ | 
*SkillsApi* | [**skills_orgs_skills_users_point_percentile_retrieve**](docs/SkillsApi.md#skills_orgs_skills_users_point_percentile_retrieve) | **GET** /api/skills/orgs/{org}/skills/users/{user_id}/point-percentile/ | 
*SkillsApi* | [**skills_orgs_skills_users_reported_skills_retrieve**](docs/SkillsApi.md#skills_orgs_skills_users_reported_skills_retrieve) | **GET** /api/skills/orgs/{org}/skills/users/{user_id}/reported-skills/ | 
*SkillsApi* | [**skills_orgs_skills_users_retrieve**](docs/SkillsApi.md#skills_orgs_skills_users_retrieve) | **GET** /api/skills/orgs/{org}/skills/users/{user_id}/ | 
*UserGroupsApi* | [**user_groups_orgs_retrieve**](docs/UserGroupsApi.md#user_groups_orgs_retrieve) | **GET** /api/user-groups/orgs/{key}/ | 


## Documentation For Models

 - [AIGeneratedImage](docs/AIGeneratedImage.md)
 - [AIUserProfileMemoryRelation](docs/AIUserProfileMemoryRelation.md)
 - [AIUserProfileRequest](docs/AIUserProfileRequest.md)
 - [APITokenCost](docs/APITokenCost.md)
 - [AWSTenantLaunchRequest](docs/AWSTenantLaunchRequest.md)
 - [AcceptanceEnum](docs/AcceptanceEnum.md)
 - [AccessEnum](docs/AccessEnum.md)
 - [ActivateUserFreeTrial](docs/ActivateUserFreeTrial.md)
 - [ActiveUsersData](docs/ActiveUsersData.md)
 - [ActiveUsersList](docs/ActiveUsersList.md)
 - [ActiveUsersPerCourse](docs/ActiveUsersPerCourse.md)
 - [ActiveUsersPerCourseData](docs/ActiveUsersPerCourseData.md)
 - [ActivityAPI](docs/ActivityAPI.md)
 - [ActivityData](docs/ActivityData.md)
 - [AiAccountOrgsUseDefaultLlmKeyCreate200Response](docs/AiAccountOrgsUseDefaultLlmKeyCreate200Response.md)
 - [AiAccountOrgsUsersFreeTrialRetrieve200Response](docs/AiAccountOrgsUsersFreeTrialRetrieve200Response.md)
 - [AlignMentorBubbleEnum](docs/AlignMentorBubbleEnum.md)
 - [AnalyticsOverview](docs/AnalyticsOverview.md)
 - [Answer](docs/Answer.md)
 - [App](docs/App.md)
 - [AppleSubscriptionStatusRequest](docs/AppleSubscriptionStatusRequest.md)
 - [AppleSubscriptionStatusView](docs/AppleSubscriptionStatusView.md)
 - [AppleVerifyTransactionId](docs/AppleVerifyTransactionId.md)
 - [Assertion](docs/Assertion.md)
 - [AssociateAccountResponse](docs/AssociateAccountResponse.md)
 - [AssociateAppleAccount](docs/AssociateAppleAccount.md)
 - [AssumedKnowledge](docs/AssumedKnowledge.md)
 - [AssumedKnowledgeLevel](docs/AssumedKnowledgeLevel.md)
 - [AudioToTextRequest](docs/AudioToTextRequest.md)
 - [AudioToTextResponse](docs/AudioToTextResponse.md)
 - [AuthToken](docs/AuthToken.md)
 - [Average](docs/Average.md)
 - [AverageData](docs/AverageData.md)
 - [AverageOvertime](docs/AverageOvertime.md)
 - [AvgCourseGradeWithCutoff](docs/AvgCourseGradeWithCutoff.md)
 - [AvgCourseGradeWithCutoffData](docs/AvgCourseGradeWithCutoffData.md)
 - [BaseErrorResponse](docs/BaseErrorResponse.md)
 - [BaseResponse](docs/BaseResponse.md)
 - [BlankCourseInvitationCreate](docs/BlankCourseInvitationCreate.md)
 - [BlankEnum](docs/BlankEnum.md)
 - [BlankPlatformInvitationCreate](docs/BlankPlatformInvitationCreate.md)
 - [BlankProgramInvitationCreate](docs/BlankProgramInvitationCreate.md)
 - [BlockSkillPointInfoRequest](docs/BlockSkillPointInfoRequest.md)
 - [Bot](docs/Bot.md)
 - [BotCommand](docs/BotCommand.md)
 - [BotCreate](docs/BotCreate.md)
 - [BulkCourseInvitationCreate](docs/BulkCourseInvitationCreate.md)
 - [BulkCourseInvitationResponse](docs/BulkCourseInvitationResponse.md)
 - [BulkCreateAssertion](docs/BulkCreateAssertion.md)
 - [BulkPlatformInvitationCreate](docs/BulkPlatformInvitationCreate.md)
 - [BulkPlatformInvitationResponse](docs/BulkPlatformInvitationResponse.md)
 - [BulkProgramInvitationCreate](docs/BulkProgramInvitationCreate.md)
 - [BulkProgramInvitationResponse](docs/BulkProgramInvitationResponse.md)
 - [BulkSuggestionResponse](docs/BulkSuggestionResponse.md)
 - [CallAuthenticationRequest](docs/CallAuthenticationRequest.md)
 - [CallAuthenticationResponse](docs/CallAuthenticationResponse.md)
 - [CallConfiguration](docs/CallConfiguration.md)
 - [CallConfigurationModeEnum](docs/CallConfigurationModeEnum.md)
 - [CampaignEnablement](docs/CampaignEnablement.md)
 - [CampaignExclusion](docs/CampaignExclusion.md)
 - [CatalogAutoIncrementResponse](docs/CatalogAutoIncrementResponse.md)
 - [CatalogAutoIncrementUpdateRequest](docs/CatalogAutoIncrementUpdateRequest.md)
 - [CeleryHeartbeat](docs/CeleryHeartbeat.md)
 - [CeleryHeartbeatFail](docs/CeleryHeartbeatFail.md)
 - [CeleryHeartbeatFailStatusEnum](docs/CeleryHeartbeatFailStatusEnum.md)
 - [CeleryHeartbeatStatusEnum](docs/CeleryHeartbeatStatusEnum.md)
 - [ChatHistory](docs/ChatHistory.md)
 - [ChatHistoryFilterData](docs/ChatHistoryFilterData.md)
 - [ChatHistoryFilterUser](docs/ChatHistoryFilterUser.md)
 - [ChatHistoryItem](docs/ChatHistoryItem.md)
 - [ChatHistorySessionId](docs/ChatHistorySessionId.md)
 - [ChatSessionRequest](docs/ChatSessionRequest.md)
 - [ChatSessionResponse](docs/ChatSessionResponse.md)
 - [CheckDocumentTrainingStatus](docs/CheckDocumentTrainingStatus.md)
 - [Company](docs/Company.md)
 - [ComponentBlock](docs/ComponentBlock.md)
 - [ComponentBlockTypeEnum](docs/ComponentBlockTypeEnum.md)
 - [ContextResponse](docs/ContextResponse.md)
 - [ConversationMessage](docs/ConversationMessage.md)
 - [ConversationRating](docs/ConversationRating.md)
 - [ConversationSummary](docs/ConversationSummary.md)
 - [ConversationVolume](docs/ConversationVolume.md)
 - [Conversations](docs/Conversations.md)
 - [Cost](docs/Cost.md)
 - [CostPerTenant](docs/CostPerTenant.md)
 - [Count](docs/Count.md)
 - [CountData](docs/CountData.md)
 - [Course](docs/Course.md)
 - [CourseAccessRequestCreate](docs/CourseAccessRequestCreate.md)
 - [CourseAccessRequestDetail](docs/CourseAccessRequestDetail.md)
 - [CourseAccessRequestStatusResponse](docs/CourseAccessRequestStatusResponse.md)
 - [CourseAccessRequestUpdate](docs/CourseAccessRequestUpdate.md)
 - [CourseCompletion](docs/CourseCompletion.md)
 - [CourseCompletionPerCourse](docs/CourseCompletionPerCourse.md)
 - [CourseCompletionPerCourseData](docs/CourseCompletionPerCourseData.md)
 - [CourseCompletionSummaryDataOvertime](docs/CourseCompletionSummaryDataOvertime.md)
 - [CourseCompletionSummaryOvertime](docs/CourseCompletionSummaryOvertime.md)
 - [CourseCreateUpdate](docs/CourseCreateUpdate.md)
 - [CourseCreationTask](docs/CourseCreationTask.md)
 - [CourseCreationTaskFile](docs/CourseCreationTaskFile.md)
 - [CourseCreationTaskStatusEnum](docs/CourseCreationTaskStatusEnum.md)
 - [CourseDeleteResponse](docs/CourseDeleteResponse.md)
 - [CourseEnrollmentSearchResponse](docs/CourseEnrollmentSearchResponse.md)
 - [CourseGradeDetailBlock](docs/CourseGradeDetailBlock.md)
 - [CourseGradeDetailSubSection](docs/CourseGradeDetailSubSection.md)
 - [CourseGradeSummary](docs/CourseGradeSummary.md)
 - [CourseGradeSummaryData](docs/CourseGradeSummaryData.md)
 - [CourseGradingDetail](docs/CourseGradingDetail.md)
 - [CourseGradingDetailData](docs/CourseGradingDetailData.md)
 - [CourseGroupSuggestionCreate](docs/CourseGroupSuggestionCreate.md)
 - [CourseGroupSuggestionDetail](docs/CourseGroupSuggestionDetail.md)
 - [CourseInvitationCreate](docs/CourseInvitationCreate.md)
 - [CourseInvitationDetail](docs/CourseInvitationDetail.md)
 - [CourseInvitationRedemption](docs/CourseInvitationRedemption.md)
 - [CourseLicenseAssignmentCreate](docs/CourseLicenseAssignmentCreate.md)
 - [CourseLicenseAssignmentDetail](docs/CourseLicenseAssignmentDetail.md)
 - [CourseLicenseCreate](docs/CourseLicenseCreate.md)
 - [CourseLicenseDetail](docs/CourseLicenseDetail.md)
 - [CourseLicenseGroupAssignmentCreate](docs/CourseLicenseGroupAssignmentCreate.md)
 - [CourseLicenseGroupAssignmentDetail](docs/CourseLicenseGroupAssignmentDetail.md)
 - [CourseLicenseUpdate](docs/CourseLicenseUpdate.md)
 - [CourseMetadataSearchRequest](docs/CourseMetadataSearchRequest.md)
 - [CourseMetadataUpdateRequest](docs/CourseMetadataUpdateRequest.md)
 - [CoursePoint](docs/CoursePoint.md)
 - [CourseReviewInfoResponse](docs/CourseReviewInfoResponse.md)
 - [CourseReviewPaginatedResponse](docs/CourseReviewPaginatedResponse.md)
 - [CourseReviewRequest](docs/CourseReviewRequest.md)
 - [CourseReviewResponse](docs/CourseReviewResponse.md)
 - [CourseSkill](docs/CourseSkill.md)
 - [CourseSkillPointInfoRequest](docs/CourseSkillPointInfoRequest.md)
 - [CourseSuggestionBulkCreate](docs/CourseSuggestionBulkCreate.md)
 - [CourseSuggestionCreate](docs/CourseSuggestionCreate.md)
 - [CourseSuggestionDetail](docs/CourseSuggestionDetail.md)
 - [Credential](docs/Credential.md)
 - [CredentialRequest](docs/CredentialRequest.md)
 - [CrontabSchedule](docs/CrontabSchedule.md)
 - [CustomInstructionResponse](docs/CustomInstructionResponse.md)
 - [DataSet](docs/DataSet.md)
 - [DataSetCreate](docs/DataSetCreate.md)
 - [DataSetPlatformValue](docs/DataSetPlatformValue.md)
 - [DataSetStatusEnum](docs/DataSetStatusEnum.md)
 - [DateRange](docs/DateRange.md)
 - [DesiredRole](docs/DesiredRole.md)
 - [DesiredRoleCreateUpdateRequest](docs/DesiredRoleCreateUpdateRequest.md)
 - [DesiredSkill](docs/DesiredSkill.md)
 - [DesiredSkillCreateUpdateRequest](docs/DesiredSkillCreateUpdateRequest.md)
 - [DetailedGradeSubsection](docs/DetailedGradeSubsection.md)
 - [DetailedGradeView](docs/DetailedGradeView.md)
 - [DetailedGradeViewData](docs/DetailedGradeViewData.md)
 - [DiscordConfig](docs/DiscordConfig.md)
 - [DiscordUserConfig](docs/DiscordUserConfig.md)
 - [DiscordWebhook](docs/DiscordWebhook.md)
 - [Document](docs/Document.md)
 - [DocumentFacet](docs/DocumentFacet.md)
 - [DocumentSearchResponse](docs/DocumentSearchResponse.md)
 - [DocumentSettingsResponse](docs/DocumentSettingsResponse.md)
 - [Education](docs/Education.md)
 - [EdxCourse](docs/EdxCourse.md)
 - [EdxSignalReceiverRequest](docs/EdxSignalReceiverRequest.md)
 - [ElevenlabsCustomVoice](docs/ElevenlabsCustomVoice.md)
 - [ElevenlabsCustomVoiceResponse](docs/ElevenlabsCustomVoiceResponse.md)
 - [EmailPromptDetail](docs/EmailPromptDetail.md)
 - [EmailPromptList](docs/EmailPromptList.md)
 - [EmailPromptSummary](docs/EmailPromptSummary.md)
 - [EngagementPerCourse](docs/EngagementPerCourse.md)
 - [EngagementPerCourseData](docs/EngagementPerCourseData.md)
 - [Enrollments](docs/Enrollments.md)
 - [EnrollmentsData](docs/EnrollmentsData.md)
 - [EnrollmentsPerUser](docs/EnrollmentsPerUser.md)
 - [EnrollmentsPerUserData](docs/EnrollmentsPerUserData.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [Experience](docs/Experience.md)
 - [FloatOverTime](docs/FloatOverTime.md)
 - [FreeUsageCount](docs/FreeUsageCount.md)
 - [FullCourse](docs/FullCourse.md)
 - [GCPTenantLaunchRequest](docs/GCPTenantLaunchRequest.md)
 - [GlobalCatalogSearchResponse](docs/GlobalCatalogSearchResponse.md)
 - [GooglePayAccountResponse](docs/GooglePayAccountResponse.md)
 - [GooglePayAccountResponseStatusEnum](docs/GooglePayAccountResponseStatusEnum.md)
 - [GooglePayVerifyToken](docs/GooglePayVerifyToken.md)
 - [GradingPerUser](docs/GradingPerUser.md)
 - [GradingPerUserData](docs/GradingPerUserData.md)
 - [GreetingMethodEnum](docs/GreetingMethodEnum.md)
 - [GroupList](docs/GroupList.md)
 - [GroupListData](docs/GroupListData.md)
 - [GuidedPromptsResponse](docs/GuidedPromptsResponse.md)
 - [HeygenMarketingVideoDetail](docs/HeygenMarketingVideoDetail.md)
 - [HeygenMarketingVideoList](docs/HeygenMarketingVideoList.md)
 - [HeygenTemplateRequest](docs/HeygenTemplateRequest.md)
 - [HeygenTemplateResponseSingle](docs/HeygenTemplateResponseSingle.md)
 - [HeygenVideoDetail](docs/HeygenVideoDetail.md)
 - [HeygenVideoRequest](docs/HeygenVideoRequest.md)
 - [IBLAIPlatformMeta](docs/IBLAIPlatformMeta.md)
 - [IBLAIPlatformMetaRequest](docs/IBLAIPlatformMetaRequest.md)
 - [IBLAIPlatformMetaUpdateRequest](docs/IBLAIPlatformMetaUpdateRequest.md)
 - [ImageUpload](docs/ImageUpload.md)
 - [InputQuestion](docs/InputQuestion.md)
 - [Institution](docs/Institution.md)
 - [InstitutionTypeEnum](docs/InstitutionTypeEnum.md)
 - [IntegrationCredential](docs/IntegrationCredential.md)
 - [IntialQuestionAnswer](docs/IntialQuestionAnswer.md)
 - [Issuer](docs/Issuer.md)
 - [IssuerAuthority](docs/IssuerAuthority.md)
 - [ItemTypeEnum](docs/ItemTypeEnum.md)
 - [JobRun](docs/JobRun.md)
 - [KindEnum](docs/KindEnum.md)
 - [LLMCredentialRequest](docs/LLMCredentialRequest.md)
 - [LLMCredentialResponse](docs/LLMCredentialResponse.md)
 - [LLMModelForTenant](docs/LLMModelForTenant.md)
 - [LLMQuestion](docs/LLMQuestion.md)
 - [LLMResponse](docs/LLMResponse.md)
 - [LLMTracesListResponse](docs/LLMTracesListResponse.md)
 - [LanguagesView](docs/LanguagesView.md)
 - [LauncherViewPostRequest](docs/LauncherViewPostRequest.md)
 - [LearnerInformationAPI](docs/LearnerInformationAPI.md)
 - [LearnerInformationAPIData](docs/LearnerInformationAPIData.md)
 - [LinkCourseRequest](docs/LinkCourseRequest.md)
 - [LinkCourseResponse](docs/LinkCourseResponse.md)
 - [LlmProviderEnum](docs/LlmProviderEnum.md)
 - [LtiKey](docs/LtiKey.md)
 - [LtiLaunchGate](docs/LtiLaunchGate.md)
 - [LtiTool](docs/LtiTool.md)
 - [MCPServer](docs/MCPServer.md)
 - [ManagerAuthToken](docs/ManagerAuthToken.md)
 - [MarkAllReadRequest](docs/MarkAllReadRequest.md)
 - [MarkAllReadResponse](docs/MarkAllReadResponse.md)
 - [MediaResource](docs/MediaResource.md)
 - [MediaTypeEnum](docs/MediaTypeEnum.md)
 - [MemoryComponentData](docs/MemoryComponentData.md)
 - [MemoryComponentMemory](docs/MemoryComponentMemory.md)
 - [MemoryComponentMemoryDetail](docs/MemoryComponentMemoryDetail.md)
 - [MemoryComponentResponse](docs/MemoryComponentResponse.md)
 - [MemoryProgress](docs/MemoryProgress.md)
 - [MemoryStatusRequestView](docs/MemoryStatusRequestView.md)
 - [MemoryStatusView](docs/MemoryStatusView.md)
 - [Mentor](docs/Mentor.md)
 - [MentorAudience](docs/MentorAudience.md)
 - [MentorCategory](docs/MentorCategory.md)
 - [MentorCategoryCreate](docs/MentorCategoryCreate.md)
 - [MentorCategoryGroup](docs/MentorCategoryGroup.md)
 - [MentorCategoryGroupCreate](docs/MentorCategoryGroupCreate.md)
 - [MentorCreate](docs/MentorCreate.md)
 - [MentorCustomVoice](docs/MentorCustomVoice.md)
 - [MentorCustomVoiceResponse](docs/MentorCustomVoiceResponse.md)
 - [MentorData](docs/MentorData.md)
 - [MentorDetailAnalytics](docs/MentorDetailAnalytics.md)
 - [MentorEval](docs/MentorEval.md)
 - [MentorEvalQuestion](docs/MentorEvalQuestion.md)
 - [MentorEvalQuestionRequest](docs/MentorEvalQuestionRequest.md)
 - [MentorEvalReport](docs/MentorEvalReport.md)
 - [MentorEvalRequest](docs/MentorEvalRequest.md)
 - [MentorFacet](docs/MentorFacet.md)
 - [MentorFork](docs/MentorFork.md)
 - [MentorFromTemplateRequest](docs/MentorFromTemplateRequest.md)
 - [MentorFromTemplateWithSettingRequest](docs/MentorFromTemplateWithSettingRequest.md)
 - [MentorMemorySettingsRequest](docs/MentorMemorySettingsRequest.md)
 - [MentorMemorySettingsResponse](docs/MentorMemorySettingsResponse.md)
 - [MentorMetadata](docs/MentorMetadata.md)
 - [MentorScenario](docs/MentorScenario.md)
 - [MentorScenarioPrompt](docs/MentorScenarioPrompt.md)
 - [MentorSearchResponse](docs/MentorSearchResponse.md)
 - [MentorSession](docs/MentorSession.md)
 - [MentorSettings](docs/MentorSettings.md)
 - [MentorSettingsMentorVisibility](docs/MentorSettingsMentorVisibility.md)
 - [MentorSettingsPublic](docs/MentorSettingsPublic.md)
 - [MentorSettingsRequest](docs/MentorSettingsRequest.md)
 - [MentorVisibilityEnum](docs/MentorVisibilityEnum.md)
 - [MentorWizard](docs/MentorWizard.md)
 - [MessageStatistics](docs/MessageStatistics.md)
 - [MessageStatus](docs/MessageStatus.md)
 - [MessageView](docs/MessageView.md)
 - [MessageViewRequest](docs/MessageViewRequest.md)
 - [MessageViewUpdatResponse](docs/MessageViewUpdatResponse.md)
 - [Metadata](docs/Metadata.md)
 - [MetricChange](docs/MetricChange.md)
 - [ModelCost](docs/ModelCost.md)
 - [ModerationLog](docs/ModerationLog.md)
 - [NetRevenueOverTime](docs/NetRevenueOverTime.md)
 - [NewPerLearnerList](docs/NewPerLearnerList.md)
 - [NewPerLearnerListData](docs/NewPerLearnerListData.md)
 - [NoChatMessagesFound](docs/NoChatMessagesFound.md)
 - [Notification](docs/Notification.md)
 - [NotificationCount](docs/NotificationCount.md)
 - [NotificationPreview](docs/NotificationPreview.md)
 - [NotificationSource](docs/NotificationSource.md)
 - [NotificationSourceTypeEnum](docs/NotificationSourceTypeEnum.md)
 - [NotificationStatusEnum](docs/NotificationStatusEnum.md)
 - [NotificationTemplateData](docs/NotificationTemplateData.md)
 - [NotificationV1CampaignsUnsubscribeRetrieve200Response](docs/NotificationV1CampaignsUnsubscribeRetrieve200Response.md)
 - [NullEnum](docs/NullEnum.md)
 - [OnboardingStatusUpdate](docs/OnboardingStatusUpdate.md)
 - [Order](docs/Order.md)
 - [OverTime](docs/OverTime.md)
 - [OverTimeWithTotal](docs/OverTimeWithTotal.md)
 - [OvertimeMeta](docs/OvertimeMeta.md)
 - [OvertimeWithChangeInfo](docs/OvertimeWithChangeInfo.md)
 - [PageContent](docs/PageContent.md)
 - [PaginatedAIGeneratedImageList](docs/PaginatedAIGeneratedImageList.md)
 - [PaginatedAssertionsResponse](docs/PaginatedAssertionsResponse.md)
 - [PaginatedConversationsList](docs/PaginatedConversationsList.md)
 - [PaginatedCourseAccessRequest](docs/PaginatedCourseAccessRequest.md)
 - [PaginatedCourseCreationTaskFileList](docs/PaginatedCourseCreationTaskFileList.md)
 - [PaginatedCourseCreationTaskList](docs/PaginatedCourseCreationTaskList.md)
 - [PaginatedCourseGroupSuggestion](docs/PaginatedCourseGroupSuggestion.md)
 - [PaginatedCourseInvitation](docs/PaginatedCourseInvitation.md)
 - [PaginatedCourseLicense](docs/PaginatedCourseLicense.md)
 - [PaginatedCourseLicenseAssignment](docs/PaginatedCourseLicenseAssignment.md)
 - [PaginatedCourseLicenseGroupAssignment](docs/PaginatedCourseLicenseGroupAssignment.md)
 - [PaginatedCourseSuggestion](docs/PaginatedCourseSuggestion.md)
 - [PaginatedDataSetList](docs/PaginatedDataSetList.md)
 - [PaginatedEdxCourseList](docs/PaginatedEdxCourseList.md)
 - [PaginatedEmailPromptListList](docs/PaginatedEmailPromptListList.md)
 - [PaginatedHeygenMarketingVideoListList](docs/PaginatedHeygenMarketingVideoListList.md)
 - [PaginatedHeygenTemplateResponseSingleList](docs/PaginatedHeygenTemplateResponseSingleList.md)
 - [PaginatedJobRunList](docs/PaginatedJobRunList.md)
 - [PaginatedMCPServerList](docs/PaginatedMCPServerList.md)
 - [PaginatedMentorList](docs/PaginatedMentorList.md)
 - [PaginatedModerationLogList](docs/PaginatedModerationLogList.md)
 - [PaginatedPathwayGroupSuggestion](docs/PaginatedPathwayGroupSuggestion.md)
 - [PaginatedPathwaySuggestion](docs/PaginatedPathwaySuggestion.md)
 - [PaginatedPeriodicAgentList](docs/PaginatedPeriodicAgentList.md)
 - [PaginatedPeriodicAgentLogList](docs/PaginatedPeriodicAgentLogList.md)
 - [PaginatedPlatformInvitation](docs/PaginatedPlatformInvitation.md)
 - [PaginatedPlatformLicense](docs/PaginatedPlatformLicense.md)
 - [PaginatedPlayWrightScriptList](docs/PaginatedPlayWrightScriptList.md)
 - [PaginatedProgramGroupSuggestion](docs/PaginatedProgramGroupSuggestion.md)
 - [PaginatedProgramInvitation](docs/PaginatedProgramInvitation.md)
 - [PaginatedProgramLicense](docs/PaginatedProgramLicense.md)
 - [PaginatedProgramLicenseAssignment](docs/PaginatedProgramLicenseAssignment.md)
 - [PaginatedProgramLicenseGroupAssignment](docs/PaginatedProgramLicenseGroupAssignment.md)
 - [PaginatedProgramSuggestion](docs/PaginatedProgramSuggestion.md)
 - [PaginatedRbacGroupList](docs/PaginatedRbacGroupList.md)
 - [PaginatedRbacPolicyList](docs/PaginatedRbacPolicyList.md)
 - [PaginatedRbacRoleList](docs/PaginatedRbacRoleList.md)
 - [PaginatedRetrieverDocumentEmbeddingList](docs/PaginatedRetrieverDocumentEmbeddingList.md)
 - [PaginatedSectionList](docs/PaginatedSectionList.md)
 - [PaginatedSkill](docs/PaginatedSkill.md)
 - [PaginatedSubSectionList](docs/PaginatedSubSectionList.md)
 - [PaginatedTopicStatisticsResponse](docs/PaginatedTopicStatisticsResponse.md)
 - [PaginatedTrainingList](docs/PaginatedTrainingList.md)
 - [PaginatedUnitList](docs/PaginatedUnitList.md)
 - [PaginatedUserAppList](docs/PaginatedUserAppList.md)
 - [PaginatedUserEdxMemoryList](docs/PaginatedUserEdxMemoryList.md)
 - [PaginatedUserLicense](docs/PaginatedUserLicense.md)
 - [PaginatedUserLicenseAssignment](docs/PaginatedUserLicenseAssignment.md)
 - [PaginatedUserLicenseGroupAssignment](docs/PaginatedUserLicenseGroupAssignment.md)
 - [PaginatedVoiceList](docs/PaginatedVoiceList.md)
 - [Pagination](docs/Pagination.md)
 - [PatchedBotCommand](docs/PatchedBotCommand.md)
 - [PatchedBotCreate](docs/PatchedBotCreate.md)
 - [PatchedCallConfiguration](docs/PatchedCallConfiguration.md)
 - [PatchedConversations](docs/PatchedConversations.md)
 - [PatchedCourseCreationTaskFile](docs/PatchedCourseCreationTaskFile.md)
 - [PatchedCredentialRequest](docs/PatchedCredentialRequest.md)
 - [PatchedDataSet](docs/PatchedDataSet.md)
 - [PatchedDiscordConfig](docs/PatchedDiscordConfig.md)
 - [PatchedDiscordUserConfig](docs/PatchedDiscordUserConfig.md)
 - [PatchedLLMCredentialRequest](docs/PatchedLLMCredentialRequest.md)
 - [PatchedMCPServer](docs/PatchedMCPServer.md)
 - [PatchedMediaResource](docs/PatchedMediaResource.md)
 - [PatchedMentorCategoryGroupCreate](docs/PatchedMentorCategoryGroupCreate.md)
 - [PatchedMentorCreate](docs/PatchedMentorCreate.md)
 - [PatchedNotification](docs/PatchedNotification.md)
 - [PatchedPeriodicAgentCreate](docs/PatchedPeriodicAgentCreate.md)
 - [PatchedPlatformPublicMetadata](docs/PatchedPlatformPublicMetadata.md)
 - [PatchedPlayWrightScript](docs/PatchedPlayWrightScript.md)
 - [PatchedPrompt](docs/PatchedPrompt.md)
 - [PatchedPromptPromptVisibility](docs/PatchedPromptPromptVisibility.md)
 - [PatchedRbacGroup](docs/PatchedRbacGroup.md)
 - [PatchedRbacPolicy](docs/PatchedRbacPolicy.md)
 - [PatchedRbacRole](docs/PatchedRbacRole.md)
 - [PatchedSection](docs/PatchedSection.md)
 - [PatchedSkillThreshold](docs/PatchedSkillThreshold.md)
 - [PatchedSlackConfig](docs/PatchedSlackConfig.md)
 - [PatchedSlackUserConfig](docs/PatchedSlackUserConfig.md)
 - [PatchedSubSection](docs/PatchedSubSection.md)
 - [PatchedTeamsConfig](docs/PatchedTeamsConfig.md)
 - [PatchedTrainingCreate](docs/PatchedTrainingCreate.md)
 - [PatchedUnit](docs/PatchedUnit.md)
 - [PatchedWebexConfig](docs/PatchedWebexConfig.md)
 - [PatchedWhatsappConfig](docs/PatchedWhatsappConfig.md)
 - [PatchedWhatsappUserConfig](docs/PatchedWhatsappUserConfig.md)
 - [Pathway](docs/Pathway.md)
 - [PathwayCompletionResponse](docs/PathwayCompletionResponse.md)
 - [PathwayCreateUpdateRequest](docs/PathwayCreateUpdateRequest.md)
 - [PathwayDeleteResponse](docs/PathwayDeleteResponse.md)
 - [PathwayEnrollment](docs/PathwayEnrollment.md)
 - [PathwayEnrollmentPlus](docs/PathwayEnrollmentPlus.md)
 - [PathwayEnrollmentRequest](docs/PathwayEnrollmentRequest.md)
 - [PathwayGroupSuggestionCreate](docs/PathwayGroupSuggestionCreate.md)
 - [PathwayGroupSuggestionDetail](docs/PathwayGroupSuggestionDetail.md)
 - [PathwaySelfEnrollmentRequest](docs/PathwaySelfEnrollmentRequest.md)
 - [PathwaySuggestionBulkCreate](docs/PathwaySuggestionBulkCreate.md)
 - [PathwaySuggestionCreate](docs/PathwaySuggestionCreate.md)
 - [PathwaySuggestionDetail](docs/PathwaySuggestionDetail.md)
 - [PerLearnerCourseLastAccessData](docs/PerLearnerCourseLastAccessData.md)
 - [PerLearnerCourseVideosWatched](docs/PerLearnerCourseVideosWatched.md)
 - [PerLearnerCourseVideosWatchedData](docs/PerLearnerCourseVideosWatchedData.md)
 - [PerLearnerLastAccess](docs/PerLearnerLastAccess.md)
 - [PerLearnerLastAccessData](docs/PerLearnerLastAccessData.md)
 - [PerLearnerTimeSpentInCourseTree](docs/PerLearnerTimeSpentInCourseTree.md)
 - [PerformanceGradesPerCourse](docs/PerformanceGradesPerCourse.md)
 - [PerformanceGradesPerCourseData](docs/PerformanceGradesPerCourseData.md)
 - [PeriodicAgent](docs/PeriodicAgent.md)
 - [PeriodicAgentCreate](docs/PeriodicAgentCreate.md)
 - [PeriodicAgentLog](docs/PeriodicAgentLog.md)
 - [PeriodicAgentLogStatusEnum](docs/PeriodicAgentLogStatusEnum.md)
 - [PeriodicTask](docs/PeriodicTask.md)
 - [PerlearnerCourseProgress](docs/PerlearnerCourseProgress.md)
 - [PerlearnerCourseProgressData](docs/PerlearnerCourseProgressData.md)
 - [PerlearnerEngagementVideosData](docs/PerlearnerEngagementVideosData.md)
 - [PerlearnerEngagementVideosWatchedPerCourse](docs/PerlearnerEngagementVideosWatchedPerCourse.md)
 - [PerlearnerGradeSummary](docs/PerlearnerGradeSummary.md)
 - [PerlearnerGradeSummaryData](docs/PerlearnerGradeSummaryData.md)
 - [PerlearnerGradeWithCutOff](docs/PerlearnerGradeWithCutOff.md)
 - [PerlearnerGradeWithCutOffData](docs/PerlearnerGradeWithCutOffData.md)
 - [PerlearnerGradingPerCourseAPI](docs/PerlearnerGradingPerCourseAPI.md)
 - [PerlearnerGradingPerCourseAPIData](docs/PerlearnerGradingPerCourseAPIData.md)
 - [PerlearnerUserList](docs/PerlearnerUserList.md)
 - [PerlearnerUserListData](docs/PerlearnerUserListData.md)
 - [PieChartData](docs/PieChartData.md)
 - [PieChartSegment](docs/PieChartSegment.md)
 - [PinnedMessageCreate](docs/PinnedMessageCreate.md)
 - [PinnedMessageGet](docs/PinnedMessageGet.md)
 - [PinnedMessageRequest](docs/PinnedMessageRequest.md)
 - [Platform](docs/Platform.md)
 - [PlatformApiKey](docs/PlatformApiKey.md)
 - [PlatformInvitationCreate](docs/PlatformInvitationCreate.md)
 - [PlatformInvitationDetail](docs/PlatformInvitationDetail.md)
 - [PlatformInvitationRedemption](docs/PlatformInvitationRedemption.md)
 - [PlatformLicenseCreate](docs/PlatformLicenseCreate.md)
 - [PlatformLicenseDetail](docs/PlatformLicenseDetail.md)
 - [PlatformLicenseUpdate](docs/PlatformLicenseUpdate.md)
 - [PlatformList](docs/PlatformList.md)
 - [PlatformListStatusEnum](docs/PlatformListStatusEnum.md)
 - [PlatformPublicMetadata](docs/PlatformPublicMetadata.md)
 - [PlatformSkillPointBulkRequest](docs/PlatformSkillPointBulkRequest.md)
 - [PlatformSkillPointBulkResponse](docs/PlatformSkillPointBulkResponse.md)
 - [PlatformSkillPointGroupRequest](docs/PlatformSkillPointGroupRequest.md)
 - [PlatformSkillPointRequest](docs/PlatformSkillPointRequest.md)
 - [PlatformSkillPointResponse](docs/PlatformSkillPointResponse.md)
 - [PlatformUpdatePostRequest](docs/PlatformUpdatePostRequest.md)
 - [PlayWrightScript](docs/PlayWrightScript.md)
 - [PointsPercentile](docs/PointsPercentile.md)
 - [PredictiveAnalyticsRequest](docs/PredictiveAnalyticsRequest.md)
 - [PredictiveAnalyticsResponse](docs/PredictiveAnalyticsResponse.md)
 - [PreviewResponse](docs/PreviewResponse.md)
 - [PreviousAgentStatusEnum](docs/PreviousAgentStatusEnum.md)
 - [Product](docs/Product.md)
 - [ProductTable](docs/ProductTable.md)
 - [Program](docs/Program.md)
 - [ProgramCompletionResponse](docs/ProgramCompletionResponse.md)
 - [ProgramCoursePosition](docs/ProgramCoursePosition.md)
 - [ProgramCreateUpdateRequest](docs/ProgramCreateUpdateRequest.md)
 - [ProgramDeleteResponse](docs/ProgramDeleteResponse.md)
 - [ProgramEnrollment](docs/ProgramEnrollment.md)
 - [ProgramEnrollmentPlus](docs/ProgramEnrollmentPlus.md)
 - [ProgramEnrollmentSearchResponse](docs/ProgramEnrollmentSearchResponse.md)
 - [ProgramGroupSuggestionCreate](docs/ProgramGroupSuggestionCreate.md)
 - [ProgramGroupSuggestionDetail](docs/ProgramGroupSuggestionDetail.md)
 - [ProgramInvitationCreate](docs/ProgramInvitationCreate.md)
 - [ProgramInvitationDetail](docs/ProgramInvitationDetail.md)
 - [ProgramInvitationRedemption](docs/ProgramInvitationRedemption.md)
 - [ProgramLicenseAssignmentCreate](docs/ProgramLicenseAssignmentCreate.md)
 - [ProgramLicenseAssignmentDetail](docs/ProgramLicenseAssignmentDetail.md)
 - [ProgramLicenseCreateDetail](docs/ProgramLicenseCreateDetail.md)
 - [ProgramLicenseDetail](docs/ProgramLicenseDetail.md)
 - [ProgramLicenseGroupAssignmentCreate](docs/ProgramLicenseGroupAssignmentCreate.md)
 - [ProgramLicenseGroupAssignmentDetail](docs/ProgramLicenseGroupAssignmentDetail.md)
 - [ProgramLicenseUpdateDetail](docs/ProgramLicenseUpdateDetail.md)
 - [ProgramMetadataRequest](docs/ProgramMetadataRequest.md)
 - [ProgramMetadataResponse](docs/ProgramMetadataResponse.md)
 - [ProgramReview](docs/ProgramReview.md)
 - [ProgramReviewInfoResponse](docs/ProgramReviewInfoResponse.md)
 - [ProgramReviewPaginatedResponse](docs/ProgramReviewPaginatedResponse.md)
 - [ProgramReviewRequest](docs/ProgramReviewRequest.md)
 - [ProgramSearch](docs/ProgramSearch.md)
 - [ProgramSuggestionBulkCreate](docs/ProgramSuggestionBulkCreate.md)
 - [ProgramSuggestionCreate](docs/ProgramSuggestionCreate.md)
 - [ProgramSuggestionDetail](docs/ProgramSuggestionDetail.md)
 - [ProgramTypeEnum](docs/ProgramTypeEnum.md)
 - [Prompt](docs/Prompt.md)
 - [PromptCategory](docs/PromptCategory.md)
 - [PromptFacet](docs/PromptFacet.md)
 - [PromptSearchResponse](docs/PromptSearchResponse.md)
 - [PromptVisibilityEnum](docs/PromptVisibilityEnum.md)
 - [Provider05cEnum](docs/Provider05cEnum.md)
 - [Provider637Enum](docs/Provider637Enum.md)
 - [Provider63aEnum](docs/Provider63aEnum.md)
 - [ProviderAssociationStripeCallbackRetrieve404Response](docs/ProviderAssociationStripeCallbackRetrieve404Response.md)
 - [QuestionCardTag](docs/QuestionCardTag.md)
 - [QuestionRequest](docs/QuestionRequest.md)
 - [QuestionResponse](docs/QuestionResponse.md)
 - [RatingEnum](docs/RatingEnum.md)
 - [RatingRecord](docs/RatingRecord.md)
 - [RbacBaseRole](docs/RbacBaseRole.md)
 - [RbacGroup](docs/RbacGroup.md)
 - [RbacPlatform](docs/RbacPlatform.md)
 - [RbacPolicy](docs/RbacPolicy.md)
 - [RbacPolicyGroup](docs/RbacPolicyGroup.md)
 - [RbacRole](docs/RbacRole.md)
 - [RbacUser](docs/RbacUser.md)
 - [RecentlyAccessedMentor](docs/RecentlyAccessedMentor.md)
 - [Recipient](docs/Recipient.md)
 - [RecommendCourseBlock](docs/RecommendCourseBlock.md)
 - [RecommendCourseResponse](docs/RecommendCourseResponse.md)
 - [RecommendationSearchAPI](docs/RecommendationSearchAPI.md)
 - [RecommendedCoursesResponse](docs/RecommendedCoursesResponse.md)
 - [RedirectTokenRequest](docs/RedirectTokenRequest.md)
 - [RedirectTokenResponse](docs/RedirectTokenResponse.md)
 - [RelatedText](docs/RelatedText.md)
 - [ReportCreate](docs/ReportCreate.md)
 - [ReportData](docs/ReportData.md)
 - [ReportDetail](docs/ReportDetail.md)
 - [ReportList](docs/ReportList.md)
 - [ReportRequest](docs/ReportRequest.md)
 - [ReportStatus](docs/ReportStatus.md)
 - [ReportedRole](docs/ReportedRole.md)
 - [ReportedRoleCreateUpdateRequest](docs/ReportedRoleCreateUpdateRequest.md)
 - [ReportedSkill](docs/ReportedSkill.md)
 - [RequestDataVariable](docs/RequestDataVariable.md)
 - [Resource](docs/Resource.md)
 - [ResourceCompletion](docs/ResourceCompletion.md)
 - [ResourceCompletionRequest](docs/ResourceCompletionRequest.md)
 - [ResourceCreateUpdate](docs/ResourceCreateUpdate.md)
 - [ResourceDeleteResponse](docs/ResourceDeleteResponse.md)
 - [ResourcePoint](docs/ResourcePoint.md)
 - [ResourceScrappedData](docs/ResourceScrappedData.md)
 - [ResourceScrappedDataStatus](docs/ResourceScrappedDataStatus.md)
 - [ResourceScrappedDataStatusEnum](docs/ResourceScrappedDataStatusEnum.md)
 - [ResponseDataVariable](docs/ResponseDataVariable.md)
 - [RetreiverTrainViewRequest](docs/RetreiverTrainViewRequest.md)
 - [RetreiverTrainViewResponse](docs/RetreiverTrainViewResponse.md)
 - [RetrieveTask](docs/RetrieveTask.md)
 - [RetrieverDocumentEmbedding](docs/RetrieverDocumentEmbedding.md)
 - [RetrieverDocumentEmbeddingAccess](docs/RetrieverDocumentEmbeddingAccess.md)
 - [RetrieverDocumentEmbeddingRequest](docs/RetrieverDocumentEmbeddingRequest.md)
 - [RetrieverDocumentEmbeddingTrainingStatus](docs/RetrieverDocumentEmbeddingTrainingStatus.md)
 - [RetrieverRequestSearch](docs/RetrieverRequestSearch.md)
 - [RetrieverRequestSearchDocument](docs/RetrieverRequestSearchDocument.md)
 - [RetrieverResponseSearch](docs/RetrieverResponseSearch.md)
 - [ReuestDataVariableList](docs/ReuestDataVariableList.md)
 - [RevenueByProduct](docs/RevenueByProduct.md)
 - [Role](docs/Role.md)
 - [RoleCreateUpdateRequest](docs/RoleCreateUpdateRequest.md)
 - [RunMentorEval](docs/RunMentorEval.md)
 - [ScanWebhookRequest](docs/ScanWebhookRequest.md)
 - [ScanWebhookResponse](docs/ScanWebhookResponse.md)
 - [Section](docs/Section.md)
 - [SectionWithChildren](docs/SectionWithChildren.md)
 - [SeedMentorsView](docs/SeedMentorsView.md)
 - [SendNotification](docs/SendNotification.md)
 - [SendResponse](docs/SendResponse.md)
 - [SentimentSummary](docs/SentimentSummary.md)
 - [SessionBrowserScreenshot](docs/SessionBrowserScreenshot.md)
 - [SessionDetail](docs/SessionDetail.md)
 - [SessionMemoryStorage](docs/SessionMemoryStorage.md)
 - [ShellLogs](docs/ShellLogs.md)
 - [Skill](docs/Skill.md)
 - [SkillCreateUpdateRequest](docs/SkillCreateUpdateRequest.md)
 - [SkillDetail](docs/SkillDetail.md)
 - [SkillInfo](docs/SkillInfo.md)
 - [SkillThreshold](docs/SkillThreshold.md)
 - [SlackConfig](docs/SlackConfig.md)
 - [SlackUserConfig](docs/SlackUserConfig.md)
 - [SlackWebhook](docs/SlackWebhook.md)
 - [SpacedRepetitionLearningPath](docs/SpacedRepetitionLearningPath.md)
 - [SpacedRepetitionQuestionStats](docs/SpacedRepetitionQuestionStats.md)
 - [StarMentor](docs/StarMentor.md)
 - [StateEnum](docs/StateEnum.md)
 - [Status6eeEnum](docs/Status6eeEnum.md)
 - [Step](docs/Step.md)
 - [StepStatusEnum](docs/StepStatusEnum.md)
 - [StripeBillingPageIdentifierResponse](docs/StripeBillingPageIdentifierResponse.md)
 - [StripeCheckoutSessionRequest](docs/StripeCheckoutSessionRequest.md)
 - [StripeCheckoutSessionRequestModeEnum](docs/StripeCheckoutSessionRequestModeEnum.md)
 - [StripeCheckoutSessionResponse](docs/StripeCheckoutSessionResponse.md)
 - [StripeContext](docs/StripeContext.md)
 - [StripeCustomerPortalRequest](docs/StripeCustomerPortalRequest.md)
 - [StripeCustomerPortalResponse](docs/StripeCustomerPortalResponse.md)
 - [StripeLocalProduct](docs/StripeLocalProduct.md)
 - [StripeNewUserTenantLaunchRequest](docs/StripeNewUserTenantLaunchRequest.md)
 - [StripeSubscriptionRenewalRequest](docs/StripeSubscriptionRenewalRequest.md)
 - [StripeSubscriptionRenewalResponse](docs/StripeSubscriptionRenewalResponse.md)
 - [SttProviderEnum](docs/SttProviderEnum.md)
 - [StudentChatMessage](docs/StudentChatMessage.md)
 - [StylesView](docs/StylesView.md)
 - [SubSection](docs/SubSection.md)
 - [SubSectionWithChildren](docs/SubSectionWithChildren.md)
 - [SubTimeChild](docs/SubTimeChild.md)
 - [Summary](docs/Summary.md)
 - [TagsView](docs/TagsView.md)
 - [TargetSystemEnum](docs/TargetSystemEnum.md)
 - [TaskView](docs/TaskView.md)
 - [TeamsConfig](docs/TeamsConfig.md)
 - [TeamsWebhook](docs/TeamsWebhook.md)
 - [TemplateMentor](docs/TemplateMentor.md)
 - [TenantLaunchError](docs/TenantLaunchError.md)
 - [TenantLaunchFailed](docs/TenantLaunchFailed.md)
 - [TenantLaunchRequest](docs/TenantLaunchRequest.md)
 - [TenantLaunchResponse](docs/TenantLaunchResponse.md)
 - [TenantMentorTraces](docs/TenantMentorTraces.md)
 - [ThemeEnum](docs/ThemeEnum.md)
 - [TimeChildData](docs/TimeChildData.md)
 - [TimeDetail](docs/TimeDetail.md)
 - [TimeDetailChild](docs/TimeDetailChild.md)
 - [TimeDetailData](docs/TimeDetailData.md)
 - [TimeSpentByUsersInCourse](docs/TimeSpentByUsersInCourse.md)
 - [TimeSpentByUsersInCourseData](docs/TimeSpentByUsersInCourseData.md)
 - [TimeSpentPerCourse](docs/TimeSpentPerCourse.md)
 - [TimeSpentPerCourseData](docs/TimeSpentPerCourseData.md)
 - [TimeSpentPerUserResponse](docs/TimeSpentPerUserResponse.md)
 - [TimeSpentUpdateRequest](docs/TimeSpentUpdateRequest.md)
 - [TimeSpentUpdateResponse](docs/TimeSpentUpdateResponse.md)
 - [TokenProxyInput](docs/TokenProxyInput.md)
 - [TokenProxyOutput](docs/TokenProxyOutput.md)
 - [TokenProxyOutputSerializerData](docs/TokenProxyOutputSerializerData.md)
 - [TokenProxyUser](docs/TokenProxyUser.md)
 - [TonesView](docs/TonesView.md)
 - [ToolResponse](docs/ToolResponse.md)
 - [TopicModel](docs/TopicModel.md)
 - [TopicRecord](docs/TopicRecord.md)
 - [TopicStatistics](docs/TopicStatistics.md)
 - [TopicStatisticsResponse](docs/TopicStatisticsResponse.md)
 - [TopicSummaryView](docs/TopicSummaryView.md)
 - [TrainChatSessionDocumentView](docs/TrainChatSessionDocumentView.md)
 - [TrainChatSessionDocumentViewRequest](docs/TrainChatSessionDocumentViewRequest.md)
 - [TrainDocumentViewRequest](docs/TrainDocumentViewRequest.md)
 - [TrainDocumentViewResponse](docs/TrainDocumentViewResponse.md)
 - [Training](docs/Training.md)
 - [TrainingCreate](docs/TrainingCreate.md)
 - [TrainingStatusEnum](docs/TrainingStatusEnum.md)
 - [TransportEnum](docs/TransportEnum.md)
 - [TrendEntry](docs/TrendEntry.md)
 - [TriggerRequest](docs/TriggerRequest.md)
 - [TriggerResponse](docs/TriggerResponse.md)
 - [TtsProviderEnum](docs/TtsProviderEnum.md)
 - [TypeC42Enum](docs/TypeC42Enum.md)
 - [Unit](docs/Unit.md)
 - [UnitWithChildren](docs/UnitWithChildren.md)
 - [UploadedImage](docs/UploadedImage.md)
 - [UseMainCreds](docs/UseMainCreds.md)
 - [UserAllChatMemoryView](docs/UserAllChatMemoryView.md)
 - [UserApp](docs/UserApp.md)
 - [UserCatalogItemMemoryView](docs/UserCatalogItemMemoryView.md)
 - [UserChatByPeriod](docs/UserChatByPeriod.md)
 - [UserChatFeedback](docs/UserChatFeedback.md)
 - [UserChatFeedbackCount](docs/UserChatFeedbackCount.md)
 - [UserChatMemoryStatusRequestView](docs/UserChatMemoryStatusRequestView.md)
 - [UserChatMemoryStatusView](docs/UserChatMemoryStatusView.md)
 - [UserChatMemoryUpdateView](docs/UserChatMemoryUpdateView.md)
 - [UserCountRecord](docs/UserCountRecord.md)
 - [UserDeleteAPIError](docs/UserDeleteAPIError.md)
 - [UserDeleteAPIRequest](docs/UserDeleteAPIRequest.md)
 - [UserDeleteAPIResponse](docs/UserDeleteAPIResponse.md)
 - [UserEdxMemory](docs/UserEdxMemory.md)
 - [UserInfo](docs/UserInfo.md)
 - [UserLicenseAssignmentCreate](docs/UserLicenseAssignmentCreate.md)
 - [UserLicenseAssignmentDetail](docs/UserLicenseAssignmentDetail.md)
 - [UserLicenseCreate](docs/UserLicenseCreate.md)
 - [UserLicenseDetail](docs/UserLicenseDetail.md)
 - [UserLicenseGroupAssignmentCreate](docs/UserLicenseGroupAssignmentCreate.md)
 - [UserLicenseGroupAssignmentDetail](docs/UserLicenseGroupAssignmentDetail.md)
 - [UserLicenseUpdate](docs/UserLicenseUpdate.md)
 - [UserMemoryContextRequest](docs/UserMemoryContextRequest.md)
 - [UserMemoryContextResponse](docs/UserMemoryContextResponse.md)
 - [UserMetric](docs/UserMetric.md)
 - [UserMetricsResponse](docs/UserMetricsResponse.md)
 - [UserPlatformLink](docs/UserPlatformLink.md)
 - [UserPlatformManagementListViewGetResponse](docs/UserPlatformManagementListViewGetResponse.md)
 - [UserPlatformViewPostRequest](docs/UserPlatformViewPostRequest.md)
 - [UserProxyBulkRequest](docs/UserProxyBulkRequest.md)
 - [UserProxyGetResponse](docs/UserProxyGetResponse.md)
 - [UserProxyPostRequest](docs/UserProxyPostRequest.md)
 - [UserProxyPostResponse](docs/UserProxyPostResponse.md)
 - [UserSearchResponse](docs/UserSearchResponse.md)
 - [UserSearchViewGetResponse](docs/UserSearchViewGetResponse.md)
 - [UserSentimentCountView](docs/UserSentimentCountView.md)
 - [UserSkill](docs/UserSkill.md)
 - [UserSkillPointsPercentile](docs/UserSkillPointsPercentile.md)
 - [UserTrendByPeriod](docs/UserTrendByPeriod.md)
 - [ValidateSourceResponse](docs/ValidateSourceResponse.md)
 - [Value](docs/Value.md)
 - [ValueData](docs/ValueData.md)
 - [VectorResult](docs/VectorResult.md)
 - [VerifyGCPMarketPlaceFailedResponse](docs/VerifyGCPMarketPlaceFailedResponse.md)
 - [VerifyGCPMarketPlaceRequest](docs/VerifyGCPMarketPlaceRequest.md)
 - [VerifyGCPMarketPlaceResponse](docs/VerifyGCPMarketPlaceResponse.md)
 - [VideoBlock](docs/VideoBlock.md)
 - [VideoCaption](docs/VideoCaption.md)
 - [VideoEngagementPerCourse](docs/VideoEngagementPerCourse.md)
 - [VideoEngagementPerCourseData](docs/VideoEngagementPerCourseData.md)
 - [VideosCount](docs/VideosCount.md)
 - [VideosCountData](docs/VideosCountData.md)
 - [VideosInCourseSummary](docs/VideosInCourseSummary.md)
 - [VideosInCourseSummaryData](docs/VideosInCourseSummaryData.md)
 - [VideosSpecificCourse](docs/VideosSpecificCourse.md)
 - [VideosSpecificCourseData](docs/VideosSpecificCourseData.md)
 - [VideosWatchedSubSection](docs/VideosWatchedSubSection.md)
 - [Voice](docs/Voice.md)
 - [WatchedVideosPerCourse](docs/WatchedVideosPerCourse.md)
 - [WatchedVideosPerCourseData](docs/WatchedVideosPerCourseData.md)
 - [WatchedVideosPerUser](docs/WatchedVideosPerUser.md)
 - [WatchedVideosPerUserData](docs/WatchedVideosPerUserData.md)
 - [WebResource](docs/WebResource.md)
 - [WebResourceCard](docs/WebResourceCard.md)
 - [WebResourcesQuery](docs/WebResourcesQuery.md)
 - [WebexConfig](docs/WebexConfig.md)
 - [WebexWebhook](docs/WebexWebhook.md)
 - [WhatAppWebHook](docs/WhatAppWebHook.md)
 - [WhatsappConfig](docs/WhatsappConfig.md)
 - [WhatsappUserConfig](docs/WhatsappUserConfig.md)
 - [WhitelistedDomain](docs/WhitelistedDomain.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="PlatformApiKeyAuthentication"></a>
### PlatformApiKeyAuthentication

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




